@@ -12,18 +12,22 @@
 -- Stability   :  experimental
 -- Portability :  portable
 --
--- GZIp and MMap IO for ByteStrings, and miscellaneous functions for Data.ByteString
+-- GZIp and MMap IO for ByteStrings, encoding utilities, and miscellaneous
+-- functions for Data.ByteString
 --
 
 module ByteStringUtils (
 
         unsafeWithInternals,
+        unpackPSFromUTF8,
+        packStringToUTF8,
 
         -- IO with mmap or gzip
         gzReadFilePS,
         mmapFilePS,
         gzWriteFilePS,
         gzWriteFilePSs,
+        gzReadStdin,
 
         -- gzip handling
         isGZFile,
@@ -40,13 +44,20 @@ module ByteStringUtils (
         breakLastPS,
         substrPS,
         readIntPS,
-        is_funky,
+        isFunky,
         fromHex2PS,
         fromPS2Hex,
         betweenLinesPS,
-        break_after_nth_newline,
-        break_before_nth_newline,
-        intercalate
+        breakAfterNthNewline,
+        breakBeforeNthNewline,
+        intercalate,
+
+        -- encoding and unicode utilities
+        decodeLocale,
+        encodeLocale,
+        encodeLatin1,
+        decodeString,
+        utf8ToLocale
     ) where
 
 import Prelude hiding ( catch )
@@ -57,10 +68,12 @@ import Data.ByteString (intercalate, uncons)
 import Data.ByteString.Internal (fromForeignPtr)
 
 #if defined (HAVE_MMAP)
-import Control.Exception        ( catch )
+import Control.Exception.Extensible ( catch, SomeException )
 #endif
 import System.IO
 import System.IO.Unsafe         ( unsafePerformIO )
+import System.Console.Haskeline ( runInputT, defaultSettings )
+import System.Console.Haskeline.Encoding ( decode, encode )
 
 import Foreign.Storable         ( peekElemOff, peek )
 import Foreign.Marshal.Array    ( advancePtr )
@@ -70,6 +83,9 @@ import Data.Bits                ( rotateL )
 import Data.Char                ( ord, isSpace )
 import Data.Word                ( Word8 )
 import Data.Int                 ( Int32 )
+import qualified Data.Text as T ( pack, unpack )
+import Data.Text.Encoding       ( encodeUtf8, decodeUtf8With )
+import Data.Text.Encoding.Error ( lenientDecode )
 import Control.Monad            ( when )
 
 import Foreign.Ptr              ( plusPtr, Ptr )
@@ -113,6 +129,17 @@ unsafeWithInternals ps f
 readIntPS :: B.ByteString -> Maybe (Int, B.ByteString)
 readIntPS = BC.readInt . BC.dropWhile isSpace
 
+-- -----------------------------------------------------------------------------
+-- Destructor functions (taking PackedStrings apart)
+
+-- | Decodes a 'ByteString' containing UTF-8 to a 'String'. Decoding errors are
+--   flagged with the U+FFFD character.
+unpackPSFromUTF8 :: B.ByteString -> String
+unpackPSFromUTF8  = T.unpack . decodeUtf8With lenientDecode
+
+packStringToUTF8 :: String -> B.ByteString
+packStringToUTF8 = encodeUtf8 . T.pack
+
 -- -----------------------------------------------------------------------------
 -- List-mimicking functions for PackedStrings
 
@@ -154,7 +181,7 @@ firstspace !ptr !n !m
 -- | 'dropSpace' efficiently returns the 'ByteString' argument with
 -- white space Chars removed from the front. It is more efficient than
 -- calling dropWhile for removing whitespace. I.e.
--- 
+--
 -- > dropWhile isSpace == dropSpace
 --
 dropSpace :: B.ByteString -> B.ByteString
@@ -165,7 +192,7 @@ dropSpace (BI.PS x s l) = BI.inlinePerformIO $ withForeignPtr x $ \p -> do
 
 -- | 'breakSpace' returns the pair of ByteStrings when the argument is
 -- broken at the first whitespace byte. I.e.
--- 
+--
 -- > break isSpace == breakSpace
 --
 breakSpace :: B.ByteString -> (B.ByteString,B.ByteString)
@@ -180,9 +207,9 @@ breakSpace (BI.PS x s l) = BI.inlinePerformIO $ withForeignPtr x $ \p -> do
 
 ------------------------------------------------------------------------
 
-{-# INLINE is_funky #-}
-is_funky :: B.ByteString -> Bool
-is_funky ps = case BI.toForeignPtr ps of
+{-# INLINE isFunky #-}
+isFunky :: B.ByteString -> Bool
+isFunky ps = case BI.toForeignPtr ps of
    (x,s,l) ->
     unsafePerformIO $ withForeignPtr x $ \p->
     (/=0) `fmap` has_funky_char (p `plusPtr` s) (fromIntegral l)
@@ -372,6 +399,20 @@ gzWriteFilePSs :: FilePath -> [B.ByteString] -> IO ()
 gzWriteFilePSs f pss  =
     BL.writeFile f $ GZ.compress $ BL.fromChunks pss
 
+-- | Read standard input, which may or may not be gzip compressed, directly
+-- into a 'B.ByteString'.
+gzReadStdin :: IO B.ByteString
+gzReadStdin = do header <- B.hGet stdin 2
+                 rest   <- B.hGetContents stdin
+                 let allStdin = B.concat [header,rest]
+                 return $
+                  if header /= BC.pack "\31\139"
+                   then allStdin
+                   else let decompress = fst . gzDecompress Nothing
+                            compressed = BL.fromChunks [allStdin]
+                        in
+                        B.concat $ decompress compressed
+
 -- -----------------------------------------------------------------------------
 -- mmapFilePS
 
@@ -390,7 +431,7 @@ mmapFilePS :: FilePath -> IO B.ByteString
 #ifdef HAVE_MMAP
 mmapFilePS f = do
   x <- mmapFileByteString f Nothing
-   `catch` (\_ -> do
+   `catch` (\(_ :: SomeException) -> do
                      size <- fileSize `fmap` getSymbolicLinkStatus f
                      if size == 0
                         then return B.empty
@@ -443,12 +484,12 @@ betweenLinesPS start end ps
        _ -> Nothing
 
 -- -------------------------------------------------------------------------
--- break_after_nth_newline
+-- breakAfterNthNewline
 
-break_after_nth_newline :: Int -> B.ByteString
+breakAfterNthNewline :: Int -> B.ByteString
                         -> Maybe (B.ByteString, B.ByteString)
-break_after_nth_newline 0 the_ps | B.null the_ps = Just (B.empty, B.empty)
-break_after_nth_newline n the_ps =
+breakAfterNthNewline 0 the_ps | B.null the_ps = Just (B.empty, B.empty)
+breakAfterNthNewline n the_ps =
   case BI.toForeignPtr the_ps of
   (fp,the_s,l) ->
    unsafePerformIO $ withForeignPtr fp $ \p ->
@@ -465,12 +506,12 @@ break_after_nth_newline n the_ps =
       findit n the_s
 
 -- -------------------------------------------------------------------------
--- break_before_nth_newline
+-- breakBeforeNthNewline
 
-break_before_nth_newline :: Int -> B.ByteString -> (B.ByteString, B.ByteString)
-break_before_nth_newline 0 the_ps
+breakBeforeNthNewline :: Int -> B.ByteString -> (B.ByteString, B.ByteString)
+breakBeforeNthNewline 0 the_ps
  | B.null the_ps = (B.empty, B.empty)
-break_before_nth_newline n the_ps =
+breakBeforeNthNewline n the_ps =
  case BI.toForeignPtr the_ps of
  (fp,the_s,l) ->
    unsafePerformIO $ withForeignPtr fp $ \p ->
@@ -486,3 +527,31 @@ break_before_nth_newline n the_ps =
           nl = BI.c2w '\n'
           end = the_s + l
       findit n the_s
+
+-- | Decode a ByteString to a String according to the current locale
+-- unsafePerformIO in the locale function is ratified by the fact that GHC 6.12
+-- and above also supply locale conversion with functions with a pure type.
+-- Unrecognized byte sequences in the input are skipped.
+decodeLocale :: B.ByteString -> String
+decodeLocale = unsafePerformIO . runInputT defaultSettings . decode
+
+-- | Encode a String to a ByteString with latin1 (i.e., the values of the
+-- characters become the values of the bytes; if a character value is greater
+-- than 255, its byte becomes the character value modulo 256)
+encodeLatin1 :: String -> B.ByteString
+encodeLatin1 = B.pack . (map (fromIntegral . ord))
+
+-- | Encode a String to a ByteString according to the current locale
+encodeLocale :: String -> B.ByteString
+encodeLocale = unsafePerformIO . runInputT defaultSettings . encode
+
+-- | Take a @String@ that represents byte values and re-decode it acording to
+-- the current locale.
+decodeString :: String -> String
+decodeString = decodeLocale . encodeLatin1
+
+-- | Convert a bytestring representing a text from UTF-8 to the current locale
+utf8ToLocale :: B.ByteString -> B.ByteString
+utf8ToLocale bs = encodeLocale string
+  where string = unpackPSFromUTF8 bs
+
