@@ -8,13 +8,14 @@ import Printer (Printer, Printers, Printers'(..), Printable(..), Color(..),
                 invisiblePrinter, (<>), (<?>), Doc(Doc,unDoc), unsafeBothText, simplePrinter, hcat,
                 unsafeText, unsafeChar, space, unsafePackedString,
                 renderStringWith, prefix )
-import Data.Char ( isAscii, isPrint, isSpace, isControl, ord, chr, intToDigit )
+import Data.Char ( isAscii, isPrint, isSpace, isControl, ord, chr )
 import Data.Bits ( bit, xor )
 import System.Environment ( getEnv )
 import qualified Data.ByteString.Char8 as BC (unpack, any, last, spanEnd)
 import qualified Data.ByteString       as B (null, init)
 import System.IO.Unsafe ( unsafePerformIO )
 import System.IO ( hIsTerminalDevice, Handle )
+import Text.Printf ( printf )
 
 dollar, cr :: Doc
 dollar = unsafeBothText "$"
@@ -101,7 +102,7 @@ getPolicy handle = unsafePerformIO $
 -- | @'fancyPrinters' h@ returns a set of printers suitable for outputting
 -- to @h@
 fancyPrinters :: Printers
-fancyPrinters h = let policy = getPolicy h in 
+fancyPrinters h = let policy = getPolicy h in
                       Printers { colorP = colorPrinter policy,
                              invisibleP = invisiblePrinter,
                              hiddenP = colorPrinter policy Green,
@@ -115,11 +116,11 @@ fancyPrinters h = let policy = getPolicy h in
 -- That is, if @policy@ has @poLineColor@ set, then colors the line, otherwise
 -- does nothing.
 lineColorTrans :: Policy -> Color -> Doc -> Doc
-lineColorTrans po | poLineColor po = \c d -> prefix (set_color c) d <?> unsafeBothText reset_color
+lineColorTrans po | poLineColor po = \c d -> prefix (setColor c) d <?> unsafeBothText resetColor
                   | otherwise      = const id
 
 lineColorSuffix :: Policy -> [Printable] -> [Printable]
-lineColorSuffix po | poLineColor po = \d -> S reset_color : d
+lineColorSuffix po | poLineColor po = \d -> S resetColor : d
                    | otherwise      = id
 
 colorPrinter :: Policy -> Color -> Printer
@@ -141,7 +142,7 @@ userchunkPrinter po p
                 then Doc $ escapePrinter po p
                 else Doc (escapePrinter po (PS leadPS))
                   <> Doc (escapePrinter po{poSpace=True} (PS trailPS))
-                  <> mark_escape po dollar
+                  <> markEscape po dollar
 
   prString s = let (trail',lead') = span isSpace (reverse s)
                    lead = reverse lead'
@@ -149,7 +150,7 @@ userchunkPrinter po p
                in if (not.null) trail
                    then Doc (escapePrinter po (S lead))
                      <> Doc (escapePrinter po{poSpace=True} (S trail))
-                     <> mark_escape po dollar
+                     <> markEscape po dollar
                    else Doc (escapePrinter po p)
 
 escapePrinter :: Policy -> Printer
@@ -161,7 +162,7 @@ escapePrinter po
           | otherwise            = epr p
 
   epr (S s)      = escape po s
-  epr (PS ps)    = if BC.any (not.no_escape po) ps
+  epr (PS ps)    = if BC.any (not.noEscape po) ps
                    then escape po (BC.unpack ps)
                    else unsafePackedString ps
   epr (Both s _) = escape po s
@@ -175,28 +176,26 @@ escapePrinter po
   initPR (Both s ps) = Both (init s) (B.init ps)
 
 
--- escape assumes the input is in ['\0'..'\255']
-
 -- | @'escape' policy string@ escapes @string@ according to the rules
 -- defined in 'policy', turning it into a 'Doc'.
 escape :: Policy -> String -> Doc
 escape _ "" = unsafeText ""
 escape po s = hcat (map escapeChar s)
  where
-  escapeChar c | no_escape po c = unsafeChar c
+  escapeChar c | noEscape po c = unsafeChar c
   escapeChar ' ' = space
   escapeChar c = (emph.unsafeText.quoteChar) c
-  emph = mark_escape po
+  emph = markEscape po
 
--- | @'no_escape' policy c@ tells wether @c@ will be left as-is
+-- | @'noEscape' policy c@ tells wether @c@ will be left as-is
 -- when escaping according to @policy@
-no_escape :: Policy -> Char -> Bool
-no_escape po c | poSpace po && isSpace c = False
-no_escape po c | c `elem` poEscX po = False
-no_escape po c | c `elem` poNoEscX po = True
-no_escape _ '\t' = True  -- tabs will likely be converted to spaces
-no_escape _ '\n' = True
-no_escape po c = if (poIsprint po) then isPrint c
+noEscape :: Policy -> Char -> Bool
+noEscape po c | poSpace po && isSpace c = False
+noEscape po c | c `elem` poEscX po = False
+noEscape po c | c `elem` poNoEscX po = True
+noEscape _ '\t' = True  -- tabs will likely be converted to spaces
+noEscape _ '\n' = True
+noEscape po c = if (poIsprint po) then isPrint c
                                    else isPrintableAscii c
                  ||  c >= '\x80' && po8bit po
 
@@ -216,66 +215,65 @@ quoteChar c
  | otherwise = sHex
  where
   cHat = chr $ (bit 6 `xor`) $ ord c
-  sHex = let (q, r) = quotRem (ord c) 16
-         in ['\\', intToDigit q, intToDigit r]
+  sHex = "<U+" ++ printf "%04X" c ++ ">"
 
 
 -- make colors and highlightings
 
--- | @'mark_escape' policy doc@ marks @doc@ with the appropriate
+-- | @'markEscape' policy doc@ marks @doc@ with the appropriate
 -- marking for escaped characters according to @policy@
-mark_escape :: Policy -> Doc -> Doc
-mark_escape po | poAltColor po  = make_invert
-               | poColor po     = make_color Red
-               | otherwise      = make_asciiart
+markEscape :: Policy -> Doc -> Doc
+markEscape po  | poAltColor po  = makeInvert
+               | poColor po     = makeColor Red
+               | otherwise      = makeAsciiart
 
 -- | @'color' policy color doc@ colors @doc@ with color @color@ if
 -- @policy@ is not set to use an alternative to color. In that case,
 -- it makes the text bold instead.
 color :: Policy -> Color -> Doc -> Doc
-color po | poAltColor po = \_ -> make_bold
-         | otherwise     = make_color
+color po | poAltColor po = \_ -> makeBold
+         | otherwise     = makeColor
 
-make_color, make_color' :: Color -> Doc -> Doc
+makeColor, makeColor' :: Color -> Doc -> Doc
 
-make_color' = with_color . set_color
+makeColor' = withColor . setColor
 
--- memoized version of make_color'
-make_color Blue    = make_color' Blue
-make_color Red     = make_color' Red
-make_color Green   = make_color' Green
-make_color Cyan    = make_color' Cyan
-make_color Magenta = make_color' Magenta
+-- memoized version of makeColor'
+makeColor Blue    = makeColor' Blue
+makeColor Red     = makeColor' Red
+makeColor Green   = makeColor' Green
+makeColor Cyan    = makeColor' Cyan
+makeColor Magenta = makeColor' Magenta
 
-set_color :: Color -> String
-set_color Blue    = "\x1B[01;34m" -- bold blue
-set_color Red     = "\x1B[01;31m" -- bold red
-set_color Green   = "\x1B[01;32m" -- bold green
-set_color Cyan    = "\x1B[36m"    -- light cyan
-set_color Magenta = "\x1B[35m"    -- light magenta
+setColor :: Color -> String
+setColor Blue    = "\x1B[01;34m" -- bold blue
+setColor Red     = "\x1B[01;31m" -- bold red
+setColor Green   = "\x1B[01;32m" -- bold green
+setColor Cyan    = "\x1B[36m"    -- light cyan
+setColor Magenta = "\x1B[35m"    -- light magenta
 
--- | @'make_asciiart' doc@ tries to make @doc@ (usually a
+-- | @'makeAsciiart' doc@ tries to make @doc@ (usually a
 -- single escaped char) stand out with the help of only plain
 -- ascii, i.e., no color or font style.
-make_asciiart :: Doc -> Doc
-make_asciiart x = unsafeBothText "[_" <> x <> unsafeBothText "_]"
+makeAsciiart :: Doc -> Doc
+makeAsciiart x = unsafeBothText "[_" <> x <> unsafeBothText "_]"
 
 -- | the string to reset the terminal's color.
-reset_color :: String
-reset_color = "\x1B[00m"
+resetColor :: String
+resetColor = "\x1B[00m"
 
--- | @'with_color' color doc@ returns a colorized version of @doc@.
--- @color@ is a string that represents a color, given by 'set_color'
-with_color :: String -> Doc -> Doc
-with_color c =
+-- | @'withColor' color doc@ returns a colorized version of @doc@.
+-- @color@ is a string that represents a color, given by 'setColor'
+withColor :: String -> Doc -> Doc
+withColor c =
    let c' = unsafeBothText c
-       r' = unsafeBothText reset_color
+       r' = unsafeBothText resetColor
    in \x -> c' <> x <> r'
 
 
--- | 'make_bold' boldens a doc.
-make_bold :: Doc -> Doc
--- | 'make_invert' returns an invert video version of a doc.
-make_invert :: Doc -> Doc
-make_bold   = with_color "\x1B[01m"
-make_invert = with_color "\x1B[07m"
+-- | 'makeBold' boldens a doc.
+makeBold :: Doc -> Doc
+-- | 'makeInvert' returns an invert video version of a doc.
+makeInvert :: Doc -> Doc
+makeBold   = withColor "\x1B[01m"
+makeInvert = withColor "\x1B[07m"
