@@ -1,16 +1,15 @@
 {-# OPTIONS_GHC -cpp #-}
 {-# LANGUAGE CPP #-}
-module Darcs.Email ( make_email, read_email, formatHeader ) where
+module Darcs.Email ( makeEmail, readEmail, formatHeader ) where
 
 import Data.Char ( digitToInt, isHexDigit, ord, intToDigit, isPrint, toUpper )
 import Data.List ( isInfixOf )
-import qualified Codec.Binary.UTF8.String as UTF8 ( encode )
 import Printer ( Doc, ($$), (<+>), (<>), text, empty, packedString, renderPS)
 
-import ByteStringUtils (dropSpace, linesPS, betweenLinesPS )
+import ByteStringUtils ( packStringToUTF8, dropSpace, linesPS, betweenLinesPS )
 import qualified Data.ByteString          as B  (ByteString, length, null, tail
                                                 ,drop, head, concat, singleton
-                                                ,pack, append, empty
+                                                ,pack, append, empty, unpack
                                                 )
 import qualified Data.ByteString.Char8    as BC (index, head, pack)
 import Data.ByteString.Internal as B (c2w, createAndTrim)
@@ -19,12 +18,12 @@ import Foreign.Ptr ( Ptr, plusPtr )
 import Foreign.Storable ( poke )
 import Data.Word ( Word8 )
 
--- line_max is maximum number of characters in an e-mail line excluding the CRLF
--- at the end. qline_max is the number of characters in a q-encoded or
+-- lineMax is maximum number of characters in an e-mail line excluding the CRLF
+-- at the end. qlineMax is the number of characters in a q-encoded or
 -- quoted-printable-encoded line.
-line_max, qline_max :: Int
-line_max  = 78
-qline_max = 75
+lineMax, qlineMax :: Int
+lineMax  = 78
+qlineMax = 75
 
 -- | Formats an e-mail header by encoding any non-ascii characters using UTF-8
 --   and Q-encoding, and folding lines at appropriate points. It doesn't do
@@ -37,39 +36,39 @@ formatHeader :: String -> String -> B.ByteString
 formatHeader headerName headerValue =
     B.append nameColon encodedValue
   where nameColon = B.pack (map B.c2w (headerName ++ ":")) -- space for folding
-        encodedValue = fold_and_encode (' ':headerValue)
+        encodedValue = foldAndEncode (' ':headerValue)
                                        (B.length nameColon) False False
 
 -- run through a string and encode non-ascii words and fold where appropriate.
 -- the integer argument is the current position in the current line.
 -- the string in the first argument must begin with whitespace, or be empty.
-fold_and_encode :: String -> Int -> Bool -> Bool -> B.ByteString
-fold_and_encode [] _ _               _         = B.empty
-fold_and_encode s  p lastWordEncoded inMidWord = 
+foldAndEncode :: String -> Int -> Bool -> Bool -> B.ByteString
+foldAndEncode [] _ _               _         = B.empty
+foldAndEncode s  p lastWordEncoded inMidWord =
   let newline  = B.singleton 10
       space    = B.singleton 32
       s2bs     = B.pack . map B.c2w
       -- the twelve there is the max number of ASCII chars to encode a single
       -- character: 4 * 3, 4 UTF-8 bytes times 3 ASCII chars per byte
-      safeEncChunkLength = (qline_max - B.length encoded_word_start
-                                      - B.length encoded_word_end) `div` 12
+      safeEncChunkLength = (qlineMax - B.length encodedWordStart
+                                      - B.length encodedWordEnd) `div` 12
       (curSpace, afterCurSpace) = span (== ' ') s
       (curWord,  afterCurWord)  = break (== ' ') afterCurSpace
       qEncWord | lastWordEncoded = qEncode (curSpace ++ curWord)
                | otherwise       = qEncode curWord
       mustEncode = inMidWord
                    || any (\c -> not (isPrint c) || (ord c) > 127) curWord
-                   || length curWord > line_max - 1
+                   || length curWord > lineMax - 1
                    || isInfixOf "=?" curWord
       mustFold
         | mustEncode && lastWordEncoded
-            = p + 1 + B.length qEncWord > line_max
+            = p + 1 + B.length qEncWord > lineMax
         | mustEncode
-            = p + length curSpace + B.length qEncWord > line_max
+            = p + length curSpace + B.length qEncWord > lineMax
         | otherwise
-            = p + length curSpace + length curWord > line_max
-      mustSplit = (B.length qEncWord > qline_max && mustEncode)
-                  || length curWord > line_max - 1
+            = p + length curSpace + length curWord > lineMax
+      mustSplit = (B.length qEncWord > qlineMax && mustEncode)
+                  || length curWord > lineMax - 1
       spaceToInsert | mustEncode && lastWordEncoded = space
                     | otherwise                     = s2bs curSpace
       wordToInsert
@@ -80,36 +79,39 @@ fold_and_encode s  p lastWordEncoded inMidWord =
                 | otherwise = B.concat [spaceToInsert, wordToInsert]
       (rest, nextP)
         | mustSplit
-            = (drop safeEncChunkLength curWord ++ afterCurWord, qline_max + 1)
-        | mustEncode && mustFold 
+            = (drop safeEncChunkLength curWord ++ afterCurWord, qlineMax + 1)
+        | mustEncode && mustFold
             = (afterCurWord, B.length spaceToInsert + B.length wordToInsert)
         | otherwise
             = (afterCurWord, p + B.length doneChunk)
-  in B.append doneChunk (fold_and_encode rest nextP mustEncode mustSplit)
+  in B.append doneChunk (foldAndEncode rest nextP mustEncode mustSplit)
 
 -- | Turns a piece of string into a q-encoded block
 --   Applies q-encoding, for use in e-mail header values, as defined in RFC 2047.
 --   It just takes a string and builds an encoded-word from it, it does not check
 --   length or necessity.
 qEncode :: String -> B.ByteString
-qEncode s = B.concat [encoded_word_start,
+qEncode s = B.concat [encodedWordStart,
                       encodedString,
-                      encoded_word_end]
-  where encodedString =  B.concat (map q_encode_char s)
+                      encodedWordEnd]
+  where encodedString =  B.concat (map qEncodeChar s)
 
-encoded_word_start, encoded_word_end :: B.ByteString
-encoded_word_start = B.pack (map B.c2w "=?UTF-8?Q?")
-encoded_word_end   = B.pack (map B.c2w "?=")
+encodedWordStart, encodedWordEnd :: B.ByteString
+encodedWordStart = B.pack (map B.c2w "=?UTF-8?Q?")
+encodedWordEnd   = B.pack (map B.c2w "?=")
 
 -- turns a character into its q-encoded bytestring value. For most printable
 -- ASCII characters, that's just the singleton bytestring with that char.
-q_encode_char :: Char -> B.ByteString
-q_encode_char c
+qEncodeChar :: Char -> B.ByteString
+qEncodeChar c
     | c == ' '                          = c2bs '_'
     | isPrint c
       && not (c `elem` ['?', '=', '_'])
       && ord c < 128                    = c2bs c
-    | otherwise                         = B.concat (map qbyte (UTF8.encode [c]))
+    | otherwise                         = B.concat
+                                            (map qbyte
+                                              (B.unpack
+                                                (packStringToUTF8 [c])))
   where c2bs = B.singleton . B.c2w
         -- qbyte turns a byte into its q-encoded "=hh" representation
         qbyte b = B.pack (map B.c2w ['='
@@ -123,24 +125,24 @@ q_encode_char c
 qpencode :: B.ByteString -> B.ByteString
 qpencode s = unsafePerformIO
            -- Really only (3 + 2/75) * length or something in the worst case
-           $ B.createAndTrim (4 * B.length s) (\buf -> encode s qline_max buf 0)
+           $ B.createAndTrim (4 * B.length s) (\buf -> encode s qlineMax buf 0)
 
 encode :: B.ByteString -> Int -> Ptr Word8 -> Int -> IO Int
 encode ps _ _ bufi | B.null ps = return bufi
 encode ps n buf bufi = case B.head ps of
   c | c == newline ->
         do poke (buf `plusPtr` bufi) newline
-           encode ps' qline_max buf (bufi+1)
+           encode ps' qlineMax buf (bufi+1)
     | n == 0 && B.length ps > 1 ->
         do poke (buf `plusPtr` bufi) equals
            poke (buf `plusPtr` (bufi+1)) newline
-           encode ps qline_max buf (bufi + 2)
+           encode ps qlineMax buf (bufi + 2)
     | (c == tab || c == space) ->
         if B.null ps' || B.head ps' == newline
         then do poke (buf `plusPtr` bufi) c
                 poke (buf `plusPtr` (bufi+1)) equals
                 poke (buf `plusPtr` (bufi+2)) newline
-                encode ps' qline_max buf (bufi + 3)
+                encode ps' qlineMax buf (bufi + 3)
         else do poke (buf `plusPtr` bufi) c
                 encode ps' (n - 1) buf (bufi + 1)
     | (c >= bang && c /= equals && c <= tilde) ->
@@ -193,8 +195,8 @@ decode (ps:pss) buf bufi
           toWord8 :: Int -> Word8
           toWord8 = fromIntegral
 
-make_email :: String -> [(String, String)] -> (Maybe Doc) -> Doc -> (Maybe String) -> Doc
-make_email repodir headers mcontents bundle mfilename =
+makeEmail :: String -> [(String, String)] -> (Maybe Doc) -> Doc -> (Maybe String) -> Doc
+makeEmail repodir headers mcontents bundle mfilename =
     text "DarcsURL:" <+> text repodir
  $$ foldl (\m (h,v) -> m $$ (text (h ++ ":") <+> text v)) empty headers
  $$ text "MIME-Version: 1.0"
@@ -224,8 +226,8 @@ make_email repodir headers mcontents bundle mfilename =
  $$ text ""
  $$ text ""
 
-read_email :: B.ByteString -> B.ByteString
-read_email s =
+readEmail :: B.ByteString -> B.ByteString
+readEmail s =
     case betweenLinesPS
          (BC.pack "Content-Description: A darcs patch for your repository!")
          (BC.pack "--=_--") s of
