@@ -4,7 +4,7 @@ module Darcs.External (
     backupByRenaming, backupByCopying,
     copyFileOrUrl, speculateFileOrUrl, copyFilesOrUrls, copyLocal, cloneFile,
     cloneTree, cloneTreeExcept, clonePartialsTree, clonePaths,
-    fetchFilePS, gzFetchFilePS,
+    fetchFilePS, fetchFileLazyPS, gzFetchFilePS,
     sendEmail, generateEmail, sendEmailDoc, resendEmail,
     signString, verifyPS,
     execDocPipe, execPipeIgnoreError,
@@ -14,7 +14,7 @@ module Darcs.External (
     maybeURLCmd,
     Cachable(Cachable, Uncachable, MaxAge),
     viewDoc, viewDocWith,
-    sendmail_path, diff_program, darcs_program
+    sendmailPath, diffProgram, darcsProgram
   ) where
 
 import qualified Ratified
@@ -34,7 +34,7 @@ import System.Directory ( createDirectory, getDirectoryContents,
                           findExecutable )
 import System.Process ( runProcess, runInteractiveProcess, waitForProcess )
 import Control.Concurrent ( forkIO, newEmptyMVar, putMVar, takeMVar )
-import Control.Exception ( bracket, try, finally )
+import Control.Exception.Extensible ( bracket, try, finally, SomeException )
 import Data.Char ( toUpper )
 #if defined (HAVE_MAPI)
 import Foreign.C ( CString, withCString )
@@ -53,7 +53,7 @@ import System.FilePath.Posix ( (</>), takeDirectory, normalise )
 import Darcs.Flags ( DarcsFlag( SignAs, Sign, SignSSL, NoLinks,
                                 Verify, VerifySSL, RemoteDarcs ) )
 import Darcs.RepoPath ( AbsolutePath, toFilePath )
-import Darcs.Utils ( withCurrentDirectory, breakCommand, get_viewer, ortryrunning, )
+import Darcs.Utils ( withCurrentDirectory, breakCommand, getViewer, ortryrunning, )
 import Progress ( withoutProgress, progressList, debugMessage )
 
 import ByteStringUtils (gzReadFilePS, linesPS, unlinesPS)
@@ -61,22 +61,23 @@ import qualified Data.ByteString as B (ByteString, empty, null, readFile
             ,hGetContents, writeFile, hPut, length
             ,take, concat, drop, isPrefixOf, singleton, append)
 import qualified Data.ByteString.Char8 as BC (unpack, pack)
+import qualified Data.ByteString.Lazy as BL
 
-import Darcs.Lock ( withTemp, withOpenTemp, tempdir_loc, removeFileMayNotExist )
+import Darcs.Lock ( withTemp, withOpenTemp, tempdirLoc, removeFileMayNotExist )
 import CommandLine ( parseCmd, addUrlencoded )
 import URL ( copyUrl, copyUrlFirst, waitUrl )
 import Ssh ( getSSH, copySSH, copySSHs, SSHCmd(..) )
 import URL ( Cachable(..) )
 import Exec ( exec, Redirect(..), withoutNonBlock )
-import Darcs.URL ( is_file, is_url, is_ssh )
+import Darcs.URL ( isFile, isUrl, isSsh )
 import Darcs.Utils ( catchall )
 import Printer ( Doc, Printers, putDocLnWith, hPutDoc, hPutDocLn, hPutDocWith, ($$), renderPS,
                  simplePrinters,
                  text, empty, packedString, vcat, renderString )
 import Darcs.Email ( formatHeader )
 
-sendmail_path :: IO String
-sendmail_path = do
+sendmailPath :: IO String
+sendmailPath = do
   l <- filterM doesFileExist $ liftM2 (</>)
                 [ "/usr/sbin", "/sbin", "/usr/lib" ]
                 [ "sendmail" ]
@@ -84,15 +85,15 @@ sendmail_path = do
   when (isNothing ex && null l) $ fail "Cannot find the \"sendmail\" program."
   return $ head $ maybeToList ex ++ l
 
-diff_program :: IO String
-diff_program = do
+diffProgram :: IO String
+diffProgram = do
   l <- filterM (fmap isJust . findExecutable) [ "gdiff", "gnudiff", "diff" ]
   when (null l) $ fail "Cannot find the \"diff\" program."
   return $ head l
 
 -- |Get the name of the darcs executable (as supplied by @getProgName@)
-darcs_program :: IO String
-darcs_program = getProgName
+darcsProgram :: IO String
+darcsProgram = getProgName
 -- Another option: getEnv "DARCS" `catch` \_ -> getProgName
 
 backupByRenaming :: FilePath -> IO ()
@@ -129,13 +130,23 @@ backupBy backup f =
 -- (either a file or an URL). If it has to download an url, then it
 -- will use a cache as required by its second argument.
 fetchFilePS :: String -> Cachable -> IO B.ByteString
-fetchFilePS fou _ | is_file fou = B.readFile fou
+fetchFilePS fou _ | isFile fou = B.readFile fou
 fetchFilePS fou cache = withTemp $ \t -> do let opts = [] -- FIXME: no network flags
                                             copyFileOrUrl opts fou t cache
                                             B.readFile t
 
+-- | @fetchFileLazyPS fileOrUrl cache@ lazily reads the content of
+-- its argument (either a file or an URL). Warning: this function may
+-- constitute a fd leak; make sure to force consumption of file contents
+-- to avoid that.
+fetchFileLazyPS :: String -> Cachable -> IO BL.ByteString
+fetchFileLazyPS fou _ | isFile fou = BL.readFile fou
+fetchFileLazyPS fou cache = withTemp $ \t -> do let opts = [] -- FIXME: no network flags
+                                                copyFileOrUrl opts fou t cache
+                                                BL.readFile t
+
 gzFetchFilePS :: String -> Cachable -> IO B.ByteString
-gzFetchFilePS fou _ | is_file fou = gzReadFilePS fou
+gzFetchFilePS fou _ | isFile fou = gzReadFilePS fou
 gzFetchFilePS fou cache = withTemp $ \t-> do let opts = [] -- FIXME: no network flags
                                              copyFileOrUrl opts fou t cache
                                              gzReadFilePS t
@@ -144,15 +155,18 @@ remoteDarcsCmd :: [DarcsFlag] -> String
 remoteDarcsCmd flags = head $ [ c | (RemoteDarcs c) <- flags ] ++ ["darcs"]
 
 copyFileOrUrl :: [DarcsFlag] -> FilePath -> FilePath -> Cachable -> IO ()
-copyFileOrUrl opts fou out _     | is_file fou = copyLocal opts fou out
-copyFileOrUrl _    fou out cache | is_url  fou = copyRemote fou out cache
-copyFileOrUrl opts fou out _     | is_ssh  fou = copySSH (remoteDarcsCmd opts) fou out
+copyFileOrUrl opts fou out _     | isFile fou = copyLocal opts fou out
+copyFileOrUrl _    fou out cache | isUrl  fou = copyRemote fou out cache
+copyFileOrUrl opts fou out _     | isSsh  fou = copySSH (remoteDarcsCmd opts) fou out
 copyFileOrUrl _    fou _   _     = fail $ "unknown transport protocol: " ++ fou
 
 speculateFileOrUrl :: String -> FilePath -> IO ()
-speculateFileOrUrl fou out | is_url fou = speculateRemote fou out
+speculateFileOrUrl fou out | isUrl fou = speculateRemote fou out
                            | otherwise = return ()
 
+speculateFilesOrUrls :: FilePath -> [String] -> FilePath -> IO ()
+speculateFilesOrUrls _ _ _ = return () -- FIXME
+
 copyLocal  :: [DarcsFlag] -> String -> FilePath -> IO ()
 copyLocal opts fou out | NoLinks `elem` opts = cloneFile fou out
                        | otherwise = createLink fou out `catchall` cloneFile fou out
@@ -249,9 +263,9 @@ copyRemoteNormal :: String -> FilePath -> Cachable -> IO ()
 copyRemoteNormal u v cache = copyUrlFirst u v cache >> waitUrl u
 
 copyFilesOrUrls :: [DarcsFlag]->FilePath->[String]->FilePath->Cachable->IO ()
-copyFilesOrUrls opts dou ns out _ | is_file dou = copyLocals opts dou ns out
-copyFilesOrUrls _ dou ns out c    | is_url  dou = copyRemotes dou ns out c
-copyFilesOrUrls opts dou ns out _ | is_ssh  dou = copySSHs (remoteDarcsCmd opts) dou ns out
+copyFilesOrUrls opts dou ns out _ | isFile dou = copyLocals opts dou ns out
+copyFilesOrUrls _ dou ns out c    | isUrl  dou = copyRemotes dou ns out c
+copyFilesOrUrls opts dou ns out _ | isSsh  dou = copySSHs (remoteDarcsCmd opts) dou ns out
 copyFilesOrUrls _ dou _  _   _    = fail $ "unknown transport protocol: "++dou
 
 
@@ -364,8 +378,8 @@ generateEmail h f t s cc body = do
             = B.hPut h (B.append (formatHeader field value) newline)
         newline = B.singleton 10
 
-have_sendmail :: IO Bool
-have_sendmail = (sendmail_path >> return True) `catch` (\_ -> return False)
+haveSendmail :: IO Bool
+haveSendmail = (sendmailPath >> return True) `catch` (\_ -> return False)
 
 -- | Send an email, optionally containing a patch bundle
 --   (more precisely, its description and the bundle itself)
@@ -382,7 +396,7 @@ sendEmailDoc _ "" _ "" _ _ _ = return ()
 sendEmailDoc f "" s cc scmd mbundle body =
   sendEmailDoc f cc s "" scmd mbundle body
 sendEmailDoc f t s cc scmd mbundle body = do
-  use_sendmail <- have_sendmail
+  use_sendmail <- haveSendmail
   if use_sendmail || scmd /= "" then do
     withOpenTemp $ \(h,fn) -> do
       generateEmail h f t s cc body
@@ -428,7 +442,7 @@ sendEmailDoc f t s cc scmd mbundle body = do
 resendEmail :: String -> String -> B.ByteString -> IO ()
 resendEmail "" _ _ = return ()
 resendEmail t scmd body = do
-  use_sendmail <- have_sendmail
+  use_sendmail <- haveSendmail
   if use_sendmail || scmd /= ""
    then do
     withOpenTemp $ \(h,fn) -> do
@@ -468,7 +482,7 @@ resendEmail t scmd body = do
 execSendmail :: [(Char,String)] -> String -> String -> IO ExitCode
 execSendmail ftable scmd fn =
   if scmd == "" then do
-     cmd <- sendmail_path
+     cmd <- sendmailPath
      exec cmd ["-i", "-t"] (File fn, Null, AsIs)
   else case parseCmd (addUrlencoded ftable) scmd of
          Right (arg0:opts, wantstdin) ->
@@ -633,7 +647,7 @@ viewDocWith :: Printers -> Doc -> IO ()
 viewDocWith pr msg = do
   isTerminal <- hIsTerminalDevice stdout
   if isTerminal && lengthGreaterThan (20 :: Int) (lines $ renderString msg)
-     then do viewerPlusArgs <- get_viewer
+     then do viewerPlusArgs <- getViewer
              let (viewer:args) = words viewerPlusArgs
              pipeDocToPager viewer args pr msg
                `ortryrunning` pipeDocToPager  "less" [] pr msg
@@ -655,7 +669,7 @@ pipeDocToPager "" _ pr inp = do
   return ExitSuccess
 
 pipeDocToPager c args pr inp = withoutNonBlock $ withoutProgress $ do
-  tmp <- tempdir_loc
+  tmp <- tempdirLoc
   bracket (openBinaryTempFile tmp "darcs-pager") cleanup $ \(fn,fh) ->
     do hPutDocWith pr fh inp
        hClose fh
@@ -666,5 +680,5 @@ pipeDocToPager c args pr inp = withoutNonBlock $ withoutProgress $ do
                  putStrLn $ "Command not found:\n   "++ show (c:args)
             return x
   where
-    cleanup (f,h) = do try $ hClose h
+    cleanup (f,h) = do try (hClose h) :: IO (Either SomeException ())
                        removeFileMayNotExist f
