@@ -21,21 +21,22 @@
 #include "gadts.h"
 
 module Darcs.Hopefully ( Hopefully, PatchInfoAnd,
+                         WPatchInfo, unWPatchInfo, compareWPatchInfo,
                          piap, n2pia, patchInfoAndPatch,
-                         conscientiously, hopefully, info,
+                         conscientiously, hopefully, info, winfo,
                          hopefullyM, createHashed, extractHash,
-                         actually, unavailable ) where
+                         actually, unavailable, patchDesc ) where
 
 import System.IO.Unsafe ( unsafeInterleaveIO )
 
 import Darcs.SignalHandler ( catchNonSignal )
 import Printer ( Doc, renderString, errorDoc, text, ($$) )
-import Darcs.Patch.Info ( PatchInfo, human_friendly, idpatchinfo )
+import Darcs.Patch.Info ( PatchInfo, humanFriendly, idpatchinfo, justName )
 import Darcs.Patch ( RepoPatch, Named, patch2patchinfo )
 import Darcs.Patch.Prim ( Effect(..), Conflict(..) )
 import Darcs.Patch.Patchy ( Patchy, ReadPatch(..), Apply(..), Invert(..),
                             ShowPatch(..), Commute(..) )
-import Darcs.Witnesses.Ordered ( MyEq, unsafeCompare, (:>)(..), (:\/:)(..), (:/\:)(..) )
+import Darcs.Witnesses.Ordered ( MyEq, EqCheck(..), unsafeCoerceP, unsafeCompare, (:>)(..), (:\/:)(..), (:/\:)(..) )
 import Darcs.Witnesses.Sealed ( Sealed(Sealed), seal, mapSeal )
 import Darcs.Utils ( prettyException )
 
@@ -58,6 +59,19 @@ data SimpleHopefully a C(x y) = Actually (a C(x y)) | Unavailable String
 -- know its info.
 data PatchInfoAnd p C(a b) = PIAP !PatchInfo (Hopefully (Named p) C(a b))
 
+-- | @'WPatchInfo' C(a b)@ represents the info of a patch, marked with
+-- the patch's witnesses.
+newtype WPatchInfo C(a b) = WPatchInfo { unWPatchInfo :: PatchInfo }
+
+-- This is actually unsafe if we ever commute patches and then compare them
+-- using this function. TODO: consider adding an extra existential to WPatchInfo
+-- (as with TaggedPatch in Darcs.Patch.Choices)
+compareWPatchInfo :: WPatchInfo C(a b) -> WPatchInfo C(c d) -> EqCheck C((a, b) (c, d))
+compareWPatchInfo (WPatchInfo x) (WPatchInfo y) = if x == y then unsafeCoerceP IsEq else NotEq
+
+instance MyEq WPatchInfo where
+   WPatchInfo x `unsafeCompare` WPatchInfo y = x == y
+
 fmapH :: (a C(x y) -> b C(w z)) -> Hopefully a C(x y) -> Hopefully b C(w z)
 fmapH f (Hopefully sh) = Hopefully (ff sh)
     where ff (Actually a) = Actually (f a)
@@ -69,6 +83,12 @@ fmapH f (Hashed h sh) = Hashed h (ff sh)
 info :: PatchInfoAnd p C(a b) -> PatchInfo
 info (PIAP i _) = i
 
+patchDesc :: forall p C(x y) . PatchInfoAnd p C(x y) -> String
+patchDesc p = justName $ info p
+
+winfo :: PatchInfoAnd p C(a b) -> WPatchInfo C(a b)
+winfo (PIAP i _) = WPatchInfo i
+
 -- | @'piap' i p@ creates a PatchInfoAnd containing p with info i.
 piap :: PatchInfo -> Named p C(a b) -> PatchInfoAnd p C(a b)
 piap i p = PIAP i (Hopefully $ Actually p)
@@ -95,14 +115,14 @@ conscientiously :: (Doc -> Doc)
 conscientiously er (PIAP pinf hp) =
     case hopefully2either hp of
       Right p -> p
-      Left e -> errorDoc $ er (human_friendly pinf $$ text e)
+      Left e -> errorDoc $ er (humanFriendly pinf $$ text e)
 
 -- | @hopefullyM@ is a version of @hopefully@ which calls @fail@ in a
 -- monad instead of erroring.
 hopefullyM :: Monad m => PatchInfoAnd p C(a b) -> m (Named p C(a b))
 hopefullyM (PIAP pinf hp) = case hopefully2either hp of
                               Right p -> return p
-                              Left e -> fail $ renderString (human_friendly pinf $$ text e)
+                              Left e -> fail $ renderString (humanFriendly pinf $$ text e)
 
 -- Any recommendations for a nice adverb to name the below?
 hopefully2either :: Hopefully a C(x y) -> Either String (a C(x y))
@@ -139,17 +159,17 @@ instance Invert p => Invert (PatchInfoAnd p) where
 instance (Conflict p, Effect p, ShowPatch p) => ShowPatch (PatchInfoAnd p) where
     showPatch (PIAP n p) = case hopefully2either p of
                            Right x -> showPatch x
-                           Left _ -> human_friendly n
+                           Left _ -> humanFriendly n
     showContextPatch (PIAP n p) = case hopefully2either p of
                                     Right x -> showContextPatch x
-                                    Left _ -> return $ human_friendly n
-    description (PIAP n _) = human_friendly n
+                                    Left _ -> return $ humanFriendly n
+    description (PIAP n _) = humanFriendly n
     summary (PIAP n p) = case hopefully2either p of
                          Right x -> summary x
-                         Left _ -> human_friendly n
+                         Left _ -> humanFriendly n
     showNicely (PIAP n p) = case hopefully2either p of
                             Right x -> showNicely x
-                            Left _ -> human_friendly n
+                            Left _ -> humanFriendly n
 
 instance Commute p => Commute (PatchInfoAnd p) where
     commute (x :> y) = do y' :> x' <- commute (hopefully x :> hopefully y)
@@ -179,8 +199,9 @@ instance Effect p => Effect (PatchInfoAnd p) where
 instance Conflict p => Conflict (PatchInfoAnd p) where
     listConflictedFiles = listConflictedFiles . hopefully
     resolveConflicts = resolveConflicts . hopefully
-    commute_no_conflicts (x:>y) = do y':>x' <- commute_no_conflicts (hopefully x :> hopefully y)
+    commuteNoConflicts (x:>y) =   do y':>x' <- commuteNoConflicts (hopefully x :> hopefully y)
                                      return (info y `piap` y' :> info x `piap` x')
     conflictedEffect = conflictedEffect . hopefully
+    isInconsistent = isInconsistent . hopefully
 
 instance RepoPatch p => Patchy (PatchInfoAnd p)
