@@ -24,7 +24,7 @@ import Prelude hiding ( catch )
 import Data.Char ( toLower )
 import Data.List ( isSuffixOf )
 import System.IO.Error ( isDoesNotExistError, isPermissionError )
-import Control.Exception ( catch, catchJust, ioErrors )
+import Control.Exception.Extensible ( catch, SomeException, IOException )
 import Control.Monad.Error
 import System.Directory ( getDirectoryContents, createDirectory,
                           removeDirectory, removeFile,
@@ -108,7 +108,7 @@ instance WriteableDirectory IO where
                             fail $ "Cannot remove non-empty file "++fp
                        removeFile fp
     mRemoveDirectory = removeDirectory . fn2fp
-    mRename a b = catchJust ioErrors
+    mRename a b = catch
                   (renameDirectory x y `mplus` renameFile x y)
                   -- We need to catch does not exist errors, since older
                   -- versions of darcs allowed users to rename nonexistent
@@ -132,7 +132,7 @@ instance TolerantMonad TolerantIO where
 
 newtype SilentIO a = SIO { runSilently :: IO a }
 instance TolerantMonad SilentIO where
-    warning io = SIO $ io `catch` \_ -> return ()
+    warning io = SIO $ io `catch` \(_ :: SomeException) -> return ()
     runIO (SIO io) = io
     runTM io = SIO io
 
@@ -192,15 +192,15 @@ instance WriteableDirectory TolerantIO where
      mCreateFile f = warning $ backup f >> mWriteFilePS f B.empty
      mCreateDirectory d = warning $ backup d >> mCreateDirectory d
      mRemoveFile f = warning $ mRemoveFile f
-     mRemoveDirectory d = warning $ catchJust ioErrors
+     mRemoveDirectory d = warning $ catch
                                  (mRemoveDirectory d)
-                                 (\e ->
+                                 (\(e :: IOException) ->
                                    if "(Directory not empty)" `isSuffixOf` show e
                                    then ioError $ userError $
                                             "Not deleting " ++ fn2fp d ++ " because it is not empty."
                                    else ioError $ userError $
                                             "Not deleting " ++ fn2fp d ++ " because:\n" ++ show e)
-     mRename a b = warning $ catchJust ioErrors
+     mRename a b = warning $ catch
                           (let do_backup = if (map toLower x == map toLower y)
                                            then backupByCopying y -- avoid making the original vanish
                                            else backupByRenaming y
@@ -224,15 +224,15 @@ instance WriteableDirectory SilentIO where
      mCreateFile f = warning $ backup f >> mWriteFilePS f B.empty
      mCreateDirectory d = warning $ backup d >> mCreateDirectory d
      mRemoveFile f = warning $ mRemoveFile f
-     mRemoveDirectory d = warning $ catchJust ioErrors
+     mRemoveDirectory d = warning $ catch
                                  (mRemoveDirectory d)
-                                 (\e ->
+                                 (\(e :: SomeException) ->
                                    if "(Directory not empty)" `isSuffixOf` show e
                                    then ioError $ userError $
                                             "Not deleting " ++ fn2fp d ++ " because it is not empty."
                                    else ioError $ userError $
                                             "Not deleting " ++ fn2fp d ++ " because:\n" ++ show e)
-     mRename a b = warning $ catchJust ioErrors
+     mRename a b = warning $ catch
                           (let do_backup = if (map toLower x == map toLower y)
                                            then backupByCopying y -- avoid making the original vanish
                                            else backupByRenaming y
@@ -255,7 +255,7 @@ backup f = backupByRenaming $ fn2fp f
 floatFn :: FileName -> AnchoredPath
 floatFn = floatPath . fn2fp
 
-instance (MonadPlus m, MonadError e m) => ReadableDirectory (HSM.TreeMonad m) where
+instance (Functor m, MonadPlus m, MonadError e m) => ReadableDirectory (HSM.TreeMonad m) where
     mDoesDirectoryExist d = HSM.directoryExists (floatFn d)
     mDoesFileExist f = HSM.fileExists (floatFn f)
     mInCurrentDirectory d action = HSM.withDirectory (floatFn d) action
