@@ -20,19 +20,25 @@
 
 #include "gadts.h"
 
-module Darcs.Patch.Bundle ( hash_bundle, make_bundle, make_bundle2, scan_bundle,
-                     make_context, scan_context,
+module Darcs.Patch.Bundle ( hashBundle, makeBundle, makeBundle2, makeBundleN, scanBundle,
+                            contextPatches, scanContext, patchFilename
                    ) where
 
-import Darcs.Flags ( DarcsFlag, isUnified )
+import Data.Char ( isAlpha, toLower, isDigit, isSpace )
 import Darcs.Hopefully ( PatchInfoAnd, piap,
                          patchInfoAndPatch,
                          unavailable, hopefully )
 import Darcs.Patch ( RepoPatch, Named, showPatch, showContextPatch, readPatch )
-import Darcs.Patch.Info ( PatchInfo, readPatchInfo, showPatchInfo, human_friendly, is_tag )
-import Darcs.Patch.Set ( PatchSet, SealedPatchSet )
+import Darcs.Patch.Info ( PatchInfo, readPatchInfo, showPatchInfo, humanFriendly, isTag )
+import Darcs.Patch.Set ( PatchSet(..), Tagged(..), SealedPatchSet )
+import Darcs.Patch.Depends ( slightlyOptimizePatchset )
+import Darcs.Hopefully( info )
+#ifdef GADT_WITNESSES
+import Darcs.Patch.Set ( Origin )
+#endif
+import Darcs.Witnesses.Sealed ( flipSeal, FlippedSeal(..) )
 import Darcs.Witnesses.Ordered ( RL(..), FL(..), unsafeCoerceP,
-                             reverseFL, (+<+), mapFL, mapFL_FL )
+                             reverseFL, (+<+), mapFL, mapFL_FL, mapRL )
 import Printer ( Doc, renderPS, newline, text, ($$),
                  (<>), vcat, vsep, renderString )
 
@@ -46,24 +52,32 @@ import Darcs.Witnesses.Sealed ( Sealed(Sealed), mapSeal )
 import Storage.Hashed.Tree( Tree )
 import Storage.Hashed.Monad( virtualTreeIO )
 
-hash_bundle :: RepoPatch p => [PatchInfo] -> FL (Named p) C(x y) -> String
-hash_bundle _ to_be_sent = sha1PS $ renderPS
+hashBundle :: RepoPatch p => [PatchInfo] -> FL (Named p) C(x y) -> String
+hashBundle _ to_be_sent = sha1PS $ renderPS
                          $ vcat (mapFL showPatch to_be_sent) <> newline
 
-make_bundle :: RepoPatch p => [DarcsFlag] -> Tree IO -> [PatchInfo] -> FL (Named p) C(x y) -> IO Doc
-make_bundle opts the_s common to_be_sent = make_bundle2 opts the_s common to_be_sent to_be_sent
+makeBundleN :: RepoPatch p => Maybe (Tree IO)
+             -> PatchSet p C(start x) -> FL (Named p) C(x y) -> IO Doc
+makeBundleN the_s (PatchSet ps (Tagged t _ _ :<: _)) to_be_sent =
+    makeBundle2 the_s (ps +<+ (t :<: NilRL)) to_be_sent to_be_sent
+makeBundleN the_s (PatchSet ps NilRL) to_be_sent =
+    makeBundle2 the_s ps to_be_sent to_be_sent
 
--- | In make_bundle2, it is presumed that the two patch sequences are
+makeBundle :: RepoPatch p => Maybe (Tree IO) -> RL (PatchInfoAnd p) C(start x)
+              -> FL (Named p) C(x y) -> IO Doc
+makeBundle the_s common to_be_sent = makeBundle2 the_s common to_be_sent to_be_sent
+
+-- | In makeBundle2, it is presumed that the two patch sequences are
 -- identical, but that they may be lazily generated.  If two different
 -- patch sequences are passed, a bundle with a mismatched hash will be
 -- generated, which is not the end of the world, but isn't very useful
 -- either.
-make_bundle2 :: RepoPatch p => [DarcsFlag] -> Tree IO -> [PatchInfo]
+makeBundle2 :: RepoPatch p => Maybe (Tree IO) -> RL (PatchInfoAnd p) C(start x)
              -> FL (Named p) C(x y) -> FL (Named p) C(x y) -> IO Doc
-make_bundle2 opts the_s common to_be_sent to_be_sent2 =
-    do patches <- case (isUnified opts) of
-                    True -> fst `fmap` virtualTreeIO (showContextPatch to_be_sent) the_s
-                    False -> return (vsep $ mapFL showPatch to_be_sent)
+makeBundle2 the_s common' to_be_sent to_be_sent2 =
+    do patches <- case the_s of
+                    Just tree -> fst `fmap` virtualTreeIO (showContextPatch to_be_sent) tree
+                    Nothing -> return (vsep $ mapFL showPatch to_be_sent)
        return $ format patches
     where format the_new = text ""
                            $$ text "New patches:"
@@ -74,26 +88,27 @@ make_bundle2 opts the_s common to_be_sent to_be_sent2 =
                            $$ text ""
                            $$ (vcat $ map showPatchInfo common)
                            $$ text "Patch bundle hash:"
-                           $$ text (hash_bundle common to_be_sent2)
+                           $$ text (hashBundle common to_be_sent2)
                            $$ text ""
+          common = mapRL info common'
 
-scan_bundle :: RepoPatch p => B.ByteString -> Either String (SealedPatchSet p)
-scan_bundle ps
+scanBundle :: RepoPatch p => B.ByteString -> Either String (SealedPatchSet p C(Origin))
+scanBundle ps
   | B.null ps = Left "Bad patch bundle!"
   | otherwise =
-    case silly_lex ps of
+    case sillyLex ps of
     ("New patches:",rest) ->
-        case get_patches rest of
+        case getPatches rest of
         (Sealed patches, rest') ->
-            case silly_lex rest' of
+            case sillyLex rest' of
             ("Context:", rest'') ->
                 case getContext rest'' of
                 (cont,maybe_hash) ->
                     case substrPS (BC.pack "Patch bundle hash:")
                          maybe_hash of
                     Just n ->
-                        if hash_bundle cont (mapFL_FL hopefully patches)
-                               == fst (silly_lex $ snd $ silly_lex $
+                        if hashBundle cont (mapFL_FL hopefully patches)
+                               == fst (sillyLex $ snd $ sillyLex $
                                        B.drop n maybe_hash)
                         then seal_up_patches patches cont
                         else Left $
@@ -107,37 +122,33 @@ scan_bundle ps
     ("Context:",rest) ->
         case getContext rest of
         (cont, rest') ->
-            case silly_lex rest' of
+            case sillyLex rest' of
             ("New patches:", rest'') ->
-                case parse_patches rest'' of
+                case parsePatches rest'' of
                 Sealed ps'' -> seal_up_patches ps'' cont
             (a,_) -> Left $ "Malformed patch bundle: '" ++ a ++
                      "' is not 'New patches:'"
     ("-----BEGIN PGP SIGNED MESSAGE-----",rest) ->
-            scan_bundle $ filter_gpg_dashes rest
-    (_,rest) -> scan_bundle rest
+            scanBundle $ filterGpgDashes rest
+    (_,rest) -> scanBundle rest
     where seal_up_patches :: RepoPatch p => FL (PatchInfoAnd p) C(x y) -> [PatchInfo]
-                          -> Either String (SealedPatchSet p)
+                          -> Either String (SealedPatchSet p C(Origin))
           seal_up_patches xxx yyy =
               case reverse yyy of
-              (x:_) | is_tag x ->
-                        Right $ Sealed ((reverseFL xxx +<+ unavailable_patches yyy)
-                                        :<: NilRL)
-                                        -- The above NilRL isn't quite
-                                        -- right, because ther *are*
-                                        -- earlier patches, but we
-                                        -- can't set this to undefined
-                                        -- because there are
-                                        -- situations where we look at
-                                        -- the rest.  :{
+              (x:ry) | isTag x ->
+                        Right $ Sealed (PatchSet
+                                        (reverseFL xxx +<+ unavailablePatches (reverse ry))
+                                        (Tagged (piUnavailable x) Nothing NilRL :<: NilRL))
+              _ -> Right $ Sealed (PatchSet (reverseFL xxx +<+ unavailablePatches yyy)
+                                   NilRL)
+                   -- The above NilRLs aren't quite right, because ther *are*
+                   -- earlier patches, but we can't set this to undefined
+                   -- because there are situations where we look at the rest.
+                   -- :{
 
-                                        -- bug "No more patches in patch bundle!")
-              _ -> Right $ Sealed ((reverseFL xxx +<+ unavailable_patches yyy)
-                                   :<: NilRL)
-
--- filter_gpg_dashes is needed because clearsigned patches escape dashes:
-filter_gpg_dashes :: B.ByteString -> B.ByteString
-filter_gpg_dashes ps =
+-- filterGpgDashes is needed because clearsigned patches escape dashes:
+filterGpgDashes :: B.ByteString -> B.ByteString
+filterGpgDashes ps =
     unlinesPS $ map drop_dashes $
     takeWhile (/= BC.pack "-----END PGP SIGNED MESSAGE-----") $
     dropWhile not_context_or_newpatches $ linesPS ps
@@ -148,14 +159,14 @@ filter_gpg_dashes ps =
           not_context_or_newpatches s = (s /= BC.pack "Context:") &&
                                         (s /= BC.pack "New patches:")
 
-unavailable_patches :: RepoPatch p => [PatchInfo] -> RL (PatchInfoAnd p) C(x y)
-unavailable_patches [] = unsafeCoerceP NilRL
-unavailable_patches (x:xs) = pi_unavailable x :<: unavailable_patches xs
+unavailablePatches :: RepoPatch p => [PatchInfo] -> RL (PatchInfoAnd p) C(x y)
+unavailablePatches [] = unsafeCoerceP NilRL
+unavailablePatches (x:xs) = piUnavailable x :<: unavailablePatches xs
 
-pi_unavailable :: RepoPatch p => PatchInfo -> PatchInfoAnd p C(x y)
-pi_unavailable i = (i `patchInfoAndPatch`
+piUnavailable :: RepoPatch p => PatchInfo -> PatchInfoAnd p C(x y)
+piUnavailable i = (i `patchInfoAndPatch`
                       unavailable ("Patch not stored in patch bundle:\n" ++
-                                   renderString (human_friendly i)))
+                                   renderString (humanFriendly i)))
 getContext :: B.ByteString -> ([PatchInfo],B.ByteString)
 getContext ps =
     case readPatchInfo ps of
@@ -165,50 +176,61 @@ getContext ps =
     Nothing -> ([],ps)
 (-:-) :: a C(x y) -> (Sealed (FL a C(y)),b) -> (Sealed (FL a C(x)),b)
 p -:- (Sealed ps, r) = (Sealed (p:>:ps), r)
-get_patches :: RepoPatch p => B.ByteString -> (Sealed (FL (PatchInfoAnd p) C(x)), B.ByteString)
-get_patches ps =
+getPatches :: RepoPatch p => B.ByteString -> (Sealed (FL (PatchInfoAnd p) C(x)), B.ByteString)
+getPatches ps =
     case readPatchInfo ps of
     Nothing -> (Sealed NilFL, ps)
     Just (pinfo,_) ->
         case readPatch ps of
         Nothing -> (Sealed NilFL, ps)
-        Just (Sealed p, r) -> (pinfo `piap` p) -:- get_patches r
-parse_patches :: RepoPatch p => B.ByteString -> Sealed (FL (PatchInfoAnd p) C(x))
-parse_patches ps =
+        Just (Sealed p, r) -> (pinfo `piap` p) -:- getPatches r
+parsePatches :: RepoPatch p => B.ByteString -> Sealed (FL (PatchInfoAnd p) C(x))
+parsePatches ps =
   case readPatchInfo ps of
   Nothing -> Sealed NilFL
   Just (pinfo,_) ->
     case readPatch ps of
     Nothing -> Sealed NilFL
-    Just (Sealed p, r) -> ((pinfo `piap` p) :>:) `mapSeal` parse_patches r
+    Just (Sealed p, r) -> ((pinfo `piap` p) :>:) `mapSeal` parsePatches r
 
-silly_lex :: B.ByteString -> (String, B.ByteString)
-silly_lex ps = (BC.unpack a, b)
+sillyLex :: B.ByteString -> (String, B.ByteString)
+sillyLex ps = (BC.unpack a, b)
     where
         (a, b) = BC.break (== '\n') (dropSpace ps)
 
 {-
-silly_lex ps = (BC.unpack $ BC.takeWhile (/='\n') ps', BC.dropWhile (/='\n') ps')
+sillyLex ps = (BC.unpack $ BC.takeWhile (/='\n') ps', BC.dropWhile (/='\n') ps')
     where
         ps' = dropSpace ps
 -}
 
-make_context :: [PatchInfo] -> Doc
-make_context common =
-    text ""
- $$ text "Context:"
- $$ text ""
- $$ (vcat $ map showPatchInfo $ common)
- $$ text ""
 
-scan_context :: RepoPatch p => B.ByteString -> PatchSet p C(x)
-scan_context ps
+contextPatches :: RepoPatch p => PatchSet p C(Origin x) -> FlippedSeal (RL (PatchInfoAnd p)) C(x)
+contextPatches set = case slightlyOptimizePatchset set of
+  PatchSet ps (Tagged t _ _ :<: _) -> flipSeal (ps +<+ (t :<: NilRL))
+  PatchSet ps NilRL -> flipSeal ps
+
+-- are the type witnesses sensible?
+scanContext :: RepoPatch p => B.ByteString -> PatchSet p C(Origin x)
+scanContext ps
   | B.null ps = error "Bad context!"
   | otherwise =
-    case silly_lex ps of
+    case sillyLex ps of
     ("Context:",rest) ->
         case getContext rest of
-        (cont, _) -> unavailable_patches cont :<: NilRL
+          (cont@(_:_), _) | isTag (last cont) ->
+            PatchSet (unavailablePatches $ init cont)
+                     (Tagged (piUnavailable $ last cont) Nothing NilRL :<: NilRL)
+          (cont, _) -> PatchSet (unavailablePatches cont) NilRL
     ("-----BEGIN PGP SIGNED MESSAGE-----",rest) ->
-            scan_context $ filter_gpg_dashes rest
-    (_,rest) -> scan_context rest
+            scanContext $ filterGpgDashes rest
+    (_,rest) -> scanContext rest
+
+
+patchFilename :: String -> String
+patchFilename the_summary = name ++ ".dpatch"
+    where name = map safeFileChar the_summary
+          safeFileChar c | isAlpha c = toLower c
+                         | isDigit c = c
+                         | isSpace c = '-'
+          safeFileChar _ = '_'
