@@ -23,13 +23,13 @@
 
 -- | Conflictor patches
 module Darcs.Patch.Real
-       ( RealPatch(..), prim2real, is_consistent, is_forward, is_duplicate,
+       ( RealPatch(..), prim2real, isConsistent, isForward, isDuplicate,
          pullCommon, mergeUnravelled ) where
 
 import Control.Monad ( mplus, liftM )
 import Data.List ( partition, nub )
 import Darcs.Patch.Prim ( Prim, FromPrim(..), ToFromPrim(..), Conflict(..), Effect(..),
-                          showPrim, FileNameFormat(NewFormat),
+                          showPrim, showPrimFL, FileNameFormat(NewFormat),
                           IsConflictedPrim(..), ConflictState(..) )
 import Darcs.Patch.Read ( readPrim )
 import Darcs.Patch.Patchy
@@ -37,16 +37,16 @@ import Darcs.Witnesses.Ordered
 --import Darcs.Patch.Read ()
 --import Darcs.Patch.Viewing ()
 --import Darcs.Patch.Apply ()
-import Darcs.Patch.Commute ( mangle_unravelled )
+import Darcs.Patch.Commute ( mangleUnravelled )
 import Darcs.Patch.Non ( Non(..), Nonable(..), unNon,
                          showNons, showNon, readNons, readNon,
                          add, addP, addPs, remP, remPs, remNons,
                          (*>), (>*), (*>>), (>>*) )
 import Darcs.Patch.Permutations ( commuteWhatWeCanFL, commuteWhatWeCanRL,
                                   genCommuteWhatWeCanRL,
-                                  removeRL, removeFL, remove_subsequenceFL )
+                                  removeRL, removeFL, removeSubsequenceFL )
 import qualified Data.ByteString.Char8 as BC ( ByteString, unpack )
-import Darcs.Patch.ReadMonads ( work, peek_input, my_lex )
+import Darcs.Patch.ReadMonads ( work, peekInput, myLex )
 import Darcs.Utils ( nubsort )
 import Darcs.Witnesses.Sealed ( FlippedSeal(..), Sealed(Sealed), mapSeal )
 import Darcs.Witnesses.Show
@@ -85,19 +85,19 @@ data RealPatch C(x y) where
     Conflictor :: [Non RealPatch C(x)] -> FL Prim C(x y) -> Non RealPatch C(x) -> RealPatch C(y x)
     InvConflictor :: [Non RealPatch C(x)] -> FL Prim C(x y) -> Non RealPatch C(x) -> RealPatch C(x y)
 
--- | 'is_duplicate' @p@ is ' @True@ if @p@ is either a  'Duplicate' or 'Etacilpud' patch
-is_duplicate :: RealPatch C(s y) -> Bool
-is_duplicate (Duplicate _) = True
-is_duplicate (Etacilpud _) = True
-is_duplicate _ = False
+-- | 'isDuplicate' @p@ is ' @True@ if @p@ is either a  'Duplicate' or 'Etacilpud' patch
+isDuplicate :: RealPatch C(s y) -> Bool
+isDuplicate (Duplicate _) = True
+isDuplicate (Etacilpud _) = True
+isDuplicate _ = False
 
 -- | This is only used for unit testing
-is_forward :: RealPatch C(s y) -> Maybe Doc
-is_forward p@(InvConflictor _ _ _) =
+isForward :: RealPatch C(s y) -> Maybe Doc
+isForward p@(InvConflictor _ _ _) =
     Just $ redText "An inverse conflictor" $$ showPatch p
-is_forward p@(Etacilpud _) =
+isForward p@(Etacilpud _) =
     Just $ redText "An inverse duplicate" $$ showPatch p
-is_forward _ = Nothing
+isForward _ = Nothing
 
 mergeUnravelled :: [Sealed ((FL Prim) C(x))] -> Maybe (FlippedSeal RealPatch C(x))
 mergeUnravelled [] = Nothing
@@ -124,7 +124,7 @@ mergeConflictingNons :: [Non RealPatch C(x)] -> Maybe (FL RealPatch C(x x))
 mergeConflictingNons ns = mcn $ map unNon ns
     where mcn :: [Sealed (FL RealPatch C(x))] -> Maybe (FL RealPatch C(x x))
           mcn [] = Just NilFL
-          mcn [Sealed p] = case join_effects p of -- this is just a safety check, and could
+          mcn [Sealed p] = case joinEffects p of -- this is just a safety check, and could
                            NilFL -> Just p                 -- be removed when we're sure of the code.
                            _ -> Nothing
           mcn (Sealed p1:Sealed p2:zs) = case pullCommon p1 p2 of
@@ -132,17 +132,17 @@ mergeConflictingNons ns = mcn $ map unNon ns
                                              case merge (ps :\/: qs) of
                                              qs' :/\: _ -> mcn (Sealed (c +>+ ps +>+ qs'):zs)
 
-join_effects :: Effect p => p C(x y) -> FL Prim C(x y)
-join_effects = join_inverses . effect
-    where join_inverses :: FL Prim C(x y) -> FL Prim C(x y)
-          join_inverses NilFL = NilFL
-          join_inverses (p:>:ps) = case removeFL (invert p) ps' of
+joinEffects :: Effect p => p C(x y) -> FL Prim C(x y)
+joinEffects = joinInverses . effect
+    where joinInverses :: FL Prim C(x y) -> FL Prim C(x y)
+          joinInverses NilFL = NilFL
+          joinInverses (p:>:ps) = case removeFL (invert p) ps' of
                                    Just ps'' -> ps''
                                    Nothing -> p :>: ps'
-              where ps' = join_inverses ps
+              where ps' = joinInverses ps
 
 assertConsistent :: RealPatch C(x y) -> RealPatch C(x y)
-assertConsistent x = assertDoc (do e <- is_consistent x
+assertConsistent x = assertDoc (do e <- isConsistent x
                                    Just (redText "Inconsistent patch:" $$ showPatch x $$ e)) x
 
 -- | @mergeAfterConflicting@ takes as input a sequence of conflicting
@@ -168,7 +168,7 @@ mergeAfterConflicting xxx yyy = --traceDoc (greenText "mergeAfterConflicting xxx
                                 mac (reverseFL xxx) yyy NilFL
     where mac :: RL RealPatch C(x y) -> FL Prim C(y z) -> FL RealPatch C(z a)
               -> Maybe (FL RealPatch C(x x), FL RealPatch C(x a))
-          mac NilRL xs goneby = case join_effects goneby of
+          mac NilRL xs goneby = case joinEffects goneby of
                                 NilFL -> Just (NilFL, mapFL_FL Normal xs)
                                 _z -> --traceDoc (greenText "mac1 z" $$ showPatch _z) $
                                       Nothing
@@ -176,27 +176,27 @@ mergeAfterConflicting xxx yyy = --traceDoc (greenText "mergeAfterConflicting xxx
                                    --          greenText "p" $$ showPatch p $$
                                    --          greenText "xs" $$ showPatch xs $$
                                    --          greenText "goneby" $$ showPatch goneby) $
-                                   case commuteFL (p :> mapFL_FL Normal xs) of
-                                   Left _  -> case genCommuteWhatWeCanRL commute_no_conflicts (ps :> p) of
+                                   case commuteFLorComplain (p :> mapFL_FL Normal xs) of
+                                   Left _  -> case genCommuteWhatWeCanRL commuteNoConflicts (ps :> p) of
                                               a:>p':>b ->
                                                   do (b',xs') <- mac b xs goneby
-                                                     let pa = join_effects $ p':<:a
+                                                     let pa = joinEffects $ p':<:a
                                                      --traceDoc (greenText "foo1" $$
                                                      --          showPatch pa) $ Just ()
                                                      NilFL <- return pa
                                                      return (reverseRL (p':<:a)+>+b', xs')
                                                    `mplus` do NilFL <- return goneby
-                                                              NilFL <- return $ join_effects (p:<:ps)
+                                                              NilFL <- return $ joinEffects (p:<:ps)
                                                               return (reverseRL (p:<:ps),
                                                                       mapFL_FL Normal xs)
                                    Right (l:>p'') ->
                                        case allNormal l of
                                        Just xs'' -> mac ps xs'' (p'':>:goneby)
                                        Nothing ->
-                                              case genCommuteWhatWeCanRL commute_no_conflicts (ps :> p) of
+                                              case genCommuteWhatWeCanRL commuteNoConflicts (ps :> p) of
                                               a:>p':>b ->
                                                   do (b',xs') <- mac b xs goneby
-                                                     let pa = join_effects $ p':<:a
+                                                     let pa = joinEffects $ p':<:a
                                                      --traceDoc (greenText "foo2" $$
                                                      --          showPatch pa) $ Just ()
                                                      NilFL <- return pa
@@ -235,53 +235,49 @@ allNormal NilFL = Just NilFL
 allNormal _ = Nothing
 
 -- | This is used for unit-testing and for internal sanity checks
-is_consistent :: RealPatch C(x y) -> Maybe Doc
-is_consistent (Normal _) = Nothing
-is_consistent (Duplicate _) = Nothing
-is_consistent (Etacilpud _) = Nothing
-is_consistent (Conflictor im mm m@(Non deps _))
-    | not $ everyone_conflicts im = Just $ redText "Someone doesn't conflict in im in is_consistent"
-    | Just _ <- remPs rmm m, _:>:_ <- mm = Just $ redText "m doesn't conflict with mm in is_consistent"
-    | any (\x -> any (x `conflicts_with`) nmm) im
-        = Just $ redText "mm conflicts with im in is_consistent where nmm is" $$
+isConsistent :: RealPatch C(x y) -> Maybe Doc
+isConsistent (Normal _) = Nothing
+isConsistent (Duplicate _) = Nothing
+isConsistent (Etacilpud _) = Nothing
+isConsistent (Conflictor im mm m@(Non deps _))
+    | not $ everyoneConflicts im = Just $ redText "Someone doesn't conflict in im in isConsistent"
+    | Just _ <- remPs rmm m, _:>:_ <- mm = Just $ redText "m doesn't conflict with mm in isConsistent"
+    | any (\x -> any (x `conflictsWith`) nmm) im
+        = Just $ redText "mm conflicts with im in isConsistent where nmm is" $$
                  showNons nmm
     | Nothing <- (nmm ++ im) `minus` toNons deps = Just $ redText "dependencies not in conflict:" $$
                                                    showNons (toNons deps) $$
                                                    redText "compared with deps itself:" $$
                                                    showPatch deps
-    | otherwise = case all_conflicts_with m im of
+    | otherwise = case allConflictsWith m im of
                   (im1,[]) | im1 `eqSet` im -> Nothing
-                  (_,imnc) -> Just $ redText "m doesn't conflict with im in is_consistent.  unconflicting:"
+                  (_,imnc) -> Just $ redText "m doesn't conflict with im in isConsistent.  unconflicting:"
                               $$ showNons imnc
     where (nmm, rmm) = geteff im mm
-is_consistent c@(InvConflictor _ _ _) = is_consistent (invert c)
+isConsistent c@(InvConflictor _ _ _) = isConsistent (invert c)
 
-everyone_conflicts :: [Non RealPatch C(x)] -> Bool
-everyone_conflicts [] = True
-everyone_conflicts (x:xs) = case all_conflicts_with x xs of
+everyoneConflicts :: [Non RealPatch C(x)] -> Bool
+everyoneConflicts [] = True
+everyoneConflicts (x:xs) = case allConflictsWith x xs of
                             ([],_) -> False
-                            (_,xs') -> everyone_conflicts xs'
+                            (_,xs') -> everyoneConflicts xs'
 
 prim2real :: Prim C(x y) -> RealPatch C(x y)
 prim2real = Normal
 
 instance Patchy RealPatch
 
-instance MyEq p => Eq (Sealed (p C(x))) where
-    (Sealed x) == (Sealed y) | IsEq <- x =\/= y = True
-                             | otherwise = False
-
-merge_with :: Non RealPatch C(x) -> [Non RealPatch C(x)] -> Sealed (FL Prim C(x))
-merge_with p [] = effect `mapSeal` unNon p
-merge_with p xs = mergeall $ map unNon $ (p:) $ unconflicting_of $
-                  filter (\x -> not (p `depends_upon` x) && not (p `conflicts_with` x)) xs
+mergeWith :: Non RealPatch C(x) -> [Non RealPatch C(x)] -> Sealed (FL Prim C(x))
+mergeWith p [] = effect `mapSeal` unNon p
+mergeWith p xs = mergeall $ map unNon $ (p:) $ unconflicting_of $
+                  filter (\x -> not (p `dependsUpon` x) && not (p `conflictsWith` x)) xs
     where mergeall :: [Sealed (FL RealPatch C(x))] -> Sealed (FL Prim C(x))
           mergeall [Sealed x] = Sealed $ effect x
           mergeall [] = Sealed NilFL
           mergeall (Sealed x:Sealed y:rest) = case merge (x :\/: y) of
                                               y' :/\: _ -> mergeall (Sealed (x+>+y'):rest)
           unconflicting_of [] = []
-          unconflicting_of (q:qs) = case all_conflicts_with q qs of
+          unconflicting_of (q:qs) = case allConflictsWith q qs of
                                     ([],_) -> q:qs
                                     (_,nc) -> unconflicting_of nc
 
@@ -291,8 +287,8 @@ instance Conflict RealPatch where
     conflictedEffect (Conflictor _ _ (Non _ x)) = [IsC Conflicted x]
     conflictedEffect (InvConflictor _ _ _) = impossible
     conflictedEffect (Normal x) = [IsC Okay x]
-    resolveConflicts (Conflictor ix xx x) = [mangle_unravelled unravelled : unravelled]
-            where unravelled = nub $ filter isn $ map (`merge_with` (x:ix++nonxx)) (x:ix++nonxx)
+    resolveConflicts (Conflictor ix xx x) = [mangleUnravelled unravelled : unravelled]
+            where unravelled = nub $ filter isn $ map (`mergeWith` (x:ix++nonxx)) (x:ix++nonxx)
                   nonxx = nonxx_ (nonxx_aux ix xx)
                   nonxx_aux :: [Non RealPatch C(x)] -> FL Prim C(x y) -> RL RealPatch C(x y)
                   nonxx_aux a b = reverseFL $ xx2patches a b
@@ -306,65 +302,66 @@ instance Conflict RealPatch where
     resolveConflicts _ = []
 
     -- cA
-    commute_no_conflicts (Duplicate x :> Duplicate y) = Just (Duplicate y :> Duplicate x)
-    commute_no_conflicts (Etacilpud x :> Duplicate y) = Just (Duplicate y :> Etacilpud x)
-    commute_no_conflicts (Duplicate x :> Etacilpud y) = Just (Etacilpud y :> Duplicate x)
-    commute_no_conflicts (Etacilpud x :> Etacilpud y) = Just (Etacilpud y :> Etacilpud x)
+    commuteNoConflicts (Duplicate x :> Duplicate y) = Just (Duplicate y :> Duplicate x)
+    commuteNoConflicts (Etacilpud x :> Duplicate y) = Just (Duplicate y :> Etacilpud x)
+    commuteNoConflicts (Duplicate x :> Etacilpud y) = Just (Etacilpud y :> Duplicate x)
+    commuteNoConflicts (Etacilpud x :> Etacilpud y) = Just (Etacilpud y :> Etacilpud x)
     -- cB
-    commute_no_conflicts (x :> Duplicate d) = if d == addP (invert x) (non x)
+    commuteNoConflicts (x :> Duplicate d) = if d == addP (invert x) (non x)
                                               then Just (x :> Duplicate d)
                                               else do d' <- remP (invert x) d
                                                       return (Duplicate d' :> x)
-    commute_no_conflicts (Duplicate d' :> x) = Just (x :> Duplicate (addP (invert x) d'))
-    commute_no_conflicts c@(Etacilpud _ :> _) = invertCommuteNC c
-    commute_no_conflicts c@(_ :> Etacilpud _) = invertCommuteNC c
+    commuteNoConflicts (Duplicate d' :> x) = Just (x :> Duplicate (addP (invert x) d'))
+    commuteNoConflicts c@(Etacilpud _ :> _) = invertCommuteNC c
+    commuteNoConflicts c@(_ :> Etacilpud _) = invertCommuteNC c
     -- cE
-    commute_no_conflicts (Normal x :> Normal y) = do y' :> x' <- commute (x :> y)
+    commuteNoConflicts (Normal x :> Normal y) =   do y' :> x' <- commute (x :> y)
                                                      return (Normal y' :> Normal x')
     -- cF -- involves a conflict
     -- cG
-    commute_no_conflicts (Normal x :> Conflictor iy yy y) =
-        case commuteFL (x :> invert yy) of
+    commuteNoConflicts (Normal x :> Conflictor iy yy y) =
+        case commuteFLorComplain (x :> invert yy) of
         Right (iyy' :> x') -> do
            y':iy' <- mapM (Normal x' >*) (y:iy)
            return (Conflictor iy' (invert iyy') y' :> Normal x')
         _ -> Nothing
     -- cFi+cGi  -- handle with previous two pattern matches
-    commute_no_conflicts c@(InvConflictor _ _ _ :> Normal _) = invertCommuteNC c
+    commuteNoConflicts c@(InvConflictor _ _ _ :> Normal _) = invertCommuteNC c
     -- icG FIXME: where is icF?
-    commute_no_conflicts (Conflictor iy' yy' y' :> Normal x') =
+    commuteNoConflicts (Conflictor iy' yy' y' :> Normal x') =
         do x :> iyy <- commuteRL (invertFL yy' :> x')
            y:iy <- mapM (*> Normal x') (y':iy')
            return (Normal x :> Conflictor iy (invertRL iyy) y)
     -- icGi      -- handle with previous pattern match
-    commute_no_conflicts c@(Normal _ :> InvConflictor _ _ _) = invertCommuteNC c
+    commuteNoConflicts c@(Normal _ :> InvConflictor _ _ _) = invertCommuteNC c
     -- cH -- this involves a conflict commute
     -- cI
-    commute_no_conflicts (Conflictor ix xx x :> Conflictor iy yy y) =
+    commuteNoConflicts (Conflictor ix xx x :> Conflictor iy yy y) =
         do xx' :> yy' <- commute (yy :> xx)
            x':ix' <- mapM (yy >>*) (x:ix)
            y':iy' <- mapM (*>> xx') (y:iy)
-           False <- return $ any (conflicts_with y) (x':ix')
-           False <- return $ any (conflicts_with x') iy
+           False <- return $ any (conflictsWith y) (x':ix')
+           False <- return $ any (conflictsWith x') iy
            return (Conflictor iy' yy' y' :> Conflictor ix' xx' x')
     -- cHi+cIi            uses previous two matches
-    commute_no_conflicts c@(InvConflictor _ _ _ :> InvConflictor _ _ _) = invertCommuteNC c
+    commuteNoConflicts c@(InvConflictor _ _ _ :> InvConflictor _ _ _) = invertCommuteNC c
     -- cJ
-    commute_no_conflicts (InvConflictor ix xx x :> Conflictor iy yy y) =
+    commuteNoConflicts (InvConflictor ix xx x :> Conflictor iy yy y) =
         do iyy' :> xx' <- commute (xx :> invert yy)
            y':iy' <- mapM (xx' >>*) (y:iy)
            x':ix' <- mapM (invertFL iyy' >>*) (x:ix)
-           False <- return $ any (conflicts_with y') (x':ix')
-           False <- return $ any (conflicts_with x') iy'
+           False <- return $ any (conflictsWith y') (x':ix')
+           False <- return $ any (conflictsWith x') iy'
            return (Conflictor iy' (invert iyy') y' :> InvConflictor ix' xx' x')
     -- icJ
-    commute_no_conflicts (Conflictor iy' yy' y' :> InvConflictor ix' xx' x') =
+    commuteNoConflicts (Conflictor iy' yy' y' :> InvConflictor ix' xx' x') =
         do xx :> iyy <- commute (invert yy' :> xx')
            y:iy <- mapM (*>> xx') (y':iy')
            x:ix <- mapM (*>> yy') (x':ix')
-           False <- return $ any (conflicts_with y') (x':ix')
-           False <- return $ any (conflicts_with x') iy'
+           False <- return $ any (conflictsWith y') (x':ix')
+           False <- return $ any (conflictsWith x') iy'
            return (InvConflictor ix xx x :> Conflictor iy (invert iyy) y)
+    isInconsistent = isConsistent
 
 instance FromPrim RealPatch where
     fromPrim = prim2real
@@ -468,14 +465,14 @@ instance Invert RealPatch where
 instance Commute RealPatch where
 --    commute (x :> y) | traceDoc (greenText "commuting x" $$ showPatch x $$
 --                                 greenText "with y" $$ showPatch y) False = undefined
-    commute (x :> y) | Just (y' :> x') <- commute_no_conflicts (assertConsistent x :> assertConsistent y) = Just (y' :> x')
+    commute (x :> y) | Just (y' :> x') <- commuteNoConflicts (assertConsistent x :> assertConsistent y) = Just (y' :> x')
     -- cF
     commute (Normal x :> Conflictor a1'nop2 n1'x p1') -- these patches conflicted
         | Just rn1' <- removeRL x (reverseFL n1'x) =
                       do let p2:n1nons = reverse $ xx2nons a1'nop2 $ reverseRL (x:<:rn1')
                              a2 = p1':a1'nop2++n1nons
                          case (a1'nop2, reverseRL rn1', p1') of
-                           ([], NilFL, Non c y) | NilFL <- join_effects c ->
+                           ([], NilFL, Non c y) | NilFL <- joinEffects c ->
                                     Just (Normal y :> Conflictor a1'nop2 (y:>:NilFL) p2)
                            (a1,n1,_) -> Just (Conflictor a1 n1 p1' :> Conflictor a2 NilFL p2)
     -- cFi  -- handle with previous pattern match
@@ -483,7 +480,7 @@ instance Commute RealPatch where
     -- cH
     commute (Conflictor a1 n1 p1 :> Conflictor a2 n2 p2)
         | Just a2_minus_p1 <- remove1 p1' a2,
-          not (p2 `depends_upon` p1') =
+          not (p2 `dependsUpon` p1') =
               do let n1nons = map (add n2) $ xx2nons a1 n1
                      n2nons = xx2nons a2 n2
                      Just a2_minus_p1n1 = a2_minus_p1 `minus` n1nons
@@ -501,7 +498,7 @@ instance Commute RealPatch where
                                  --          showPatch (assertConsistent $ Conflictor a2 n2 p2) $$
                                  --          greenText "where n2'nons is" $$ showNons n2'nons $$
                                  --          greenText "and others are" $$
-                                 --          showNons (fst $ all_conflicts_with p2 $ a2_minus_p1++n2nons) $$
+                                 --          showNons (fst $ allConflictsWith p2 $ a2_minus_p1++n2nons) $$
                                  --          greenText "These came from" $$
                                  --          showNons (a2_minus_p1++n2nons) $$
                                  --          greenText "n1'n2'nons" $$ showNons n1'n2'nons $$
@@ -511,14 +508,14 @@ instance Commute RealPatch where
                                  --          greenText "p2 fixed" $$ showNon p2ooo $$
                                  --          -- greenText "pren1" $$ showPatch pren1 $$
                                  --          greenText "n1'" $$ showPatch n1' $$
-                                 --          greenText "p2" $$ showNon p2 
-                                 --         ) 
-                                 (fst $ all_conflicts_with p2 $ a2_minus_p1++n2nons) `minus` n2'nons
+                                 --          greenText "p2" $$ showNon p2
+                                 --         )
+                                 (fst $ allConflictsWith p2 $ a2_minus_p1++n2nons) `minus` n2'nons
                      Just a2' = mapM (remPs (xx2patches a1'nop2 n1')) $
                                 a2'o
                      Just p2' = remPs (xx2patches a1'nop2 n1') p2
                  case (a2', n2', p2') of
-                   ([], NilFL, Non c x) | NilFL <- join_effects c ->
+                   ([], NilFL, Non c x) | NilFL <- joinEffects c ->
                                           Just (Normal x :> Conflictor a1'nop2 (n1'+>+x:>:NilFL) p1')
                                         | otherwise -> impossible
                    _ -> Just (Conflictor a2' n2' p2' :> Conflictor (p2:a1'nop2) n1' p1')
@@ -610,42 +607,42 @@ instance Commute RealPatch where
     hunkMatches f (InvConflictor x c p) = or [or $ map (nonHunkMatches f) x, hunkMatches f c, nonHunkMatches f p]
 
 {-
-all_conflicts_withFL :: FL Prim C(x y) -> [Non RealPatch C(x)]
+allConflictsWithFL :: FL Prim C(x y) -> [Non RealPatch C(x)]
                      -> ([Non RealPatch C(x)], [Non RealPatch C(x)])
-all_conflicts_withFL xx ns = case partition f ns of
+allConflictsWithFL xx ns = case partition f ns of
                              ([],nc) -> ([],nc)
                              (c,nc) -> case acw c nc of
                                        (c',nc') -> (c++c',nc')
-    where acw (y:ys) zs = case all_conflicts_with y zs of
+    where acw (y:ys) zs = case allConflictsWith y zs of
                           (c,nc) -> case acw ys nc of
                                     (c',nc') -> (c++c',nc')
           acw [] zs = ([],zs)
           f (Non c p) = case commuteRLFL (invertFL c :> mapFL_FL Normal xx) of
                         Nothing -> True
-                        Just (xx' :> _) -> case commuteFL (Normal (invert p) :> xx') of
+                        Just (xx' :> _) -> case commuteFLorComplain (Normal (invert p) :> xx') of
                                            Nothing -> True
                                            Just _ -> False
 -}
-all_conflicts_with :: Non RealPatch C(x) -> [Non RealPatch C(x)]
+allConflictsWith :: Non RealPatch C(x) -> [Non RealPatch C(x)]
                    -> ([Non RealPatch C(x)], [Non RealPatch C(x)])
-all_conflicts_with x ys = acw $ partition (conflicts_with x) ys
+allConflictsWith x ys = acw $ partition (conflictsWith x) ys
     where acw ([],nc) = ([],nc)
-          acw (c:cs, nc) = case all_conflicts_with c nc of
+          acw (c:cs, nc) = case allConflictsWith c nc of
                            (c1,nc1) -> case acw (cs, nc1) of
                                        (xs',nc') -> (c:c1++xs',nc')
 
-conflicts_with :: Non RealPatch C(x) -> Non RealPatch C(x) -> Bool
-conflicts_with x y | x `depends_upon` y || y `depends_upon` x = False
-conflicts_with x (Non cy y) =
+conflictsWith :: Non RealPatch C(x) -> Non RealPatch C(x) -> Bool
+conflictsWith x y | x `dependsUpon` y || y `dependsUpon` x = False
+conflictsWith x (Non cy y) =
     case remPs cy x of
-    Just (Non cx' x') -> case commuteFL (fromPrim (invert y) :> cx' +>+ fromPrim x' :>: NilFL) of
+    Just (Non cx' x') -> case commuteFLorComplain (fromPrim (invert y) :> cx' +>+ fromPrim x' :>: NilFL) of
                          Right _ -> False
                          Left _ -> True
     Nothing -> True
 
-depends_upon :: Non RealPatch C(x) -> Non RealPatch C(x) -> Bool
-depends_upon (Non xs _) (Non ys y) =
-    case remove_subsequenceFL (ys +>+ fromPrim y :>: NilFL) xs of
+dependsUpon :: Non RealPatch C(x) -> Non RealPatch C(x) -> Bool
+dependsUpon (Non xs _) (Non ys y) =
+    case removeSubsequenceFL (ys +>+ fromPrim y :>: NilFL) xs of
     Just _ -> True
     Nothing -> False
 
@@ -663,7 +660,7 @@ invertCommute (x :> y) = do ix' :> iy' <- commute (invert y :> invert x)
                             return (invert iy' :> invert ix')
 
 invertCommuteNC :: (RealPatch :> RealPatch) C(x y) -> Maybe ((RealPatch :> RealPatch) C(x y))
-invertCommuteNC (x :> y) = do ix' :> iy' <- commute_no_conflicts (invert y :> invert x)
+invertCommuteNC (x :> y) = do ix' :> iy' <- commuteNoConflicts (invert y :> invert x)
                               return (invert iy' :> invert ix')
 
 -- | 'pullCommon' @xs ys@ returns the set of patches that can be commuted
@@ -713,14 +710,14 @@ instance ShowPatch RealPatch where
         blueText "conflictor" <+> showNons i <+> blueText "[]" $$ showNon p
     showPatch (Conflictor i cs p) =
         blueText "conflictor" <+> showNons i <+> blueText "[" $$
-        showPatch cs $$
+        showPrimFL NewFormat cs $$
         blueText "]" $$
         showNon p
     showPatch (InvConflictor i NilFL p) =
         blueText "rotcilfnoc" <+> showNons i <+> blueText "[]" $$ showNon p
     showPatch (InvConflictor i cs p) =
         blueText "rotcilfnoc" <+> showNons i <+> blueText "[" $$
-        showPatch cs $$
+        showPrimFL NewFormat cs $$
         blueText "]" $$
         showNon p
     showContextPatch (Normal p) = showContextPatch p
@@ -728,29 +725,29 @@ instance ShowPatch RealPatch where
 
 instance ReadPatch RealPatch where
  readPatch' _ =
-     do s <- peek_input
-        case fmap (BC.unpack . fst) $ my_lex s of
+     do s <- peekInput
+        case fmap (BC.unpack . fst) $ myLex s of
           Just "duplicate" ->
-              do work my_lex
+              do work myLex
                  p <- readNon
                  return $ (Sealed . Duplicate) `fmap` p
           Just "etacilpud" ->
-              do work my_lex
+              do work myLex
                  p <- readNon
                  return $ (Sealed . Etacilpud) `fmap` p
           Just "conflictor" ->
-              do work my_lex
-                 --let tracePeek x = do y <- peek_input
+              do work myLex
+                 --let tracePeek x = do y <- peekInput
                  --                     traceDoc (greenText x $$ greenText (show $ BC.unpack y)) return ()
                  i <- readNons
-                 Just (Sealed ps) <- bracketedFL (fromIntegral $ fromEnum '[') (fromIntegral $ fromEnum ']')
+                 Just (Sealed ps) <- bracketedFL (readPrim NewFormat) (fromIntegral $ fromEnum '[') (fromIntegral $ fromEnum ']')
 
                  Just p <- readNon
                  return $ Just $ Sealed $ Conflictor i (unsafeCoerceP ps) p
           Just "rotcilfnoc" ->
-              do work my_lex
+              do work myLex
                  i <- readNons
-                 Just (Sealed ps) <- bracketedFL (fromIntegral $ fromEnum '[') (fromIntegral $ fromEnum ']')
+                 Just (Sealed ps) <- bracketedFL (readPrim NewFormat) (fromIntegral $ fromEnum '[') (fromIntegral $ fromEnum ']')
                  Just p <- readNon
                  return $ Just $ Sealed $ InvConflictor i ps p
           _ -> do mp <- readPrim NewFormat
@@ -762,7 +759,7 @@ instance Show (RealPatch C(x y)) where
     show p = renderString $ showPatch p
 
 instance Show2 RealPatch where
-    show2 = show
+    showDict2 = ShowDictClass
 
 instance Nonable RealPatch where
     non (Duplicate d) = d
