@@ -103,7 +103,7 @@ getPopFrom the_directory pinfo =
           then do
            fnames <- getDirectoryContents dirname
            sl <- withCurrentDirectory dirname
-                 (mapM getPopFrom_helper $ filter not_hidden fnames)
+                 (mapM getPopFrom_helper $ filter notHidden fnames)
            let i = Info {nameI = n,
                          modifiedByI = pinfo,
                          modifiedHowI = DullDir,
@@ -117,7 +117,7 @@ getPopFrom the_directory pinfo =
                                 creationNameI = Just n}
                   return $ PopFile i
 
-not_hidden :: FilePath -> Bool
-not_hidden ('.':_) = False
-not_hidden ('_':_) = False
-not_hidden _ = True
+notHidden :: FilePath -> Bool
+notHidden ('.':_) = False
+notHidden ('_':_) = False
+notHidden _ = True
