@@ -7,17 +7,20 @@ module Darcs.Repository.Cache (
                    cacheHash, okayHash, takeHash,
                    Cache(..), CacheType(..), CacheLoc(..), WritableOrNot(..),
                    HashedDir(..), hashedDir,
-                   unionCaches, cleanCaches, cleanCachesWithHint,
-                   fetchFileUsingCache, speculateFileUsingCache, writeFileUsingCache,
+                   unionCaches, unionRemoteCaches, cleanCaches, cleanCachesWithHint,
+                   fetchFileUsingCache, speculateFileUsingCache, speculateFilesUsingCache,
+                   writeFileUsingCache,
                    peekInCache,
                    repo2cache,
-                   writable, isthisrepo, hashedFilePath, allHashedDirs
+                   writable, isthisrepo, hashedFilePath, allHashedDirs, compareByLocality
                  ) where
 
-import Control.Monad ( liftM, when, guard )
+import Control.Monad ( liftM, when, guard, unless, filterM, forM_ )
 import Data.List ( nub )
-import Data.Maybe ( listToMaybe )
-import System.Directory ( removeFile, doesFileExist, getDirectoryContents )
+import Data.Maybe ( catMaybes, listToMaybe )
+import System.Directory ( removeFile, doesFileExist, doesDirectoryExist,
+                          getDirectoryContents, getPermissions )
+import qualified System.Directory as SD ( writable )
 import System.Posix.Files ( linkCount, getSymbolicLinkStatus )
 import System.IO ( hPutStrLn, stderr )
 
@@ -37,7 +40,7 @@ import Darcs.Flags ( Compression( .. ) )
 import Darcs.Global ( darcsdir )
 import Darcs.Lock ( writeAtomicFilePS, gzWriteAtomicFilePS )
 import Progress ( progressList, debugMessage, debugFail )
-import Darcs.URL ( is_file )
+import Darcs.URL ( isFile, isUrl, isSsh )
 import Darcs.Utils ( withCurrentDirectory, catchall )
 
 data HashedDir = HashedPristineDir | HashedPatchesDir | HashedInventoriesDir
@@ -69,6 +72,54 @@ instance Show Cache where
 unionCaches :: Cache -> Cache -> Cache
 unionCaches (Ca a) (Ca b) = Ca (nub (a++b))
 
+-- | unionRemoteCaches merges caches. It tries to do better than just blindly
+--   copying remote cache entries:
+--
+--   * If remote repository is accessed through network, do not copy any cache
+--     entries from it. Taking local entries does not make sense and using
+--     network entries can lead to darcs hang when it tries to get to
+--     unaccessible host.
+--
+--   * If remote repositoty is local, copy all network cache entries. For local
+--     cache entries if the cache directory exists and is writable it is added
+--     as writable cache, if it exists but is not writable it is added as
+--     read-only cache.
+--
+--   This approach should save us from bogus cache entries. One case it does not
+--   work very well is when you fetch from partial repository over network.
+--   Hopefully this is not a common case.
+unionRemoteCaches :: Cache -> Cache -> String -> IO (Cache)
+unionRemoteCaches local (Ca remote) repourl
+    | isFile repourl =  do f <- filtered
+                           return $ local `unionCaches` Ca f
+    | otherwise = return local
+  where filtered = mapM (\x -> fn x `catchall` return Nothing) remote >>=
+                   return . catMaybes
+        fn :: CacheLoc -> IO (Maybe CacheLoc)
+        fn (Cache Repo Writable _) = return Nothing
+        fn c@(Cache t _ url)
+          | isFile url = do
+              ex <- doesDirectoryExist url
+              if ex then do p <- getPermissions url
+                            return $ Just $
+                              if writable c && SD.writable p
+                              then c else Cache t NotWritable url
+                    else return Nothing
+          | otherwise = return $ Just c
+
+-- | Compares two caches, a remote cache is greater than a local one.
+-- The order of the comparison is given by: local < http < ssh
+compareByLocality :: CacheLoc -> CacheLoc -> Ordering
+compareByLocality (Cache _ _  x) (Cache _ _ y)
+  | isLocal x &&  isRemote y  = LT
+  | isRemote x && isLocal y = GT
+  | isUrl x && isSsh y = LT
+  | isSsh x && isUrl y = GT
+  | otherwise = EQ
+    where
+      isRemote r= isUrl r || isSsh r
+      isLocal = isFile
+
 repo2cache :: String -> Cache
 repo2cache r = Ca [Cache Repo NotWritable r]
 
@@ -132,6 +183,16 @@ speculateFileUsingCache :: Cache -> HashedDir -> String -> IO ()
 speculateFileUsingCache c sd h = do debugMessage $ "Speculating on "++h
                                     copyFileUsingCache OnlySpeculate c sd h
 
+-- | Note that the files are likely to be useful soon: pipelined downloads will
+-- add them to the (low-priority) queue, for the rest it is a noop.
+speculateFilesUsingCache :: Cache -> HashedDir -> [String] -> IO ()
+speculateFilesUsingCache _ _ [] = return ()
+speculateFilesUsingCache cache sd hs =
+    do --debugMessage $ "Thinking about speculating on "++unwords hs
+       hs' <- filterM (fmap not . peekInCache cache sd) hs
+       unless (null hs') $ do debugMessage $ "Speculating on "++unwords hs'
+                              copyFilesUsingCache OnlySpeculate cache sd hs'
+
 data OrOnlySpeculate = ActuallyCopy | OnlySpeculate deriving ( Eq )
 
 copyFileUsingCache :: OrOnlySpeculate -> Cache -> HashedDir -> String -> IO ()
@@ -157,6 +218,10 @@ copyFileUsingCache oos (Ca cache) subdir f =
                           | otherwise = sfuc cs out
           fn c = hashedFilePath c subdir f
 
+copyFilesUsingCache :: OrOnlySpeculate -> Cache -> HashedDir -> [String] -> IO ()
+copyFilesUsingCache oos cache subdir hs =
+    do forM_ hs $ copyFileUsingCache oos cache subdir
+
 
 data FromWhere = LocalOnly | Anywhere deriving ( Eq )
 
@@ -167,7 +232,7 @@ fetchFileUsingCachePrivate fromWhere (Ca cache) subdir f =
     `catchall` debugFail ("Couldn't fetch `"++f++"'\nin subdir "++(hashedDir subdir)++
                           " from sources:\n\n"++show (Ca cache))
     where ffuc (c:cs)
-           | not (writable c) && (Anywhere == fromWhere || is_file (fn c)) =
+           | not (writable c) && (Anywhere == fromWhere || isFile (fn c)) =
               do debugMessage $ "In fetchFileUsingCachePrivate I'm going manually"
                  debugMessage $ "    getting "++f
                  debugMessage $ "    from " ++ fn c
