@@ -23,7 +23,6 @@
 
 module Darcs.Repository.Pristine ( Pristine, flagsToPristine, nopristine,
                  createPristine, removePristine, identifyPristine,
-                 slurpPristine,
                  applyPristine, createPristineFromWorking,
                  getPristinePop,
                  pristineDirectory, pristineToFlagString,
@@ -34,9 +33,7 @@ module Darcs.Repository.Pristine ( Pristine, flagsToPristine, nopristine,
 import Data.Maybe ( isJust )
 import Control.Monad ( when, liftM )
 import System.Directory ( createDirectory, doesDirectoryExist, doesFileExist, removeFile )
-import Darcs.Lock ( rm_recursive, writeBinFile )
-import Workaround ( getCurrentDirectory )
-import Darcs.SlurpDirectory ( Slurpy,  mmap_slurp )
+import Darcs.Lock ( rmRecursive, writeBinFile )
 
 import Darcs.PopulationData ( Population, getPopFrom )
 import Darcs.Flags ( DarcsFlag( PristinePlain, PristineNone ) )
@@ -46,12 +43,12 @@ import Darcs.IO ( WriteableDirectory(mWithCurrentDirectory) )
 import Darcs.Patch ( Patchy, apply )
 import Darcs.Patch.Info ( PatchInfo )
 import Darcs.Patch.FileName ( fp2fn )
-import qualified Data.ByteString as B (empty)
 import Darcs.RepoPath ( FilePathLike, toFilePath )
-import SHA1 ( sha1PS )
 import Darcs.External ( cloneTree, cloneTreeExcept, clonePartialsTree )
 import Darcs.Repository.InternalTypes ( Pristine(..) )
 import Darcs.Global ( darcsdir )
+import Storage.Hashed.Darcs( writeDarcsHashed )
+import Storage.Hashed.Tree( emptyTree )
 #include "impossible.h"
 
 nopristine :: Pristine
@@ -67,7 +64,7 @@ identifyPristine = do mp <- reallyIdentifyPristine
                           Just pristine -> return pristine
 
 reallyIdentifyPristine :: IO (Maybe Pristine)
-reallyIdentifyPristine = 
+reallyIdentifyPristine =
     do dir <- findpristine doesDirectoryExist ""
        none <- findpristine doesFileExist ".none"
        hashinv <- doesFileExist $ darcsdir++"/hashed_inventory"
@@ -100,14 +97,15 @@ flagsToPristine (_ : t) rf = flagsToPristine t rf
 flagsToPristine [] rf = flagsToPristine [PristinePlain] rf
 
 createPristine :: Pristine -> IO Pristine
-createPristine p = 
+createPristine p =
     do oldpristine <- reallyIdentifyPristine
        when (isJust oldpristine) $ fail "Pristine tree already exists."
        case p of
            NoPristine n -> writeBinFile n "Do not delete this file.\n"
            PlainPristine n -> createDirectory n
            HashedPristine -> do createDirectory hashedPristineDirectory
-                                writeFile (hashedPristineDirectory++"/"++sha1PS B.empty) ""
+                                writeDarcsHashed emptyTree "_darcs/pristine.hashed"
+                                return ()
        return p
 
 hashedPristineDirectory :: String
@@ -115,16 +113,8 @@ hashedPristineDirectory = darcsdir++"/pristine.hashed"
 
 removePristine :: Pristine -> IO ()
 removePristine (NoPristine n) = removeFile n
-removePristine (PlainPristine n) = rm_recursive n
-removePristine HashedPristine = rm_recursive hashedPristineDirectory
-
-slurpPristine :: Pristine -> IO (Maybe Slurpy)
-slurpPristine (PlainPristine n) = do cwd <- getCurrentDirectory
-                                     slurpy <- mmap_slurp (cwd ++ "/" ++ n)
-                                     return (Just slurpy)
-slurpPristine (NoPristine _) = return Nothing
-slurpPristine HashedPristine =
-    bug "HashedPristine is not implemented yet."
+removePristine (PlainPristine n) = rmRecursive n
+removePristine HashedPristine = rmRecursive hashedPristineDirectory
 
 applyPristine :: Patchy p => Pristine -> p C(x y) -> IO ()
 applyPristine (NoPristine _) _ = return ()
