@@ -1,10 +1,10 @@
 {-# OPTIONS_GHC -cpp #-}
-{-# LANGUAGE CPP #-}
+{-# LANGUAGE CPP, PatternGuards #-}
 
 module Darcs.Repository.Repair ( replayRepository, checkIndex
                                , RepositoryConsistency(..) )
        where
-       
+
 import Control.Monad ( when, unless )
 import Control.Monad.Trans ( liftIO )
 import Control.Applicative( (<$>) )
@@ -13,24 +13,30 @@ import Data.Maybe ( catMaybes )
 import Data.List ( sort, (\\) )
 import System.Directory ( createDirectoryIfMissing )
 
-import Darcs.Lock( rm_recursive )
-import Darcs.Hopefully ( PatchInfoAnd, info )
+import Darcs.Lock( rmRecursive )
+import Darcs.Hopefully ( PatchInfoAnd, info, winfo, WPatchInfo, unWPatchInfo, compareWPatchInfo )
 
-import Darcs.Witnesses.Ordered ( FL(..), RL(..), lengthFL, reverseFL, reverseRL, concatRL,
-                     mapRL )
+import Darcs.Witnesses.Ordered ( FL(..), RL(..), lengthFL, reverseFL,
+                                 mapRL, nullFL, (:||:)(..), EqCheck(..) )
+import Darcs.Witnesses.Sealed ( Sealed2(..), Sealed(..), unFreeLeft )
 import Darcs.Patch.Patchy ( applyAndTryToFix )
-import Darcs.Patch.Info ( PatchInfo( .. ), human_friendly )
-import Darcs.Patch.Set ( PatchSet )
-import Darcs.Patch ( RepoPatch )
+import Darcs.Hopefully( hopefully )
+import Darcs.Patch.Info ( humanFriendly )
+import Darcs.Patch.Set ( PatchSet(..), newset2FL, newset2RL )
+#ifdef GADT_WITNESSES
+import Darcs.Patch.Set ( Origin )
+#endif
+import Darcs.Patch ( RepoPatch, isInconsistent )
+import Darcs.Patch.Core ( patchcontents )
 
-import Darcs.Repository.Format ( identifyRepoFormat, 
+import Darcs.Repository.Format ( identifyRepoFormat,
                                  RepoProperty ( HashedInventory ), formatHas )
 import Darcs.Repository.Cache ( HashedDir( HashedPristineDir ) )
-import Darcs.Repository.HashedIO ( clean_hashdir )
+import Darcs.Repository.HashedIO ( cleanHashdir )
 import Darcs.Repository.HashedRepo ( readHashedPristineRoot )
 import Darcs.Repository.InternalTypes ( extractCache )
 import Darcs.Repository.Prefs ( filetypeFunction )
-import Darcs.Repository ( Repository, read_repo, makePatchLazy
+import Darcs.Repository ( Repository, readRepo, makePatchLazy
                         , readRecorded, readIndex, readRecordedAndPending )
 
 import Progress ( debugMessage, beginTedious, endTedious, tediousSize, finishedOneIO )
@@ -53,83 +59,86 @@ import Storage.Hashed( readPlainTree )
 import qualified Data.ByteString.Char8 as BS
 
 #include "impossible.h"
+#include "gadts.h"
 
-replaceInFL :: FL (PatchInfoAnd a)
-            -> [(PatchInfo, PatchInfoAnd a)]
-            -> FL (PatchInfoAnd a)
+replaceInFL :: FL (PatchInfoAnd a) C(x y)
+            -> [Sealed2 (WPatchInfo :||: PatchInfoAnd a)]
+            -> FL (PatchInfoAnd a) C(x y)
 replaceInFL orig [] = orig
 replaceInFL NilFL _ = impossible
-replaceInFL (o:>:orig) ch@((o',c):ch_rest)
-    | info o == o' = c:>:replaceInFL orig ch_rest
+replaceInFL (o:>:orig) ch@(Sealed2 (o':||:c):ch_rest)
+    | IsEq <- winfo o `compareWPatchInfo` o' = c:>:replaceInFL orig ch_rest
     | otherwise = o:>:replaceInFL orig ch
 
-applyAndFix :: forall p. RepoPatch p => Repository p -> FL (PatchInfoAnd p) -> TreeIO (FL (PatchInfoAnd p), Bool)
+applyAndFix :: forall p C(r u t x y). RepoPatch p => Repository p C(r u t) -> FL (PatchInfoAnd p) C(Origin r) -> TreeIO (FL (PatchInfoAnd p) C(Origin r), Bool)
 applyAndFix _ NilFL = return (NilFL, True)
 applyAndFix r psin =
     do liftIO $ beginTedious k
        liftIO $ tediousSize k $ lengthFL psin
        (repaired, ok) <- aaf psin
        liftIO $ endTedious k
-       orig <- liftIO $ (reverseRL . concatRL) `fmap` read_repo r
+       orig <- liftIO $ newset2FL `fmap` readRepo r
        return (replaceInFL orig repaired, ok)
     where k = "Replaying patch"
-          aaf :: FL (PatchInfoAnd p) -> TreeIO ([(PatchInfo, PatchInfoAnd p)], Bool)
+          aaf :: FL (PatchInfoAnd p) C(w z) -> TreeIO ([Sealed2 (WPatchInfo :||: PatchInfoAnd p)], Bool)
           aaf NilFL = return ([], True)
           aaf (p:>:ps) = do
             mp' <- applyAndTryToFix p
-            let !infp = info p -- assure that 'p' can be garbage collected.
-            liftIO $ finishedOneIO k $ show $ human_friendly $ infp
+            case isInconsistent . patchcontents . hopefully $ p of
+              Just err -> liftIO $ putDocLn err
+              Nothing -> return ()
+            let !winfp = winfo p -- assure that 'p' can be garbage collected.
+            liftIO $ finishedOneIO k $ show $ humanFriendly $ unWPatchInfo winfp
             (ps', restok) <- aaf ps
             case mp' of
               Nothing -> return (ps', restok)
               Just (e,pp) -> do liftIO $ putStrLn e
                                 p' <- liftIO $ makePatchLazy r pp
-                                return ((infp, p'):ps', False)
+                                return (Sealed2 (winfp :||: p'):ps', False)
 
-data RepositoryConsistency p =
+data RepositoryConsistency p C(x) =
     RepositoryConsistent
   | BrokenPristine (Tree IO)
-  | BrokenPatches (Tree IO) (PatchSet p)
+  | BrokenPatches (Tree IO) (PatchSet p C(Origin x))
 
-check_uniqueness :: RepoPatch p => (Doc -> IO ()) -> (Doc -> IO ()) -> Repository p -> IO ()
-check_uniqueness putVerbose putInfo repository =
+checkUniqueness :: RepoPatch p => (Doc -> IO ()) -> (Doc -> IO ()) -> Repository p C(r u t) -> IO ()
+checkUniqueness putVerbose putInfo repository =
     do putVerbose $ text "Checking that patch names are unique..."
-       r <- read_repo repository
-       case has_duplicate $ mapRL info $ concatRL r of
+       r <- readRepo repository
+       case hasDuplicate $ mapRL info $ newset2RL r of
          Nothing -> return ()
          Just pinf -> do putInfo $ text "Error! Duplicate patch name:"
-                         putInfo $ human_friendly pinf
+                         putInfo $ humanFriendly pinf
                          fail "Duplicate patches found."
 
-has_duplicate :: Ord a => [a] -> Maybe a
-has_duplicate li = hd $ sort li
+hasDuplicate :: Ord a => [a] -> Maybe a
+hasDuplicate li = hd $ sort li
     where hd [_] = Nothing
           hd [] = Nothing
           hd (x1:x2:xs) | x1 == x2 = Just x1
                         | otherwise = hd (x2:xs)
-replayRepository' :: (RepoPatch p) => Repository p -> [DarcsFlag] -> IO (RepositoryConsistency p)
+replayRepository' :: (RepoPatch p)
+                  => Repository p C(r u t) -> [DarcsFlag] -> IO (RepositoryConsistency p C(r))
 replayRepository' repo opts = do
   let putVerbose s = when (Verbose `elem` opts) $ putDocLn s
       putInfo s = when (not $ Quiet `elem` opts) $ putDocLn s
-  check_uniqueness putVerbose putInfo repo
+  checkUniqueness putVerbose putInfo repo
   createDirectoryIfMissing False $ darcsdir ++ "/pristine.hashed"
   putVerbose $ text "Reading recorded state..."
   pris <- readRecorded repo `catch` \_ -> return emptyTree
   putVerbose $ text "Applying patches..."
-  patches <- read_repo repo
+  patches <- readRepo repo
   debugMessage "Fixing any broken patches..."
-  let psin = reverseRL $ concatRL patches
+  let psin = newset2FL patches
       repair = applyAndFix repo psin
   ((ps, patches_ok), newpris) <- hashedTreeIO repair emptyTree "_darcs/pristine.hashed"
   debugMessage "Done fixing broken patches..."
-  let newpatches = reverseFL ps :<: NilRL
+  let newpatches = PatchSet (reverseFL ps) NilRL
 
   debugMessage "Checking pristine against slurpy"
   ftf <- filetypeFunction
-  is_same <- do diff <- treeDiff ftf pris newpris
-                return $ case diff of
-                           NilFL -> True
-                           _ -> False
+  is_same <- do Sealed diff <- unFreeLeft `fmap` treeDiff ftf pris newpris
+                return $ nullFL diff
               `catchall` return False
   -- TODO is the latter condition needed? Does a broken patch imply pristine
   -- difference? Why, or why not?
@@ -139,25 +148,25 @@ replayRepository' repo opts = do
             then BrokenPristine newpris
             else BrokenPatches newpris newpatches)
 
-cleanupRepositoryReplay :: Repository p -> IO ()
+cleanupRepositoryReplay :: Repository p C(r u t) -> IO ()
 cleanupRepositoryReplay r = do
   let c = extractCache r
   rf_or_e <- identifyRepoFormat "."
   rf <- case rf_or_e of Left e -> fail e
                         Right x -> return x
   unless (formatHas HashedInventory rf) $
-         rm_recursive $ darcsdir ++ "/pristine.hashed" 
+         rmRecursive $ darcsdir ++ "/pristine.hashed"
   when (formatHas HashedInventory rf) $ do
        current <- readHashedPristineRoot r
-       clean_hashdir c HashedPristineDir $ catMaybes [current]
+       cleanHashdir c HashedPristineDir $ catMaybes [current]
 
-replayRepository :: (RepoPatch p) => Repository p -> [DarcsFlag] -> (RepositoryConsistency p -> IO a) -> IO a
+replayRepository :: (RepoPatch p) => Repository p C(r u t) -> [DarcsFlag] -> (RepositoryConsistency p C(r) -> IO a) -> IO a
 replayRepository r opt f = run `finally` cleanupRepositoryReplay r
     where run = do
             st <- replayRepository' r opt
             f st
 
-checkIndex :: (RepoPatch p) => Repository p -> Bool -> IO Bool
+checkIndex :: (RepoPatch p) => Repository p C(r u t) -> Bool -> IO Bool
 checkIndex repo quiet = do
   index <- updateIndex =<< readIndex repo
   pristine <- expand =<< readRecordedAndPending repo
