@@ -1,25 +1,23 @@
 {-# OPTIONS_GHC -fno-warn-deprecations -fno-warn-orphans -fglasgow-exts #-}
-{-# LANGUAGE CPP, UndecidableInstances, ScopedTypeVariables #-}
+{-# LANGUAGE CPP, UndecidableInstances, ScopedTypeVariables, ViewPatterns #-}
 
 #include "gadts.h"
 module Darcs.Test.Patch.QuickCheck ( WithStartState, RepoModel, Tree,
-#ifndef GADT_WITNESSES
-                                     merge_examples, commute_examples, triple_examples,
-#endif
-                                     prop_consistent_tree_flattenings, prop_fail,
-                                     prop_is_mergeable,
+                                     mergeExamples, commuteExamples, tripleExamples,
+                                     propConsistentTreeFlattenings, propFail,
+                                     propIsMergeable,
                                      flattenOne, testConditional,
                                      commutePairFromTree, mergePairFromTree,
                                      commuteTripleFromTree,
                                      commutePairFromTWFP, mergePairFromTWFP, getPairs, getTriples,
                                      patchFromTree,
-                                     quickCheck, real_patch_loop_examples, shrink
+                                     quickCheck, realPatchLoopExamples, shrink
                                    ) where
 
 import Control.Arrow ( (***) )
 import Control.Monad ( liftM, replicateM, mplus, mzero )
-import qualified Data.ByteString.Char8 as BC (pack)
-import qualified Data.ByteString       as B  (ByteString)
+import qualified Data.ByteString.Char8 as BC (pack, head)
+import qualified Data.ByteString       as B  (ByteString, length)
 import Test.QuickCheck
 import Test.Framework ( Test )
 import Test.Framework.Providers.QuickCheck2 ( testProperty )
@@ -28,8 +26,9 @@ import Darcs.Patch ( Patch )
 import Darcs.Witnesses.Ordered
 import Darcs.Patch.Patchy (--showPatch,
                            Invert(..), Commute(..))
-import Darcs.Patch.Prim (Prim(..), Effect(..), FilePatchType(..), FromPrim(..), is_identity )
+import Darcs.Patch.Prim (Prim(..), Effect(..), FilePatchType(..), FromPrim(..), isIdentity )
 import Darcs.Patch.Real ( RealPatch, prim2real )
+import Darcs.Patch.Set ( Origin )
 --import Darcs.ColorPrinter ( errorDoc )
 --import Darcs.ColorPrinter ( traceDoc )
 import Darcs.Witnesses.Show
@@ -38,25 +37,15 @@ import Darcs.Patch.FileName ( FileName, fp2fn )
 
 #include "impossible.h"
 
-
-#ifndef GADT_WITNESSES
-instance Eq (a C(x y)) => Eq (Sealed2 a) where
-    (Sealed2 x) == (Sealed2 y) = x == y
-#endif
-
-instance Show2 Patch where
-    show2 = show
-
-#ifndef GADT_WITNESSES
-triple_examples :: (FromPrim p, Commute p, Invert p) => [p :> p :> p]
-triple_examples = [commuteTripleFromTree id $
+tripleExamples :: (FromPrim p, Commute p, Invert p) => [Sealed2 (p :> p :> p)]
+tripleExamples = [commuteTripleFromTree seal2 $
                    WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                    (ParTree
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "g"]))
                      (SeqTree (FP (fp2fn "./file") (Hunk 1 [] [BC.pack "j"]))
                       (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "s"])) NilTree)))
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "e"])) NilTree))
-                  ,commuteTripleFromTree id $
+                  ,commuteTripleFromTree seal2 $
                    WithStartState (RepoModel { rmFileName = fp2fn "./file",
                                                rmFileContents = [BC.pack "j"] })
                    (ParTree
@@ -68,12 +57,12 @@ triple_examples = [commuteTripleFromTree id $
                   ]
 
 
-merge_examples :: (FromPrim p, Commute p, Invert p) => [p :\/: p]
-merge_examples = map (mergePairFromCommutePair id) commute_examples
+mergeExamples :: (FromPrim p, Commute p, Invert p) => [Sealed2 (p :\/: p)]
+mergeExamples = map (unseal2 (mergePairFromCommutePair seal2)) commuteExamples
 
-commute_examples :: (FromPrim p, Commute p) => [p :> p]
-commute_examples = [
-                   commutePairFromTWFP id $
+commuteExamples :: (FromPrim p, Commute p) => [Sealed2 (p :> p)]
+commuteExamples = [
+                   commutePairFromTWFP seal2 $
                    WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                    (TWFP 3
                     (ParTree
@@ -82,7 +71,7 @@ commute_examples = [
                        (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "f"]))
                          (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "v"]))
                            (SeqTree (FP (fp2fn "./file") (Hunk 1 [BC.pack "f"] [])) NilTree)))))),
-                   commutePairFromTWFP id $
+                   commutePairFromTWFP seal2 $
                    WithStartState
                    (RepoModel { rmFileName = fp2fn "./file",
                                 rmFileContents = [BC.pack "f",BC.pack "s",BC.pack "d"] })
@@ -94,7 +83,7 @@ commute_examples = [
                       (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "f"] []))
                         (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "s",BC.pack "d"] []))
                           (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "v"])) NilTree)))))),
-{-                   commutePairFromTWFP id $
+{-                   commutePairFromTWFP seal2 $
                    WithStartState
                    (RepoModel { rmFileName = fp2fn "./file",
                                 rmFileContents = [BC.pack "f",BC.pack "u",
@@ -109,7 +98,7 @@ commute_examples = [
                        (SeqTree (FP(fp2fn "./file") (Hunk 0 [BC.pack "u",BC.pack "s",BC.pack "d"] []))
                         (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "a"]))
                          (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "a"] [])) NilTree))))))),-}
-                   commutePairFromTree id $
+                   commutePairFromTree seal2 $
                    WithStartState (RepoModel { rmFileName = fp2fn "./file",
                                           rmFileContents = [BC.pack "n",BC.pack "t",BC.pack "h"] })
                    (ParTree
@@ -118,13 +107,13 @@ commute_examples = [
                     (SeqTree (FP (fp2fn "./file") (Hunk 2 [BC.pack "h"] []))
                      (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "n"] []))
                       (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "t"] [])) NilTree)))),
-                  commutePairFromTree id $
+                  commutePairFromTree seal2 $
                   WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                   (ParTree
                    (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "n"])) NilTree)
                    (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "i"]))
                                 (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "i"])) NilTree))),
-                  commutePairFromTree id $
+                  commutePairFromTree seal2 $
                   WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                   (ParTree
                    (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "c"]))
@@ -133,7 +122,7 @@ commute_examples = [
                        (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "h"]))
                         (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "d"])) NilTree))))
                    (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "f"])) NilTree)),
-                  commutePairFromTWFP id $
+                  commutePairFromTWFP seal2 $
                   WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                   (TWFP 1
                   (ParTree
@@ -141,7 +130,7 @@ commute_examples = [
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "t"])) NilTree)
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "t"])) NilTree))
                    (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "f"])) NilTree))),
-                   commutePairFromTWFP id $
+                   commutePairFromTWFP seal2 $
                    WithStartState (RepoModel { rmFileName = fp2fn "./file",
                                                rmFileContents = [BC.pack "f",BC.pack " r",
                                                                  BC.pack "c",BC.pack "v"] })
@@ -154,7 +143,7 @@ commute_examples = [
                          (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "f",BC.pack "r"] []))
                           (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "y"])) NilTree))))
                      (SeqTree (FP (fp2fn "./file") (Hunk 3 [BC.pack "v"] [])) NilTree))),
-                   commutePairFromTree id $
+                   commutePairFromTree seal2 $
                    WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                    (ParTree
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "z"])) NilTree)
@@ -163,7 +152,7 @@ commute_examples = [
                      (ParTree
                       (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "r"])) NilTree)
                       (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "d"])) NilTree))))
-                 , commutePairFromTree id $
+                 , commutePairFromTree seal2 $
                    WithStartState (RepoModel { rmFileName = fp2fn "./file",
                                                rmFileContents = [BC.pack "t",BC.pack "r",
                                                                  BC.pack "h"] })
@@ -174,7 +163,7 @@ commute_examples = [
                      (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "o"])) NilTree))
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "t"] []))
                      (SeqTree (FP (fp2fn "./file") (Hunk 1 [BC.pack "h"] [])) NilTree)))
-                 , commutePairFromTWFP id $
+                 , commutePairFromTWFP seal2 $
                    WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] }) $
                    TWFP 2
                    (ParTree
@@ -182,26 +171,26 @@ commute_examples = [
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "y"]))
                      (SeqTree (FP (fp2fn "./file") (Hunk 1 [] [BC.pack "m"]))
                       (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "v"])) NilTree))))
-                 , commutePairFromTree id $
+                 , commutePairFromTree seal2 $
                  WithStartState (RepoModel {rmFileName = fp2fn "./file",rmFileContents = [] })
                  (ParTree
                   (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "p"]))
                    (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "p"] []))
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "c"])) NilTree)))
                   (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "z"])) NilTree))
-                 , commutePairFromTree id $
+                 , commutePairFromTree seal2 $
                  WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                  (ParTree
                   (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "j" ]))
                    (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "j"] [])) NilTree))
                   (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "v"])) NilTree))
-                 , commutePairFromTree id $
+                 , commutePairFromTree seal2 $
                  WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                  (ParTree
                   (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "v"])) NilTree)
                   (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "j" ]))
                    (SeqTree (FP (fp2fn "./file") (Hunk 0 [BC.pack "j"] [])) NilTree)))
-                 , commutePairFromTree id $
+                 , commutePairFromTree seal2 $
                  WithStartState (RepoModel { rmFileName = fp2fn "./file",
                                              rmFileContents = [BC.pack "x",BC.pack "c"] })
                  (ParTree
@@ -211,7 +200,7 @@ commute_examples = [
                     (SeqTree (FP (fp2fn "./file") (Hunk 1 [BC.pack "x"] []))
                      (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "j"])) NilTree))))
                   (SeqTree (FP (fp2fn "./file") (Hunk 0 [] [BC.pack "l"])) NilTree))
-                 , commutePairFromTree id $
+                 , commutePairFromTree seal2 $
                  WithStartState (RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] })
                  (ParTree
                   (SeqTree (FP (fp2fn "./file") (Hunk 0 [] (packStringLetters "s"))) NilTree)
@@ -220,7 +209,6 @@ commute_examples = [
                     (SeqTree (FP (fp2fn "./file") (Hunk 0 [] (packStringLetters "m")))
                      (SeqTree (FP (fp2fn "./file") (Hunk 0 (packStringLetters "m") [])) NilTree)))))
                  ]
-#endif
 
 -- | Turns a condition and a test function into a conditional quickcheck
 --   property that can be run by test-framework.
@@ -240,23 +228,21 @@ data RepoModel C(x)
    } deriving (Eq)
 
 instance Show (RepoModel C(x)) where
-  showsPrec d rm = showParen (d > app_prec) $
+  showsPrec d rm = showParen (d > appPrec) $
                    showString "RepoModel { rmFileName = " . showsPrec 0 (rmFileName rm) .
-                   showString ", rmFileContents = " . showsPrec 0 (rmFileContents rm) .
+                   showString ", rmFileContents = " . showsPrec' 0 (rmFileContents rm) .
                    showString " }"
+     where showsPrec' n lines | all ((==1) . B.length) lines = showsPrecC n lines
+                              | otherwise = showsPrec n lines
+           showsPrecC _ [] = showString "[]"
+           showsPrecC n ss = showParen (n > 0) $ showString "packStringLetters " . showsPrec (appPrec + 1) (map BC.head ss)
 
 instance Show1 RepoModel where
-    showsPrec1 = showsPrec
-
-#ifdef GADT_WITNESSES
--- | The initial repository state, to be used as an argument to the @RepoModel@
---   data type.
-data InitRepoModel -- this ought to be defined somewhere central as the unique starting state
-#endif
+    showDict1 = ShowDictClass
 
 -- | The initial repository model. The repository contains a single file named
 --   @./file@, which is empty.
-initRepoModel :: RepoModel C(InitRepoModel)
+initRepoModel :: RepoModel C(Origin)
 initRepoModel = RepoModel { rmFileName = fp2fn "./file", rmFileContents = [] }
 rebuildRepoModel :: RepoModel C(x) -> RepoModel C(y)
 rebuildRepoModel rm = RepoModel { rmFileName = rmFileName rm, rmFileContents = rmFileContents rm }
@@ -285,55 +271,54 @@ instance Arbitrary (Sealed2 (FL Prim)) where
   arbitrary = do Sealed2 ps1 <- liftM (unseal (seal2 . wesPatch)) $ arbitraryState initRepoModel
                  return $ Sealed2 $ mapFL_FL make_identity_identity ps1
                      where make_identity_identity :: Prim C(x y) -> Prim C(x y)
-                           make_identity_identity p | IsEq <- is_identity p = identity
+                           make_identity_identity p | IsEq <- isIdentity p = identity
                                                     | otherwise = p
 
 instance Arbitrary (Sealed2 (FL (WithState RepoModel Prim))) where
   arbitrary = liftM (unseal (seal2 . wesPatch)) $ arbitraryState initRepoModel
 
-prop_consistent_tree_flattenings :: Sealed (WithStartState RepoModel (Tree Prim)) -> Bool
-prop_consistent_tree_flattenings (Sealed (WithStartState start t))
+propConsistentTreeFlattenings :: Sealed (WithStartState RepoModel (Tree Prim)) -> Bool
+propConsistentTreeFlattenings (Sealed (WithStartState start t))
   = fromJust $
     do Sealed (G2 flat) <- return $ flattenTree $ mapTree prim2real t
        rms <- return $ map (applyPatch start) flat
-       return $ and $ zipWith assert_equal_fst (zip rms flat) (tail $ zip rms flat)
+       return $ and $ zipWith assertEqualFst (zip rms flat) (tail $ zip rms flat)
 
-assert_equal_fst :: (Eq a, Show a, Show b, Show c) => (a, b) -> (a, c) -> Bool
-assert_equal_fst (x,bx) (y,by)
+assertEqualFst :: (Eq a, Show a, Show b, Show c) => (a, b) -> (a, c) -> Bool
+assertEqualFst (x,bx) (y,by)
     | x == y = True
     | otherwise = error ("Not really equal:\n" ++ show x ++ "\nand\n" ++ show y
                          ++ "\ncoming from\n" ++ show bx ++ "\nand\n" ++ show by)
 
--- WithState and prop_fail are handy for debugging arbitrary code
+-- WithState and propFail are handy for debugging arbitrary code
 data WithState s p C(x y) = WithState (s C(x)) (p C(x y)) (s C(y))
   deriving Show
 
 data WithStartState s p C(x) = WithStartState (s C(x)) (p C(x))
 
 instance (Show1 s, Show1 p) => Show (WithStartState s p C(x)) where
-   showsPrec d (WithStartState s p) = showParen (d > app_prec) $ showString "WithStartState " .
-                                      showsPrec1 (app_prec + 1) s . showString " " .
-                                      showsPrec1 (app_prec + 1) p
+   showsPrec d (WithStartState s p) = showParen (d > appPrec) $ showString "WithStartState " .
+                                      showsPrec1 (appPrec + 1) s . showString " " .
+                                      showsPrec1 (appPrec + 1) p
 
 instance (Show1 s, Show1 p) => Show1 (WithStartState s p) where
-   showsPrec1 = showsPrec
+   showDict1 = ShowDictClass
 
-prop_fail :: Int -> Tree Prim C(x) -> Bool
-prop_fail n xs = sizeTree xs < n
+propFail :: Int -> Tree Prim C(x) -> Bool
+propFail n xs = sizeTree xs < n
 
 instance ArbitraryState s p => ArbitraryState s (WithState s p) where
-  arbitraryState rm = do xandrm' <- arbitraryState rm
-                         flip unseal xandrm' $ \(WithEndState x rm') ->
-                           return $ seal $ WithEndState (WithState rm x rm') rm'
+  arbitraryState rm = do Sealed (WithEndState x rm') <- arbitraryState rm
+                         return $ seal $ WithEndState (WithState rm x rm') rm'
 
 instance ArbitraryState s p => ArbitraryState s (FL p) where
   arbitraryState rm1 = sized $ \n -> do k <- choose (0, n)
                                         arbitraryList k rm1
       where arbitraryList :: FORALL(x) Int -> s C(x) -> Gen (Sealed (WithEndState (FL p C(x)) s))
             arbitraryList 0 rm = return $ seal $ WithEndState NilFL rm
-            arbitraryList (n+1) rm = do Sealed (WithEndState x rm') <- arbitraryState rm
-                                        Sealed (WithEndState xs rm'') <- arbitraryList n rm'
-                                        return $ seal $ WithEndState (x :>: xs) rm''
+            arbitraryList n rm = do Sealed (WithEndState x rm') <- arbitraryState rm
+                                    Sealed (WithEndState xs rm'') <- arbitraryList (n-1) rm'
+                                    return $ seal $ WithEndState (x :>: xs) rm''
             arbitraryList _ _ = impossible
 
 data Tree p C(x) where
@@ -348,15 +333,15 @@ mapTree f (ParTree t1 t2) = ParTree (mapTree f t1) (mapTree f t2)
 
 instance Show2 p => Show (Tree p C(x)) where
    showsPrec _ NilTree = showString "NilTree"
-   showsPrec d (SeqTree a t) = showParen (d > app_prec) $ showString "SeqTree " .
-                               showsPrec2 (app_prec + 1) a . showString " " .
-                               showsPrec (app_prec + 1) t
-   showsPrec d (ParTree t1 t2) = showParen (d > app_prec) $ showString "ParTree " .
-                                 showsPrec (app_prec + 1) t1 . showString " " .
-                                 showsPrec (app_prec + 1) t2
+   showsPrec d (SeqTree a t) = showParen (d > appPrec) $ showString "SeqTree " .
+                               showsPrec2 (appPrec + 1) a . showString " " .
+                               showsPrec (appPrec + 1) t
+   showsPrec d (ParTree t1 t2) = showParen (d > appPrec) $ showString "ParTree " .
+                                 showsPrec (appPrec + 1) t1 . showString " " .
+                                 showsPrec (appPrec + 1) t2
 
 instance Show2 p => Show1 (Tree p) where
-    showsPrec1 = showsPrec
+    showDict1 = ShowDictClass
 
 sizeTree :: Tree p C(x) -> Int
 sizeTree NilTree = 0
@@ -369,9 +354,8 @@ newtype G2 l p C(x y) = G2 { unG2 :: l (p C(x y)) }
 flattenTree :: (Commute p) => Tree p C(z) -> Sealed (G2 [] (FL p) C(z))
 flattenTree NilTree = seal $ G2 $ return NilFL
 flattenTree (SeqTree p t) = mapSeal (G2 . map (p :>:) . unG2) $ flattenTree t
-flattenTree (ParTree t1 t2) = flip unseal (flattenTree t1) $ \gpss1 ->
-                              flip unseal (flattenTree t2) $ \gpss2 ->
-                              seal $ G2 $
+flattenTree (ParTree (flattenTree -> Sealed gpss1) (flattenTree -> Sealed gpss2))
+                            = seal $ G2 $
                               do ps1 <- unG2 gpss1
                                  ps2 <- unG2 gpss2
                                  ps2' :/\: ps1' <- return $ merge (ps1 :\/: ps2)
@@ -455,7 +439,7 @@ instance ShrinkablePos FilePatchType where
     | otherwise = (Hunk n (take pos' old ++ drop (pos'+1) old) new, Nothing)
         where pos' = pos - n
   shrinkPos _ _ = bug "foo1 in ShrinkablePos"
-  shrinkPatch (Hunk (n+1) [] []) = [(Hunk n [] [], Nothing)]
+  shrinkPatch (Hunk n [] []) | n > 0 = [(Hunk (n-1) [] [], Nothing)]
   shrinkPatch (Hunk n old new)
    = do i <- [0 .. length new - 1]
         return (Hunk n old (take i new ++ drop (i+1) new), Just (n + i))
@@ -511,10 +495,10 @@ instance Arbitrary (Sealed (WithStartState RepoModel (Tree Prim))) where
                  return $ Sealed $ WithStartState rm (canonizeTree tree)
   shrink = shrinkWSSTree
 
-prop_is_mergeable :: forall p C(x) . (FromPrim p, Commute p)
+propIsMergeable :: forall p C(x) . (FromPrim p, Commute p)
                   => Sealed (WithStartState RepoModel (Tree Prim))
                   -> Maybe (Tree p C(x))
-prop_is_mergeable (Sealed (WithStartState _ t))
+propIsMergeable (Sealed (WithStartState _ t))
    = case flattenOne t of
         Sealed ps -> let _ = seal2 ps :: Sealed2 (FL p)
                      in case lengthFL ps of
@@ -522,10 +506,8 @@ prop_is_mergeable (Sealed (WithStartState _ t))
 
 flattenOne :: (FromPrim p, Commute p) => Tree Prim C(x) -> Sealed (FL p C(x))
 flattenOne NilTree = seal NilFL
-flattenOne (SeqTree p t) = flip unseal (flattenOne t) $ \ps -> seal (fromPrim p :>: ps)
-flattenOne (ParTree t1 t2) =
-    flip unseal (flattenOne t1) $ \ps1 ->
-    flip unseal (flattenOne t2) $ \ps2 ->
+flattenOne (SeqTree p (flattenOne -> Sealed ps)) = seal (fromPrim p :>: ps)
+flattenOne (ParTree (flattenOne -> Sealed ps1) (flattenOne -> Sealed ps2)) =
     --traceDoc (greenText "flattening two parallel series: ps1" $$ showPatch ps1 $$
     --          greenText "ps2" $$ showPatch ps2) $
     case merge (ps1 :\/: ps2) of
@@ -630,12 +612,12 @@ patchFromTree x = commutePairFromTree (patchFromCommutePair x)
 
 
 instance Show2 p => Show (TreeWithFlattenPos p C(x)) where
-   showsPrec d (TWFP n t) = showParen (d > app_prec) $ showString "TWFP " .
-                            showsPrec (app_prec + 1) n . showString " " .
-                            showsPrec1 (app_prec + 1) t
+   showsPrec d (TWFP n t) = showParen (d > appPrec) $ showString "TWFP " .
+                            showsPrec (appPrec + 1) n . showString " " .
+                            showsPrec1 (appPrec + 1) t
 
 instance Show1 (TreeWithFlattenPos Prim) where
-   show1 = show
+   showDict1 = ShowDictClass
 
 instance Arbitrary (Sealed (WithStartState RepoModel (TreeWithFlattenPos Prim))) where
    arbitrary = do Sealed (WithStartState rm t) <- arbitrary
@@ -718,8 +700,8 @@ applyFilePatchType _ _ = bug "We haven't defined applyFilePatchType for all patc
 packStringLetters :: String -> [B.ByteString]
 packStringLetters = map (BC.pack . (:[]))
 
-real_patch_loop_examples :: [Sealed (WithStartState RepoModel (Tree Prim))]
-real_patch_loop_examples =
+realPatchLoopExamples :: [Sealed (WithStartState RepoModel (Tree Prim))]
+realPatchLoopExamples =
     [Sealed (WithStartState (RepoModel { rmFileName = fx, rmFileContents = [] })
      $ canonizeTree
      (ParTree
