@@ -21,22 +21,22 @@
 #include "gadts.h"
 
 module Darcs.Test.Patch.Test
-             ( prop_read_show,
-               prop_inverse_composition, prop_commute_twice,
-               prop_inverse_valid, prop_other_inverse_valid,
-               prop_commute_equivalency, prop_commute_either_order,
-               prop_commute_either_way, prop_merge_is_commutable_and_correct,
-               prop_merge_is_swapable, prop_merge_valid,
-               prop_unravel_three_merge, prop_unravel_seq_merge,
-               prop_unravel_order_independent,
-               prop_simple_smart_merge_good_enough,
-               prop_elegant_merge_good_enough,
-               prop_patch_and_inverse_is_identity,
-               quickmerge, check_patch, check_a_patch, verbose_check_a_patch,
-               prop_resolve_conflicts_valid,
-               test_patch, prop_commute_inverse,
-               subcommutes_inverse, subcommutes_nontrivial_inverse,
-               subcommutes_failure,
+             ( propReadShow,
+               propInverseComposition, propCommuteTwice,
+               propInverseValid, propOtherInverseValid,
+               propCommuteEquivalency, propCommuteEitherOrder,
+               propCommuteEitherWay, propMergeIsCommutableAndCorrect,
+               propMergeIsSwapable, propMergeValid,
+               propUnravelThreeMerge, propUnravelSeqMerge,
+               propUnravelOrderIndependent,
+               propSimpleSmartMergeGoodEnough,
+               propElegantMergeGoodEnough,
+               propPatchAndInverseIsIdentity,
+               quickmerge, checkPatch, checkAPatch, verboseCheckAPatch,
+               propResolveConflictsValid,
+               testPatch, propCommuteInverse,
+               subcommutesInverse, subcommutesNontrivialInverse,
+               subcommutesFailure,
                join_patches
              ) where
 
@@ -47,10 +47,10 @@ import Control.Monad ( liftM, liftM2, liftM3, liftM4, replicateM )
 
 import Darcs.Patch.Info ( PatchInfo, patchinfo )
 import Darcs.Test.Patch.Check ( PatchCheck,
-                                check_move, remove_dir, create_dir,
-                                is_valid, insert_line, file_empty, file_exists,
-                                delete_line, modify_file, create_file, remove_file,
-                                do_check, do_verbose_check, FileContents(..)
+                                checkMove, removeDir, createDir,
+                                isValid, insertLine, fileEmpty, fileExists,
+                                deleteLine, modifyFile, createFile, removeFile,
+                                doCheck, doVerboseCheck, FileContents(..)
                               )
 import Darcs.Patch.RegChars ( regChars )
 import ByteStringUtils ( linesPS )
@@ -65,8 +65,9 @@ import Darcs.Patch ( addfile, adddir, move, showPatch,
                      changepref, isMerger, invert, commute, merge,
                      readPatch, resolveConflicts,
                      effect, fromPrims,
-                     unravel, merger, elegantMerge )
+                     elegantMerge )
 import Darcs.Patch.Core ( Patch(..) )
+import Darcs.Patch.Commute ( unravel, merger )
 import Darcs.Patch.Prim ( Prim(..), DirPatchType(..), FilePatchType(..),
                           CommuteFunction, Perhaps(..),
                           subcommutes )
@@ -117,7 +118,7 @@ twofilegen :: (FilePath -> FilePath -> Prim) -> Gen Prim
 twofilegen p = do
   n1 <- filepathgen
   n2 <- filepathgen
-  if n1 /= n2 && (check_a_patch $ fromPrims $ (p n1 n2 :>: NilFL))
+  if n1 /= n2 && (checkAPatch $ fromPrims $ (p n1 n2 :>: NilFL))
      then return $ p n1 n2
      else twofilegen p
 
@@ -151,40 +152,44 @@ arbpatch 0 = PP `fmap` onepatchgen
 arbpatch n = frequency [(3,PP `fmap` onepatchgen),
                        -- (1,compgen n),
                         (2,flatcompgen n),
-                        (0,raw_merge_gen n),
+                        (0,rawMergeGen n),
                         (0,mergegen n),
                         (1,PP `fmap` onepatchgen)
                        ]
 
+-- | Generate an arbitrary list of at least one element
 unempty :: Arbitrary a => Gen [a]
 unempty = do
+  a <- arbitrary
   as <- arbitrary
-  case as of
-    [] -> unempty
-    _ -> return as
+  return (a:as)
 
 join_patches :: [Patch] -> Patch
 join_patches = joinPatches . unsafeFL
+   where
+      unsafeFL :: [a] -> FL a
+      unsafeFL [] = NilFL
+      unsafeFL (a:as) = a :>: unsafeFL as
 
-raw_merge_gen :: Int -> Gen Patch
-raw_merge_gen n = do p1 <- arbpatch len
+rawMergeGen :: Int -> Gen Patch
+rawMergeGen n =   do p1 <- arbpatch len
                      p2 <- arbpatch len
-                     if (check_a_patch $ join_patches [invert p1,p2]) &&
-                        (check_a_patch $ join_patches [invert p2,p1])
+                     if (checkAPatch $ join_patches [invert p1,p2]) &&
+                        (checkAPatch $ join_patches [invert p2,p1])
                         then case merge (p2 :\/: p1) of
                              _ :/\: p2' -> return p2'
-                        else raw_merge_gen n
+                        else rawMergeGen n
     where len = if n < 15 then n`div`3 else 3
 
 mergegen :: Int -> Gen Patch
 mergegen n = do
   p1 <- norecursgen len
   p2 <- norecursgen len
-  if (check_a_patch $ join_patches [invert p1,p2]) &&
-         (check_a_patch $ join_patches [invert p2,p1])
+  if (checkAPatch $ join_patches [invert p1,p2]) &&
+         (checkAPatch $ join_patches [invert p2,p1])
      then case merge (p2:\/:p1) of
           p1' :/\: p2' ->
-              if check_a_patch $ join_patches [p1,p2']
+              if checkAPatch $ join_patches [p1,p2']
               then return $ join_patches [p1,p2']
               else return $ join_patches [PP $ addfile "Error_in_mergegen",
                                           PP $ addfile "Error_in_mergegen",
@@ -221,7 +226,7 @@ compgen n = do
     size <- choose (0,n)
     myp <- liftM join_patches $ plistgen size ((n+1) `div` (size+1))
 -- here I assume we only want to consider valid patches...
-    if check_a_patch myp
+    if checkAPatch myp
        then return myp
        else compgen n
 -}
@@ -231,8 +236,8 @@ flatlistgen n = replicateM n (PP `fmap` onepatchgen)
 
 flatcompgen :: Int -> Gen Patch
 flatcompgen n = do
-  myp <- liftM (join_patches . regularize_patches) $ flatlistgen n
-  if check_a_patch myp
+  myp <- liftM (join_patches . regularizePatches) $ flatlistgen n
+  if checkAPatch myp
      then return myp
      else flatcompgen n
 
@@ -286,88 +291,88 @@ instance Arbitrary Char where
 -}
 --    coarbitrary c = coarbitrary (ord c)
 
-check_patch :: Patch -> PatchCheck Bool
-check_a_patch :: Patch -> Bool
-check_a_patch p = do_check $ do check_patch p
-                                check_patch $ invert p
-verbose_check_a_patch :: Patch -> Bool
-verbose_check_a_patch p = do_verbose_check $ do check_patch p
-                                                check_patch $ invert p
+checkPatch :: Patch -> PatchCheck Bool
+checkAPatch :: Patch -> Bool
+checkAPatch p = doCheck $ do checkPatch p
+                             checkPatch $ invert p
+verboseCheckAPatch :: Patch -> Bool
+verboseCheckAPatch p = doVerboseCheck $ do checkPatch p
+                                           checkPatch $ invert p
 
-check_patch p | isMerger p = do
-  check_patch $ fromPrims $ effect p
-check_patch (Merger _ _ _ _) = impossible
-check_patch (Regrem _ _ _ _) = impossible
-check_patch (ComP NilFL) = is_valid
-check_patch (ComP (p:>:ps)) =
-  check_patch p >> check_patch (ComP ps)
-check_patch (PP Identity) = is_valid
-check_patch (PP (Split NilFL)) = is_valid
-check_patch (PP (Split (p:>:ps))) =
-  check_patch (PP p) >> check_patch (PP (Split ps))
+checkPatch p | isMerger p = do
+  checkPatch $ fromPrims $ effect p
+checkPatch (Merger _ _ _ _) = impossible
+checkPatch (Regrem _ _ _ _) = impossible
+checkPatch (ComP NilFL) = isValid
+checkPatch (ComP (p:>:ps)) =
+  checkPatch p >> checkPatch (ComP ps)
+checkPatch (PP Identity) = isValid
+checkPatch (PP (Split NilFL)) = isValid
+checkPatch (PP (Split (p:>:ps))) =
+  checkPatch (PP p) >> checkPatch (PP (Split ps))
 
-check_patch (PP (FP f RmFile)) = remove_file $ fn2fp f
-check_patch (PP (FP f AddFile)) =  create_file $ fn2fp f
-check_patch (PP (FP f (Hunk line old new))) = do
-    file_exists $ fn2fp f
-    mapM_ (delete_line (fn2fp f) line) old
-    mapM_ (insert_line (fn2fp f) line) (reverse new)
-    is_valid
-check_patch (PP (FP f (TokReplace t old new))) =
-    modify_file (fn2fp f) (try_tok_possibly t old new)
+checkPatch (PP (FP f RmFile)) = removeFile $ fn2fp f
+checkPatch (PP (FP f AddFile)) =  createFile $ fn2fp f
+checkPatch (PP (FP f (Hunk line old new))) = do
+    fileExists $ fn2fp f
+    mapM_ (deleteLine (fn2fp f) line) old
+    mapM_ (insertLine (fn2fp f) line) (reverse new)
+    isValid
+checkPatch (PP (FP f (TokReplace t old new))) =
+    modifyFile (fn2fp f) (tryTokPossibly t old new)
 -- note that the above isn't really a sure check, as it leaves PSomethings
 -- and PNothings which may have contained new...
-check_patch (PP (FP f (Binary o n))) = do
-    file_exists $ fn2fp f
-    mapM_ (delete_line (fn2fp f) 1) (linesPS o)
-    file_empty $ fn2fp f
-    mapM_ (insert_line (fn2fp f) 1) (reverse $ linesPS n)
-    is_valid
+checkPatch (PP (FP f (Binary o n))) = do
+    fileExists $ fn2fp f
+    mapM_ (deleteLine (fn2fp f) 1) (linesPS o)
+    fileEmpty $ fn2fp f
+    mapM_ (insertLine (fn2fp f) 1) (reverse $ linesPS n)
+    isValid
 
-check_patch (PP (DP d AddDir)) = create_dir $ fn2fp d
-check_patch (PP (DP d RmDir)) = remove_dir $ fn2fp d
+checkPatch (PP (DP d AddDir)) = createDir $ fn2fp d
+checkPatch (PP (DP d RmDir)) = removeDir $ fn2fp d
 
-check_patch (PP (Move f f')) = check_move (fn2fp f) (fn2fp f')
-check_patch (PP (ChangePref _ _ _)) = return True
+checkPatch (PP (Move f f')) = checkMove (fn2fp f) (fn2fp f')
+checkPatch (PP (ChangePref _ _ _)) = return True
 
-regularize_patches :: [Patch] -> [Patch]
-regularize_patches patches = rpint [] patches
+regularizePatches :: [Patch] -> [Patch]
+regularizePatches patches = rpint [] patches
     where rpint ok_ps [] = ok_ps
           rpint ok_ps (p:ps) =
-            if check_a_patch (join_patches $ p:ok_ps)
+            if checkAPatch (join_patches $ p:ok_ps)
             then rpint (p:ok_ps) ps
             else rpint ok_ps ps
 
-prop_inverse_composition :: Patch -> Patch -> Bool
-prop_inverse_composition p1 p2 =
+propInverseComposition :: Patch -> Patch -> Bool
+propInverseComposition p1 p2 =
     invert (join_patches [p1,p2]) == join_patches [invert p2, invert p1]
-prop_inverse_valid :: Patch -> Bool
-prop_inverse_valid p1 = check_a_patch $ join_patches [invert p1,p1]
-prop_other_inverse_valid :: Patch -> Bool
-prop_other_inverse_valid p1 = check_a_patch $ join_patches [p1,invert p1]
+propInverseValid :: Patch -> Bool
+propInverseValid p1 = checkAPatch $ join_patches [invert p1,p1]
+propOtherInverseValid :: Patch -> Bool
+propOtherInverseValid p1 = checkAPatch $ join_patches [p1,invert p1]
 
-prop_commute_twice :: Patch -> Patch -> Property
-prop_commute_twice p1 p2 =
-    (does_commute p1 p2) ==> (Just (p1:>p2) == (commute (p1:>p2) >>= commute))
-does_commute :: Patch -> Patch -> Bool
-does_commute p1 p2 =
-    commute (p1:>p2) /= Nothing && (check_a_patch $ join_patches [p1,p2])
-prop_commute_equivalency :: Patch -> Patch -> Property
-prop_commute_equivalency p1 p2 =
-    (does_commute p1 p2) ==>
+propCommuteTwice :: Patch -> Patch -> Property
+propCommuteTwice p1 p2 =
+    (doesCommute p1 p2) ==> (Just (p1:>p2) == (commute (p1:>p2) >>= commute))
+doesCommute :: Patch -> Patch -> Bool
+doesCommute p1 p2 =
+    commute (p1:>p2) /= Nothing && (checkAPatch $ join_patches [p1,p2])
+propCommuteEquivalency :: Patch -> Patch -> Property
+propCommuteEquivalency p1 p2 =
+    (doesCommute p1 p2) ==>
     case commute (p1:>p2) of
-    Just (p2':>p1') -> check_a_patch $ join_patches [p1,p2,invert p1',invert p2']
+    Just (p2':>p1') -> checkAPatch $ join_patches [p1,p2,invert p1',invert p2']
     _ -> impossible
 
-prop_commute_either_way :: Patch -> Patch -> Property
-prop_commute_either_way p1 p2 =
-    does_commute p1 p2 ==> does_commute (invert p2) (invert p1)
+propCommuteEitherWay :: Patch -> Patch -> Property
+propCommuteEitherWay p1 p2 =
+    doesCommute p1 p2 ==> doesCommute (invert p2) (invert p1)
 
-prop_commute_either_order :: Patch -> Patch -> Patch -> Property
-prop_commute_either_order p1 p2 p3 =
-    check_a_patch (join_patches [p1,p2,p3]) &&
-    does_commute p1 (join_patches [p2,p3]) &&
-    does_commute p2 p3 ==>
+propCommuteEitherOrder :: Patch -> Patch -> Patch -> Property
+propCommuteEitherOrder p1 p2 p3 =
+    checkAPatch (join_patches [p1,p2,p3]) &&
+    doesCommute p1 (join_patches [p2,p3]) &&
+    doesCommute p2 p3 ==>
     case commute (p1:>p2) of
     Nothing -> False
     Just (p2':>p1') ->
@@ -384,9 +389,9 @@ prop_commute_either_order p1 p2 p3 =
                     Just (p3''a:>_) -> p3''a == p3''
                     Nothing -> False
 
-prop_patch_and_inverse_is_identity :: Patch -> Patch -> Property
-prop_patch_and_inverse_is_identity p1 p2 =
-    (check_a_patch $ join_patches [p1,p2]) && (commute (p1:>p2) /= Nothing) ==>
+propPatchAndInverseIsIdentity :: Patch -> Patch -> Property
+propPatchAndInverseIsIdentity p1 p2 =
+    (checkAPatch $ join_patches [p1,p2]) && (commute (p1:>p2) /= Nothing) ==>
     case commute (p1:>p2) of
     Just (p2':>_) -> case commute (invert p1:>p2') of
                     Nothing -> True -- This is a subtle distinction.
@@ -397,40 +402,40 @@ quickmerge :: (Patch :\/: Patch) -> Patch
 quickmerge (p1:\/:p2) = case merge (p1:\/:p2) of
                         _ :/\: p1' -> p1'
 
-prop_merge_is_commutable_and_correct :: Patch -> Patch -> Property
-prop_merge_is_commutable_and_correct p1 p2 =
-    (check_a_patch $ join_patches [invert p1,p2]) ==>
+propMergeIsCommutableAndCorrect :: Patch -> Patch -> Property
+propMergeIsCommutableAndCorrect p1 p2 =
+    (checkAPatch $ join_patches [invert p1,p2]) ==>
     case merge (p2:\/:p1) of
     p1' :/\: p2' ->
         case commute (p1:>p2') of
         Nothing -> False
         Just (p2'':>p1'') -> p2'' == p2 && p1' == p1''
-prop_merge_is_swapable :: Patch -> Patch -> Property
-prop_merge_is_swapable p1 p2 =
-    (check_a_patch $ join_patches [invert p1,p2]) ==>
+propMergeIsSwapable :: Patch -> Patch -> Property
+propMergeIsSwapable p1 p2 =
+    (checkAPatch $ join_patches [invert p1,p2]) ==>
     case merge (p2:\/:p1) of
     p1' :/\: p2' ->
            case merge (p1:\/:p2) of
            p2''' :/\: p1''' -> p1' == p1''' && p2' == p2'''
 
-prop_merge_valid :: Patch -> Patch -> Property
-prop_merge_valid p1 p2 =
-    (check_a_patch $ join_patches [invert p1,p2]) ==>
+propMergeValid :: Patch -> Patch -> Property
+propMergeValid p1 p2 =
+    (checkAPatch $ join_patches [invert p1,p2]) ==>
     case merge (p2:\/:p1) of
     _ :/\: p2' ->
-        check_a_patch $ join_patches [invert p1,p2,invert p2,p1,p2']
+        checkAPatch $ join_patches [invert p1,p2,invert p2,p1,p2']
 
-prop_simple_smart_merge_good_enough :: Patch -> Patch -> Property
-prop_simple_smart_merge_good_enough p1 p2 =
-    (check_a_patch $ join_patches [invert p1,p2]) ==>
-    smart_merge (p2:\/:p1) == simple_smart_merge (p2:\/:p1)
+propSimpleSmartMergeGoodEnough :: Patch -> Patch -> Property
+propSimpleSmartMergeGoodEnough p1 p2 =
+    (checkAPatch $ join_patches [invert p1,p2]) ==>
+    smartMerge (p2:\/:p1) == simpleSmartMerge (p2:\/:p1)
 
-smart_merge :: (Patch :\/: Patch) -> Maybe (Patch :< Patch)
-smart_merge (p1 :\/: p2) =
-  case simple_smart_merge (p1:\/:p2) of
+smartMerge :: (Patch :\/: Patch) -> Maybe (Patch :< Patch)
+smartMerge (p1 :\/: p2) =
+  case simpleSmartMerge (p1:\/:p2) of
   Nothing -> Nothing
   Just (p1'a:<p2a) ->
-      case simple_smart_merge (p2 :\/: p1) of
+      case simpleSmartMerge (p2 :\/: p1) of
       Nothing -> Nothing
       Just (x:<y) ->
         case commute (y:>x) of
@@ -439,8 +444,8 @@ smart_merge (p1 :\/: p2) =
           if p1'a == p1'b && p2a == p2b && p2a == p2
           then Just (p1'a :< p2)
           else Nothing
-simple_smart_merge :: (Patch :\/:  Patch) -> Maybe (Patch :< Patch)
-simple_smart_merge (p1 :\/: p2) =
+simpleSmartMerge :: (Patch :\/:  Patch) -> Maybe (Patch :< Patch)
+simpleSmartMerge (p1 :\/: p2) =
   case commute (invert p2 :> p1) of
   Just (p1':>_) ->
       case commute (p2:>p1') of
@@ -450,10 +455,10 @@ simple_smart_merge (p1 :\/: p2) =
       Nothing -> Nothing
   Nothing -> Nothing
 
-prop_elegant_merge_good_enough :: Patch -> Patch -> Property
-prop_elegant_merge_good_enough p1 p2 =
-    (check_a_patch $ join_patches [invert p1,p2]) ==>
-    (fst' `fmap` smart_merge (p2:\/:p1)) ==
+propElegantMergeGoodEnough :: Patch -> Patch -> Property
+propElegantMergeGoodEnough p1 p2 =
+    (checkAPatch $ join_patches [invert p1,p2]) ==>
+    (fst' `fmap` smartMerge (p2:\/:p1)) ==
        (snd'' `fmap` elegantMerge (p2:\/:p1))
 
 fst' :: p :< p -> p
@@ -474,42 +479,42 @@ instance Show p => Show (p :< p) where
 instance Show p => Show (p :> p) where
   show (x :> y) = show x ++ " :> " ++ show y
 
-test_patch :: String
-test_patch = test_str ++ test_note
+testPatch :: String
+testPatch = testStr ++ testNote
 tp1, tp2 :: Patch
 tp1 = unsafeUnseal . fst . fromJust . readPatch $ BC.pack "\nmove ./test/test ./hello\n"
 tp2 = unsafeUnseal . fst . fromJust . readPatch $ BC.pack "\nmove ./test ./hello\n"
 tp1', tp2' :: Patch
 tp2' = quickmerge (tp2:\/:tp1)
 tp1' = quickmerge (tp1:\/:tp2)
-test_note :: String
-test_note = (if commute (tp1:>tp2') == Just (tp2:>tp1')
+testNote :: String
+testNote = (if commute (tp1:>tp2') == Just (tp2:>tp1')
               then "At least they commutex right.\n"
               else "Argh! they don't even commutex right.\n")
-         ++(if check_a_patch $ tp2
+         ++(if checkAPatch $ tp2
               then "tp2 itself is valid!\n"
               else "Oh my! tp2 isn't even valid!\n")
-         ++(if check_a_patch $ tp2'
+         ++(if checkAPatch $ tp2'
               then "tp2' itself is valid!\n"
               else "Aaack! tp2' itself is invalid!\n")
-         ++(if check_a_patch $ join_patches [tp1, tp2']
+         ++(if checkAPatch $ join_patches [tp1, tp2']
               then "Valid merge tp2'!\n"
               else "Bad merge tp2'!\n")
-         ++ (if check_a_patch $ join_patches [tp2, tp1']
+         ++ (if checkAPatch $ join_patches [tp2, tp1']
               then "Valid merge tp1'!\n"
               else "Bad merge tp1'!\n")
-         ++ (if check_a_patch $ join_patches [tp2,tp1',invert tp2',invert tp1]
+         ++ (if checkAPatch $ join_patches [tp2,tp1',invert tp2',invert tp1]
               then "Both agree!\n"
               else "The two merges don't agree!\n")
-         ++ (if check_a_patch $ join_patches [invert tp2, tp1]
+         ++ (if checkAPatch $ join_patches [invert tp2, tp1]
               then "They should be mergable!\n"
               else "Wait a minute, these guys can't be merged!\n")
 tp :: Patch
 tp = tp1'
 
-test_str :: String
-test_str = "Patches are:\n"++(show tp)
-           ++(if check_a_patch tp
+testStr :: String
+testStr = "Patches are:\n"++(show tp)
+           ++(if checkAPatch tp
               then "At least the patch itself is valid.\n"
               else "The patch itself is bad!\n")
            ++"commute of tp2 and tp1' is "++show (commute (tp2:>tp1'))++"\n"
@@ -518,13 +523,13 @@ test_str = "Patches are:\n"++(show tp)
                   ++ (show $ mapFL (joinPatches.flattenFL.merger_equivalent) $ flattenFL tp)
            ++ "\n\nUnravelled, it gives:\n" ++ (show $ map unravel $ flatten tp)
            ++ "\n\nUnwound, it gives:\n" ++ (show $ mapFL unwind $ flattenFL tp)
-           ++(if check_a_patch (join_patches$ reverse $ unwind tp)
+           ++(if checkAPatch (join_patches$ reverse $ unwind tp)
               then "Unwinding is valid.\n"
               else "Bad unwinding!\n")
-           ++(if check_a_patch $ join_patches [tp,invert tp]
+           ++(if checkAPatch $ join_patches [tp,invert tp]
               then "Inverse is valid.\n"
               else "Bad inverse!\n")
-           ++(if check_a_patch $ join_patches [invert tp, tp]
+           ++(if checkAPatch $ join_patches [invert tp, tp]
               then "Other inverse is valid.\n"
               else "Bad other inverse!\n")-}
 
@@ -538,56 +543,56 @@ test_str = "Patches are:\n"++(show tp)
 -- unravel the merger, almost any function of the unravelled merger satisfies
 -- the two constraints mentioned above that the conflict resolution code must
 -- satisfy.
-prop_unravel_three_merge :: Patch -> Patch -> Patch -> Property
-prop_unravel_three_merge p1 p2 p3 =
-    (check_a_patch $ join_patches [invert p1,p2,invert p2,p3]) ==>
-    (unravel $ merger "0.0" (merger "0.0" p2 p3) (merger "0.0" p2 p1)) ==
-    (unravel $ merger "0.0" (merger "0.0" p1 p3) (merger "0.0" p1 p2))
+propUnravelThreeMerge :: Patch -> Patch -> Patch -> Property
+propUnravelThreeMerge p1 p2 p3 =
+    (checkAPatch $ join_patches [invert p1,p2,invert p2,p3]) ==>
+    (unravel $ unsafeUnseal $ merger "0.0" (unsafeUnseal (merger "0.0" p2 p3)) (unsafeUnseal (merger "0.0" p2 p1))) ==
+    (unravel $ unsafeUnseal $ merger "0.0" (unsafeUnseal (merger "0.0" p1 p3)) (unsafeUnseal (merger "0.0" p1 p2)))
 
-prop_unravel_seq_merge :: Patch -> Patch -> Patch -> Property
-prop_unravel_seq_merge p1 p2 p3 =
-    (check_a_patch $ join_patches [invert p1,p2,p3]) ==>
-    (unravel $ merger "0.0" p3 $ merger "0.0" p2 p1) ==
-    (unravel $ merger "0.0" (merger "0.0" p2 p1) p3)
+propUnravelSeqMerge :: Patch -> Patch -> Patch -> Property
+propUnravelSeqMerge p1 p2 p3 =
+    (checkAPatch $ join_patches [invert p1,p2,p3]) ==>
+    (unravel $ unsafeUnseal $ merger "0.0" p3 $ unsafeUnseal $ merger "0.0" p2 p1) ==
+    (unravel $ unsafeUnseal $ merger "0.0" (unsafeUnseal $ merger "0.0" p2 p1) p3)
 
-prop_unravel_order_independent :: Patch -> Patch -> Property
-prop_unravel_order_independent p1 p2 =
-    (check_a_patch $ join_patches [invert p1,p2]) ==>
-    (unravel $ merger "0.0" p2 p1) == (unravel $ merger "0.0" p1 p2)
+propUnravelOrderIndependent :: Patch -> Patch -> Property
+propUnravelOrderIndependent p1 p2 =
+    (checkAPatch $ join_patches [invert p1,p2]) ==>
+    (unravel $ unsafeUnseal $ merger "0.0" p2 p1) == (unravel $ unsafeUnseal $ merger "0.0" p1 p2)
 
-prop_resolve_conflicts_valid :: Patch -> Patch -> Property
-prop_resolve_conflicts_valid p1 p2 =
-    (check_a_patch $ join_patches [invert p1,p2]) ==>
-    and $ map (check_a_patch.(\l-> join_patches [p,merge_list l]))
+propResolveConflictsValid :: Patch -> Patch -> Property
+propResolveConflictsValid p1 p2 =
+    (checkAPatch $ join_patches [invert p1,p2]) ==>
+    and $ map (checkAPatch.(\l-> join_patches [p,mergeList l]))
             $ resolveConflicts p
         where p = case merge (p1:\/:p2) of
                   _ :/\: p1' -> join_patches [p2,p1']
 
-merge_list :: [Sealed (FL Prim C(x))] -> Patch
-merge_list patches = fromPrims `unseal` doml NilFL patches
+mergeList :: [Sealed (FL Prim C(x))] -> Patch
+mergeList patches = fromPrims `unseal` doml NilFL patches
     where doml mp (Sealed p:ps) =
               case commute (invert p :> mp) of
               Just (mp' :> _) -> doml (effect p +>+ effect mp') ps
               Nothing -> doml mp ps -- This shouldn't happen for "good" resolutions.
           doml mp [] = Sealed mp
 
-try_tok_possibly :: String -> String -> String
+tryTokPossibly :: String -> String -> String
                 -> (Maybe FileContents) -> (Maybe FileContents)
-try_tok_possibly t o n = liftM $ \contents ->
+tryTokPossibly t o n = liftM $ \contents ->
         let lines' = M.mapMaybe (liftM B.concat
-                                  . try_tok_internal t (BC.pack o) (BC.pack n))
-                                (fc_lines contents)
-        in contents { fc_lines = lines' }
+                                  . tryTokInternal t (BC.pack o) (BC.pack n))
+                                (fcLines contents)
+        in contents { fcLines = lines' }
 
-try_tok_internal :: String -> B.ByteString -> B.ByteString
+tryTokInternal :: String -> B.ByteString -> B.ByteString
                  -> B.ByteString -> Maybe [B.ByteString]
-try_tok_internal _ _ _ s | B.null s = Just []
-try_tok_internal t o n s =
+tryTokInternal _ _ _ s | B.null s = Just []
+tryTokInternal t o n s =
     case BC.break (regChars t) s of
     (before,s') ->
         case BC.break (not . regChars t) s' of
         (tok,after) ->
-            case try_tok_internal t o n after of
+            case tryTokInternal t o n after of
             Nothing -> Nothing
             Just rest ->
                 if tok == o
@@ -596,25 +601,25 @@ try_tok_internal t o n s =
                      then Nothing
                      else Just $ before : tok : rest
 
-prop_read_show :: Patch -> Bool
-prop_read_show p = case readPatch $ renderPS $ showPatch p of
+propReadShow :: Patch -> Bool
+propReadShow p = case readPatch $ renderPS $ showPatch p of
                    Just (Sealed p',_) -> p' == p
                    Nothing -> False
 
 -- |In order for merges to work right with commuted patches, inverting a patch
 -- past a patch and its inverse had golly well better give you the same patch
 -- back again.
-prop_commute_inverse :: Patch -> Patch -> Property
-prop_commute_inverse p1 p2 =
-    does_commute p1 p2 ==> case commute (p1 :> p2) of
+propCommuteInverse :: Patch -> Patch -> Property
+propCommuteInverse p1 p2 =
+    doesCommute p1 p2 ==> case commute (p1 :> p2) of
                            Nothing -> impossible
                            Just (_ :> p1') ->
                                case commute (p1' :> invert p2) of
                                Nothing -> False
                                Just (_ :> p1'') -> p1'' == p1
 
-subcommutes_inverse :: [(String, Prim -> Prim -> Property)]
-subcommutes_inverse = zip names (map prop_subcommute cs)
+subcommutesInverse :: [(String, Prim -> Prim -> Property)]
+subcommutesInverse = zip names (map prop_subcommute cs)
     where (names, cs) = unzip subcommutes
           prop_subcommute c p1 p2 =
               does c p1 p2 ==>
@@ -634,8 +639,8 @@ subcommutes_inverse = zip names (map prop_subcommute cs)
                   _ -> False
               _ -> False
 
-subcommutes_nontrivial_inverse :: [(String, Prim -> Prim -> Property)]
-subcommutes_nontrivial_inverse = zip names (map prop_subcommute cs)
+subcommutesNontrivialInverse :: [(String, Prim -> Prim -> Property)]
+subcommutesNontrivialInverse = zip names (map prop_subcommute cs)
     where (names, cs) = unzip subcommutes
           prop_subcommute c p1 p2 =
               nontrivial c p1 p2 ==>
@@ -655,28 +660,28 @@ subcommutes_nontrivial_inverse = zip names (map prop_subcommute cs)
                   _ -> False
               _ -> False
 
-subcommutes_failure :: [(String, Prim -> Prim -> Property)]
-subcommutes_failure = zip names (map prop cs)
+subcommutesFailure :: [(String, Prim -> Prim -> Property)]
+subcommutesFailure = zip names (map prop cs)
     where (names, cs) = unzip subcommutes
           prop c p1 p2 =
-              does_fail c p1 p2 ==> case c (invert p1 :< invert p2) of
+              doesFail c p1 p2 ==> case c (invert p1 :< invert p2) of
                                     Failed -> True
                                     _ -> False
 
-does_fail :: CommuteFunction -> Prim -> Prim -> Bool
-does_fail c p1 p2 =
-    fails (c (p2:<p1)) && (check_a_patch $ fromPrims $ unsafeFL [p1,p2])
+doesFail :: CommuteFunction -> Prim -> Prim -> Bool
+doesFail c p1 p2 =
+    fails (c (p2:<p1)) && (checkAPatch $ fromPrims (p1 :>: p2 :>: NilFL))
         where fails Failed = True
               fails _ = False
 
 does :: CommuteFunction -> Prim -> Prim -> Bool
 does c p1 p2 =
-    succeeds (c (p2:<p1)) && (check_a_patch $ fromPrims $ unsafeFL [p1,p2])
+    succeeds (c (p2:<p1)) && (checkAPatch $ fromPrims (p1 :>: p2 :>: NilFL))
         where succeeds (Succeeded _) = True
               succeeds _ = False
 
 nontrivial :: CommuteFunction -> Prim -> Prim -> Bool
 nontrivial c p1 p2 =
-    succeeds (c (p2:<p1)) && (check_a_patch $ fromPrims $ unsafeFL [p1,p2])
+    succeeds (c (p2:<p1)) && (checkAPatch $ fromPrims (p1 :>: p2 :>: NilFL))
         where succeeds (Succeeded (p1' :< p2')) = p1' /= p1 || p2' /= p2
               succeeds _ = False
