@@ -20,21 +20,21 @@
 
 #include "gadts.h"
 
-module Darcs.Test.Patch.Unit ( patch_unit_tests ) where
+module Darcs.Test.Patch.Unit ( patchUnitTests ) where
 
 import Data.Maybe ( catMaybes, isNothing )
 import qualified Data.ByteString.Char8 as BC ( pack )
 import Darcs.Witnesses.Sealed
 import Darcs.Patch
 import Darcs.Patch.Patchy ( mergeFL, Invert )
-import Darcs.Patch.Real ( RealPatch, prim2real, is_consistent, is_forward, is_duplicate )
+import Darcs.Patch.Real ( RealPatch, prim2real, isConsistent, isForward, isDuplicate )
 import Darcs.Test.Patch.Test () -- for instance Eq Patch
 import Darcs.Witnesses.Ordered
-import Darcs.Patch.Properties ( recommute, commute_inverses, permutivity, partial_permutivity,
-                                inverse_doesnt_commute, patch_and_inverse_commute,
-                                merge_commute, merge_consistent, merge_arguments_consistent,
-                                merge_either_way, show_read,
-                                join_inverses, join_commute )
+import Darcs.Patch.Properties ( recommute, commuteInverses, permutivity, partialPermutivity,
+                                inverseDoesntCommute, patchAndInverseCommute,
+                                mergeCommute, mergeConsistent, mergeArgumentsConsistent,
+                                mergeEitherWay, show_read,
+                                joinInverses, joinCommute )
 import Darcs.Patch.Prim ( join )
 import Darcs.Test.Patch.QuickCheck
 import Printer ( Doc, redText, ($$) )
@@ -51,56 +51,56 @@ import Test.Framework ( Test )
 -- #include "impossible.h"
 
 -- | The unit tests defined about patches
-patch_unit_tests :: [Test]
-patch_unit_tests = [--do putStr "Checking with quickcheck that real patches have consistent flattenings... "
-                    --   quickCheck (not . isBottomTimeOut (Just 10) . prop_consistent_tree_flattenings) >> return 0
-                    run_primitive_tests "prim join inverses" (\ (a:\/:_) -> join_inverses join a) mergeables,
-                    testProperty "Checking prim join inverses using QuickCheck... " (isNothing . join_inverses join),
-                    run_primitive_tests "prim inverse doesn't commute" (\ (a:\/:_) -> inverse_doesnt_commute a) mergeables,
+patchUnitTests :: [Test]
+patchUnitTests = [--do putStr "Checking with quickcheck that real patches have consistent flattenings... "
+                    --   quickCheck (not . isBottomTimeOut (Just 10) . propConsistentTreeFlattenings) >> return 0
+                    runPrimitiveTests "prim join inverses" (\ (a:\/:_) -> joinInverses join a) mergeables,
+                    testProperty "Checking prim join inverses using QuickCheck... " (isNothing . joinInverses join),
+                    runPrimitiveTests "prim inverse doesn't commute" (\ (a:\/:_) -> inverseDoesntCommute a) mergeables,
                     -- The following fails because of setpref patches...
                     --,do putStr "Checking prim inverse doesn't commute using QuickCheck... "
-                    --    simpleCheck (inverse_doesnt_commute :: Prim -> Maybe Doc)
-                    run_primitive_tests "join commute" (join_commute join) prim_permutables,
-                    testProperty "Checking prim join commute using QuickCheck... " (unseal2 (isNothing . join_commute join)),
-                    run_primitive_tests "prim recommute" (recommute commute) $ map mergeable2commutable mergeables,
-                    run_primitive_tests "prim patch and inverse commute" (patch_and_inverse_commute commute) $ map mergeable2commutable mergeables,
-                    run_primitive_tests "prim inverses commute" (commute_inverses commute) $ map mergeable2commutable mergeables,
+                    --    simpleCheck (inverseDoesntCommute :: Prim -> Maybe Doc)
+                    runPrimitiveTests "join commute" (joinCommute join) primPermutables,
+                    testProperty "Checking prim join commute using QuickCheck... " (unseal2 (isNothing . joinCommute join)),
+                    runPrimitiveTests "prim recommute" (recommute commute) $ map mergeable2commutable mergeables,
+                    runPrimitiveTests "prim patch and inverse commute" (patchAndInverseCommute commute) $ map mergeable2commutable mergeables,
+                    runPrimitiveTests "prim inverses commute" (commuteInverses commute) $ map mergeable2commutable mergeables,
                     --,do putStr "Checking prim recommute using QuickCheck... "
                     --    simpleCheck (recommute
                     --                 (commute :: Prim :> Prim
                     --                          -> Maybe (Prim :> Prim)))
-                    run_primitive_tests "FL prim recommute" (recommute commute) $ map mergeable2commutable mergeablesFL,
-                    run_primitive_tests "FL prim patch and inverse commute" (patch_and_inverse_commute commute) $ map mergeable2commutable mergeablesFL,
-                    run_primitive_tests "FL prim inverses commute" (commute_inverses commute) $ map mergeable2commutable mergeablesFL,
-                    run_primitive_tests "fails" (commute_fails commute) ([] :: [Prim :> Prim]),
-                    run_primitive_tests "read and show work on Prim" show_read prim_patches,
-                    run_primitive_tests "read and show work on RealPatch" show_read real_patches,
+                    runPrimitiveTests "FL prim recommute" (recommute commute) $ map mergeable2commutable mergeablesFL,
+                    runPrimitiveTests "FL prim patch and inverse commute" (patchAndInverseCommute commute) $ map mergeable2commutable mergeablesFL,
+                    runPrimitiveTests "FL prim inverses commute" (commuteInverses commute) $ map mergeable2commutable mergeablesFL,
+                    runPrimitiveTests "fails" (commuteFails commute) ([] :: [Prim :> Prim]),
+                    runPrimitiveTests "read and show work on Prim" show_read primPatches,
+                    runPrimitiveTests "read and show work on RealPatch" show_read realPatches,
                     testProperty "Checking that readPatch and showPatch work on RealPatch... "
                                  (isNothing . (unseal $ patchFromTree $ (show_read :: RealPatch -> Maybe Doc))),
                     testProperty "Checking that readPatch and showPatch work on FL RealPatch... "
                                  (isNothing . (unseal2 $ (show_read :: FL RealPatch -> Maybe Doc))),
-                    run_primitive_tests "example flattenings work"
-                                        (\x -> if prop_consistent_tree_flattenings x
+                    runPrimitiveTests "example flattenings work"
+                                        (\x -> if propConsistentTreeFlattenings x
                                                  then Nothing
                                                  else Just $ redText "oops")
-                                        real_patch_loop_examples,
-                    testProperty "Checking that tree flattenings are consistent... " prop_consistent_tree_flattenings,
+                                        realPatchLoopExamples,
+                    testProperty "Checking that tree flattenings are consistent... " propConsistentTreeFlattenings,
                     testProperty "Checking with quickcheck that real patches are consistent... "
-                                 (isNothing . (unseal $ patchFromTree $ is_consistent)),
-                    run_primitive_tests "real merge input consistent" (merge_arguments_consistent is_consistent) real_mergeables,
-                    run_primitive_tests "real merge input is forward" (merge_arguments_consistent is_forward) real_mergeables,
-                    run_primitive_tests "real merge output is forward" (merge_consistent is_forward) real_mergeables,
-                    run_primitive_tests "real merge output consistent" (merge_consistent is_consistent) real_mergeables,
-                    run_primitive_tests "real merge either way" merge_either_way real_mergeables,
-                    run_primitive_tests "real merge and commute" merge_commute real_mergeables,
+                                 (isNothing . (unseal $ patchFromTree $ isConsistent)),
+                    runPrimitiveTests "real merge input consistent" (mergeArgumentsConsistent isConsistent) realMergeables,
+                    runPrimitiveTests "real merge input is forward" (mergeArgumentsConsistent isForward) realMergeables,
+                    runPrimitiveTests "real merge output is forward" (mergeConsistent isForward) realMergeables,
+                    runPrimitiveTests "real merge output consistent" (mergeConsistent isConsistent) realMergeables,
+                    runPrimitiveTests "real merge either way" mergeEitherWay realMergeables,
+                    runPrimitiveTests "real merge and commute" mergeCommute realMergeables,
 
-                    run_primitive_tests "real recommute" (recommute commute) real_commutables,
-                    run_primitive_tests "real inverses commute" (commute_inverses commute) real_commutables,
-                    run_primitive_tests "real permutivity" (permutivity commute) $ filter (not_duplicatestriple) real_triples,
-                    run_primitive_tests "real partial permutivity" (partial_permutivity commute) $ filter (not_duplicatestriple) real_triples,
+                    runPrimitiveTests "real recommute" (recommute commute) realCommutables,
+                    runPrimitiveTests "real inverses commute" (commuteInverses commute) realCommutables,
+                    runPrimitiveTests "real permutivity" (permutivity commute) $ filter (notDuplicatestriple) realTriples,
+                    runPrimitiveTests "real partial permutivity" (partialPermutivity commute) $ filter (notDuplicatestriple) realTriples,
 
                     testProperty "Checking we can do merges using QuickCheck"
-                                 (isNothing . (prop_is_mergeable ::
+                                 (isNothing . (propIsMergeable ::
                                                 Sealed (WithStartState RepoModel (Tree Prim))
                                                 -> Maybe (Tree RealPatch C(x)))),
                     testProperty "Checking recommute using QuickCheck Tree generator"
@@ -114,13 +114,13 @@ patch_unit_tests = [--do putStr "Checking with quickcheck that real patches have
                                                  (commute :: RealPatch :> RealPatch
                                                           -> Maybe (RealPatch :> RealPatch))))),
                     testConditional "Checking nontrivial recommute"
-                                    (unseal $ commutePairFromTree $ nontrivial_reals)
+                                    (unseal $ commutePairFromTree $ nontrivialReals)
                                     (unseal $ commutePairFromTree $
                                      (recommute
                                       (commute :: RealPatch :> RealPatch
                                                -> Maybe (RealPatch :> RealPatch)))),
                     testConditional "Checking nontrivial recommute using TWFP"
-                                    (unseal $ commutePairFromTWFP $ nontrivial_reals)
+                                    (unseal $ commutePairFromTWFP $ nontrivialReals)
                                     (unseal $ commutePairFromTWFP $
                                       (recommute
                                        (commute :: RealPatch :> RealPatch
@@ -128,67 +128,67 @@ patch_unit_tests = [--do putStr "Checking with quickcheck that real patches have
 
                     testProperty "Checking inverses commute using QuickCheck Tree generator"
                                  (isNothing . (unseal $ commutePairFromTree $
-                                               (commute_inverses
+                                               (commuteInverses
                                                  (commute :: RealPatch :> RealPatch
                                                              -> Maybe (RealPatch :> RealPatch))))),
                     testProperty "Checking inverses commute using QuickCheck TWFP generator"
                                  (isNothing . (unseal $ commutePairFromTWFP $
-                                               (commute_inverses
+                                               (commuteInverses
                                                 (commute :: RealPatch :> RealPatch
                                                             -> Maybe (RealPatch :> RealPatch))))),
                     testConditional "Checking nontrivial inverses commute"
-                                    (unseal $ commutePairFromTree $ nontrivial_reals)
+                                    (unseal $ commutePairFromTree $ nontrivialReals)
                                     (unseal $ commutePairFromTree $
-                                     (commute_inverses
+                                     (commuteInverses
                                       (commute :: RealPatch :> RealPatch
                                                -> Maybe (RealPatch :> RealPatch)))),
                     testConditional "Checking nontrivial inverses commute using TWFP"
-                                    (unseal $ commutePairFromTWFP $ nontrivial_reals)
+                                    (unseal $ commutePairFromTWFP $ nontrivialReals)
                                     (unseal $ commutePairFromTWFP $
-                                     (commute_inverses
+                                     (commuteInverses
                                       (commute :: RealPatch :> RealPatch
                                                -> Maybe (RealPatch :> RealPatch)))),
 
                     testProperty "Checking merge either way using QuickCheck TWFP generator"
                                  (isNothing . (unseal $ mergePairFromTWFP $
-                                               (merge_either_way :: RealPatch :\/: RealPatch -> Maybe Doc))),
+                                               (mergeEitherWay :: RealPatch :\/: RealPatch -> Maybe Doc))),
                     testProperty "Checking merge either way using QuickCheck Tree generator"
                                  (isNothing . (unseal $ mergePairFromTree $
-                                               (merge_either_way :: RealPatch :\/: RealPatch -> Maybe Doc))),
+                                               (mergeEitherWay :: RealPatch :\/: RealPatch -> Maybe Doc))),
                     testConditional "Checking nontrivial merge either way"
-                                    (unseal $ mergePairFromTree $ nontrivial_merge_reals)
+                                    (unseal $ mergePairFromTree $ nontrivialMergeReals)
                                     (unseal $ mergePairFromTree $
-                                     (merge_either_way :: RealPatch :\/: RealPatch -> Maybe Doc)),
+                                     (mergeEitherWay :: RealPatch :\/: RealPatch -> Maybe Doc)),
                     testConditional "Checking nontrivial merge either way using TWFP"
-                                    (unseal $ mergePairFromTWFP $ nontrivial_merge_reals)
+                                    (unseal $ mergePairFromTWFP $ nontrivialMergeReals)
                                     (unseal $ mergePairFromTWFP $
-                                     (merge_either_way :: RealPatch :\/: RealPatch -> Maybe Doc)),
+                                     (mergeEitherWay :: RealPatch :\/: RealPatch -> Maybe Doc)),
 
                     testConditional "Checking permutivity"
-                                    (unseal $ commuteTripleFromTree not_duplicatestriple)
+                                    (unseal $ commuteTripleFromTree notDuplicatestriple)
                                     (unseal $ commuteTripleFromTree $ permutivity
                                             (commute :: RealPatch :> RealPatch -> Maybe (RealPatch :> RealPatch))),
                     testConditional "Checking partial permutivity"
-                                    (unseal $ commuteTripleFromTree not_duplicatestriple)
-                                    (unseal $ commuteTripleFromTree $ partial_permutivity
+                                    (unseal $ commuteTripleFromTree notDuplicatestriple)
+                                    (unseal $ commuteTripleFromTree $ partialPermutivity
                                             (commute :: RealPatch :> RealPatch -> Maybe (RealPatch :> RealPatch))),
                     testConditional "Checking nontrivial permutivity"
                                     (unseal $ commuteTripleFromTree
-                                               (\t -> nontrivial_triple t && not_duplicatestriple t))
+                                               (\t -> nontrivialTriple t && notDuplicatestriple t))
                                     (unseal $ commuteTripleFromTree $
                                       (permutivity
                                        (commute :: RealPatch :> RealPatch
                                                 -> Maybe (RealPatch :> RealPatch))))
                    ]
 
-not_duplicatestriple :: RealPatch :> RealPatch :> RealPatch -> Bool
-not_duplicatestriple (a :> b :> c) = not $ any is_duplicate [a,b,c]
+notDuplicatestriple :: RealPatch :> RealPatch :> RealPatch -> Bool
+notDuplicatestriple (a :> b :> c) = not $ any isDuplicate [a,b,c]
 
 --not_duplicates_pair :: RealPatch :> RealPatch -> Bool
---not_duplicates_pair (a :> b) = not $ any is_duplicate [a,b]
+--not_duplicates_pair (a :> b) = not $ any isDuplicate [a,b]
 
-nontrivial_triple :: RealPatch :> RealPatch :> RealPatch -> Bool
-nontrivial_triple (a :> b :> c) =
+nontrivialTriple :: RealPatch :> RealPatch :> RealPatch -> Bool
+nontrivialTriple (a :> b :> c) =
     case commute (a :> b) of
     Nothing -> False
     Just (b' :> a') ->
@@ -201,30 +201,30 @@ nontrivial_triple (a :> b :> c) =
                             (not (c' `unsafeCompare` c) || not (b'' `unsafeCompare` b)) &&
                             (not (c'' `unsafeCompare` c) || not (a'' `unsafeCompare` a'))
 
-nontrivial_reals :: RealPatch :> RealPatch -> Bool
-nontrivial_reals = nontrivial_commute
+nontrivialReals :: RealPatch :> RealPatch -> Bool
+nontrivialReals = nontrivialCommute
 
-nontrivial_commute :: Patchy p => p :> p -> Bool
-nontrivial_commute (x :> y) = case commute (x :> y) of
+nontrivialCommute :: Patchy p => p :> p -> Bool
+nontrivialCommute (x :> y) = case commute (x :> y) of
                               Just (y' :> x') -> not (y' `unsafeCompare` y) ||
                                                  not (x' `unsafeCompare` x)
                               Nothing -> False
 
-nontrivial_merge_reals :: RealPatch :\/: RealPatch -> Bool
-nontrivial_merge_reals = nontrivial_merge
+nontrivialMergeReals :: RealPatch :\/: RealPatch -> Bool
+nontrivialMergeReals = nontrivialMerge
 
-nontrivial_merge :: Patchy p => p :\/: p -> Bool
-nontrivial_merge (x :\/: y) = case merge (x :\/: y) of
+nontrivialMerge :: Patchy p => p :\/: p -> Bool
+nontrivialMerge (x :\/: y) = case merge (x :\/: y) of
                               y' :/\: x' -> not (y' `unsafeCompare` y) ||
                                             not (x' `unsafeCompare` x)
 
 -- | Run a test function on a set of data, using HUnit. The test function should
 --   return @Nothing@ upon success and a @Just x@ upon failure.
-run_primitive_tests :: (Show a, Show b) => String         -- ^ The test name
+runPrimitiveTests :: (Show a, Show b) => String         -- ^ The test name
                                         -> (a -> Maybe b) -- ^ The test function
                                         -> [a]            -- ^ The test data
                                         -> Test
-run_primitive_tests name test datas = testCase name (assertBool assertName res)
+runPrimitiveTests name test datas = testCase name (assertBool assertName res)
     where assertName = "Boolean assertion for \"" ++ name ++ "\""
           res        = and $ map (isNothing . test) datas
 
@@ -232,8 +232,8 @@ quickhunk :: Int -> String -> String -> Prim
 quickhunk l o n = hunk "test" l (map (\c -> BC.pack [c]) o)
                                 (map (\c -> BC.pack [c]) n)
 
-prim_permutables :: [Prim :> Prim :> Prim]
-prim_permutables =
+primPermutables :: [Prim :> Prim :> Prim]
+primPermutables =
     [quickhunk 0 "e" "bo" :> quickhunk 3 "" "x" :> quickhunk 2 "f" "qljo"]
 
 mergeables :: [Prim :\/: Prim]
@@ -255,17 +255,18 @@ mergeablesFL = map (\ (x:\/:y) -> (x :>: NilFL) :\/: (y :>: NilFL)) mergeables +
 mergeable2commutable :: Invert p => p :\/: p -> p :> p
 mergeable2commutable (x :\/: y) = invert x :> y
 
-prim_patches :: [Prim]
-prim_patches = concatMap mergeable2patches mergeables
+primPatches :: [Prim]
+primPatches = concatMap mergeable2patches mergeables
     where mergeable2patches (x:\/:y) = [x,y]
 
-real_patches :: [RealPatch]
-real_patches = concatMap commutable2patches real_commutables
+realPatches :: [RealPatch]
+realPatches = concatMap commutable2patches realCommutables
     where commutable2patches (x:>y) = [x,y]
 
-real_triples :: [RealPatch :> RealPatch :> RealPatch]
-real_triples = [ob' :> oa2 :> a2'',
-                oa' :> oa2 :> a2''] ++ triple_examples
+realTriples :: [RealPatch :> RealPatch :> RealPatch]
+realTriples = [ob' :> oa2 :> a2'',
+                oa' :> oa2 :> a2'']
+               ++ map unsafeUnseal2 tripleExamples
                ++ map unsafeUnseal2 (concatMap getTriples realFLs)
     where oa = prim2real $ quickhunk 1 "o" "aa"
           oa2 = oa
@@ -280,18 +281,19 @@ realFLs = [oa :>: invert oa :>: oa :>: invert oa :>: ps +>+ oa :>: invert oa :>:
     where oa = prim2real $ quickhunk 1 "o" "a"
           ps :/\: _ = merge (oa :>: invert oa :>: NilFL :\/: oa :>: invert oa :>: NilFL)
 
-real_commutables :: [RealPatch :> RealPatch]
-real_commutables = commute_examples ++ map mergeable2commutable real_mergeables++
+realCommutables :: [RealPatch :> RealPatch]
+realCommutables = map unsafeUnseal2 commuteExamples++
+                   map mergeable2commutable realMergeables++
                    [invert oa :> ob'] ++ map unsafeUnseal2 (concatMap getPairs realFLs)
     where oa = prim2real $ quickhunk 1 "o" "a"
           ob = prim2real $ quickhunk 1 "o" "b"
           _ :/\: ob' = mergeFL (ob :\/: oa :>: invert oa :>: NilFL)
 
-real_mergeables :: [RealPatch :\/: RealPatch]
-real_mergeables = map (\ (x :\/: y) -> prim2real x :\/: prim2real y) mergeables
-                        ++ real_igloo_mergeables
-                        ++ real_quickcheck_mergeables
-                        ++ merge_examples
+realMergeables :: [RealPatch :\/: RealPatch]
+realMergeables = map (\ (x :\/: y) -> prim2real x :\/: prim2real y) mergeables
+                        ++ realIglooMergeables
+                        ++ realQuickcheckMergeables
+                        ++ map unsafeUnseal2 mergeExamples
                         ++ catMaybes (map pair2m (concatMap getPairs realFLs))
                         ++ [(oa :\/: od),
                             (oa :\/: a2'),
@@ -335,8 +337,8 @@ real_mergeables = map (\ (x :\/: y) -> prim2real x :\/: prim2real y) mergeables
           pair2m (Sealed2 (xx :> y)) = do y' :> _ <- commute (xx :> y)
                                           return (xx :\/: y')
 
-real_igloo_mergeables :: [RealPatch :\/: RealPatch]
-real_igloo_mergeables = [(a :\/: b),
+realIglooMergeables :: [RealPatch :\/: RealPatch]
+realIglooMergeables = [(a :\/: b),
                     (b :\/: c),
                     (a :\/: c),
                     (x :\/: a),
@@ -356,8 +358,8 @@ real_igloo_mergeables = [(a :\/: b),
           y' :/\: _ = merge (b :\/: y)
           z' :/\: _ = merge (c :\/: z)
 
-real_quickcheck_mergeables :: [RealPatch :\/: RealPatch]
-real_quickcheck_mergeables = [-- invert k1 :\/: n1
+realQuickcheckMergeables :: [RealPatch :\/: RealPatch]
+realQuickcheckMergeables = [-- invert k1 :\/: n1
                              --, invert k2 :\/: n2
                                hb :\/: k
                              , b' :\/: b'
@@ -388,9 +390,9 @@ real_quickcheck_mergeables = [-- invert k1 :\/: n1
           d3 :/\: _ = merge (xi :\/: d)
           _ :/\: k3 = mergeFL (k :\/: i :>: x :>: xi :>: d3 :>: NilFL)
 
-commute_fails :: (MyEq p, Patchy p) => (p :> p -> Maybe (p :> p)) -> p :> p
+commuteFails :: (MyEq p, Patchy p) => (p :> p -> Maybe (p :> p)) -> p :> p
               -> Maybe Doc
-commute_fails c (x :> y) = do y' :> x' <- c (x :> y)
+commuteFails c (x :> y) =  do y' :> x' <- c (x :> y)
                               return $ redText "x" $$ showPatch x $$
                                        redText ":> y" $$ showPatch y $$
                                        redText "y'" $$ showPatch y' $$
