@@ -7,22 +7,25 @@ module Darcs.Utils ( catchall, ortryrunning, nubsort, breakCommand,
                     putStrLnError, putDocLnError,
                     withCurrentDirectory,
                     withUMask, askUser, stripCr,
-                    showHexLen, add_to_error_loc,
+                    showHexLen, addToErrorLoc,
                     maybeGetEnv, firstNotBlank, firstJustM, firstJustIO,
-                    isUnsupportedOperationError, isHardwareFaultError,
-                    get_viewer, edit_file, run_editor,
-                    promptYorn, promptCharFancy,
+                    getViewer, editFile, runEditor,
+                    PromptConfig(..), promptYorn, promptChar,
                     environmentHelpEditor, environmentHelpPager,
-                    formatPath
+                    formatPath,
+                    isFileReallySymlink, doesDirectoryReallyExist, doesFileReallyExist
+
                     -- * Tree filtering.
                    , filterFilePaths, filterPaths
+                    -- * Tree lookup.
+                   , treeHas, treeHasDir, treeHasFile, treeHasAnycase
                    ) where
 
 import Prelude hiding ( catch )
-import Control.Exception ( bracket, bracket_, catch, Exception(IOException), try )
-import GHC.IOBase ( IOException(ioe_location),
-                    IOErrorType(UnsupportedOperation, HardwareFault) )
-import System.IO.Error ( isUserError, ioeGetErrorType, ioeGetErrorString )
+import Control.Exception.Extensible
+             ( bracket, bracket_, catch, try,
+               IOException, SomeException, Exception(fromException) )
+import System.IO.Error ( annotateIOError, isUserError, ioeGetErrorString )
 
 import Darcs.SignalHandler ( catchNonSignal )
 import Numeric ( showHex )
@@ -30,49 +33,41 @@ import System.Directory ( doesFileExist )
 import System.Exit ( exitWith, ExitCode(..) )
 import System.Environment ( getEnv )
 import System.IO ( hPutStrLn, stderr )
-import Data.Char ( toUpper )
+import Data.Char ( toUpper, toLower )
 import Darcs.RepoPath ( FilePathLike, getCurrentDirectory, setCurrentDirectory, toFilePath )
 import Data.Maybe ( listToMaybe, isJust )
 import Data.List ( group, sort )
-import Control.Monad ( when )
-import Exec ( exec_interactive )
+import Control.Monad ( when, forM )
+import Control.Monad.Error( catchError, MonadError )
+import Exec ( execInteractive )
 import Printer ( Doc, hPutDocLn )
 import Foreign.C.String ( CString, withCString )
 import Foreign.C.Error ( throwErrno )
 import Foreign.C.Types ( CInt )
 
-import Progress ( withoutProgress )
+import qualified Data.ByteString.Char8 as BSC
 
-import Storage.Hashed.AnchoredPath( AnchoredPath, isPrefix, floatPath )
+import System.Posix.Files( getSymbolicLinkStatus, isRegularFile, isDirectory, isSymbolicLink )
+
+import Progress ( withoutProgress )
 
 import System.Console.Haskeline ( runInputT, defaultSettings, getInputLine,
                                   getInputChar, outputStrLn )
-import System.Console.Haskeline.Encoding ( encode )
 import qualified Data.ByteString as B ( readFile )
-import qualified Data.ByteString.Char8 as B ( unpack )
+
+import Control.Monad.State.Strict( gets )
+import Storage.Hashed.AnchoredPath( AnchoredPath(..), Name(..), isPrefix, floatPath )
+import Storage.Hashed.Monad( withDirectory, fileExists, exists, directoryExists
+                           , virtualTreeMonad, currentDirectory
+                           , TreeMonad, tree )
+import Storage.Hashed.Tree( Tree, listImmediate, findTree )
 
 showHexLen :: (Integral a) => Int -> a -> String
 showHexLen n x = let s = showHex x ""
                  in replicate (n - length s) ' ' ++ s
 
-add_to_error_loc :: Exception -> String -> Exception
-add_to_error_loc (IOException ioe) s
-    = IOException $ ioe { ioe_location = s ++ ": " ++ ioe_location ioe }
-add_to_error_loc e _ = e
-
-isUnsupportedOperationError :: IOError -> Bool
-isUnsupportedOperationError = isUnsupportedOperationErrorType . ioeGetErrorType
-
-isUnsupportedOperationErrorType :: IOErrorType -> Bool
-isUnsupportedOperationErrorType UnsupportedOperation = True
-isUnsupportedOperationErrorType _ = False
-
-isHardwareFaultError :: IOError -> Bool
-isHardwareFaultError = isHardwareFaultErrorType . ioeGetErrorType
-
-isHardwareFaultErrorType :: IOErrorType -> Bool
-isHardwareFaultErrorType HardwareFault = True
-isHardwareFaultErrorType _ = False
+addToErrorLoc :: IOException -> String -> IOException
+addToErrorLoc ioe s = annotateIOError ioe s Nothing Nothing
 
 catchall :: IO a -> IO a -> IO a
 a `catchall` b = a `catchNonSignal` (\_ -> b)
@@ -100,8 +95,8 @@ firstJustIO = firstJustM . map (\o -> o `catchall` return Nothing)
 clarifyErrors :: IO a -> String -> IO a
 clarifyErrors a e = a `catch` (\x -> fail $ unlines [prettyException x,e])
 
-prettyException :: Control.Exception.Exception -> String
-prettyException (IOException e) | isUserError e = ioeGetErrorString e
+prettyException :: SomeException -> String
+prettyException e | Just ioe <- fromException e, isUserError ioe = ioeGetErrorString ioe
 prettyException e = show e
 
 prettyError :: IOError -> String
@@ -120,7 +115,7 @@ a `ortryrunning` b = do
     (Right (ExitFailure 126)) -> b -- command not executable
     (Right (ExitFailure 127)) -> b -- command not found
     (Right x) -> return x          -- legitimate success/failure
-    (Left _) -> b                  -- an exception
+    (Left (_ :: SomeException)) -> b  -- an exception
 
 putStrLnError :: String -> IO ()
 putStrLnError = hPutStrLn stderr
@@ -151,13 +146,12 @@ withUMask umask job =
            (reset_umask rc)
            job
 
-askUser :: String -> IO String
+-- | Ask the user for a line of input.
+askUser :: String    -- ^ The prompt to display
+        -> IO String -- ^ The string the user entered.
 askUser prompt = withoutProgress $ runInputT defaultSettings $
                     getInputLine prompt
                         >>= maybe (error "askUser: unexpected end of input") return
-            -- Return the input as encoded, 8-bit Chars (same as the
-            -- non-Haskeline backend).
-                        >>= fmap B.unpack . encode
 
 stripCr :: String -> String
 stripCr ""     = ""
@@ -188,10 +182,10 @@ nubsort :: Ord a => [a] -> [a]
 nubsort = map head . group . sort
 
 
-edit_file :: FilePathLike p => p -> IO ExitCode
-edit_file ff = do
+editFile :: FilePathLike p => p -> IO ExitCode
+editFile ff = do
   old_content <- file_content
-  ec <- run_editor f
+  ec <- runEditor f
   new_content <- file_content
   when (new_content == old_content) $ do
     yorn <- promptYorn "File content did not change. Continue anyway?"
@@ -205,19 +199,19 @@ edit_file ff = do
                                 return $ Just content
                         else return Nothing
 
-run_editor :: FilePath -> IO ExitCode
-run_editor f = do
-  ed <- get_editor
-  exec_interactive ed f
-       `ortryrunning` exec_interactive "emacs" f
-       `ortryrunning` exec_interactive "emacs -nw" f
-       `ortryrunning` exec_interactive "nano" f
+runEditor :: FilePath -> IO ExitCode
+runEditor f = do
+  ed <- getEditor
+  execInteractive ed f
+       `ortryrunning` execInteractive "emacs" f
+       `ortryrunning` execInteractive "emacs -nw" f
+       `ortryrunning` execInteractive "nano" f
 #ifdef WIN32
-       `ortryrunning` exec_interactive "edit" f
+       `ortryrunning` execInteractive "edit" f
 #endif
 
-get_editor :: IO String
-get_editor = getEnv "DARCS_EDITOR" `catchall`
+getEditor :: IO String
+getEditor = getEnv "DARCS_EDITOR" `catchall`
              getEnv "DARCSEDITOR" `catchall`
              getEnv "VISUAL" `catchall`
              getEnv "EDITOR" `catchall` return "vi"
@@ -231,8 +225,8 @@ environmentHelpEditor = (["DARCS_EDITOR", "DARCSEDITOR", "VISUAL", "EDITOR"],[
  "found in your PATH, emacs, emacs -nw, nano and (on Windows) edit are",
  "each tried in turn."])
 
-get_viewer :: IO String
-get_viewer = getEnv "DARCS_PAGER" `catchall`
+getViewer :: IO String
+getViewer = getEnv "DARCS_PAGER" `catchall`
              getEnv "PAGER" `catchall` return "less"
 
 environmentHelpPager :: ([String], [String])
@@ -241,26 +235,36 @@ environmentHelpPager = (["DARCS_PAGER", "PAGER"],[
  "to fit onscreen.  Darcs will use the pager specified by $DARCS_PAGER",
  "or $PAGER.  If neither are set, `less' will be used."])
 
-promptYorn :: [Char] -> IO Char
-promptYorn p = promptCharFancy p "yn" Nothing []
+data PromptConfig = PromptConfig { pPrompt :: String
+                                 , pBasicCharacters :: [Char]
+                                 , pAdvancedCharacters :: [Char] -- ^ only shown on help
+                                 , pDefault :: Maybe Char
+                                 , pHelp    :: [Char]
+                                 }
 
-promptCharFancy :: String -> [Char] -> Maybe Char -> [Char] -> IO Char
-promptCharFancy p chs md help_chs = withoutProgress $ runInputT defaultSettings $
-                                        loopChar
+promptYorn :: [Char] -> IO Char
+promptYorn p = promptChar (PromptConfig p "yn" [] Nothing [])
+
+promptChar :: PromptConfig -> IO Char
+promptChar (PromptConfig p basic_chs adv_chs md help_chs) =
+  withoutProgress $ runInputT defaultSettings $ loopChar
  where
+ chs = basic_chs ++ adv_chs
  loopChar = do
-    let prompt = p ++ " [" ++ setDefault chs ++ "]" ++ helpStr
-    a <- getInputChar prompt >>= maybe (error "promptCharFancy: unexpected end of input")
+    let chars = setDefault (basic_chs ++ (if null adv_chs then "" else "..."))
+        prompt = p ++ " [" ++ chars ++ "]" ++ helpStr
+    a <- getInputChar prompt >>= maybe (error "promptChar: unexpected end of input")
                                     return
-    case () of 
+    case () of
      _ | a `elem` chs                   -> return a
-       | a == ' ' -> case md of Nothing -> tryAgain 
+       | a == ' ' -> case md of Nothing -> tryAgain
                                 Just d  -> return d
        | a `elem` help_chs              -> return a
        | otherwise                      -> tryAgain
  helpStr = case help_chs of
-           []    -> ""
-           (h:_) -> ", or " ++ (h:" for help: ")
+           []                      -> ""
+           (h:_) | null adv_chs    -> ", or " ++ (h:" for help: ")
+                 | otherwise       -> ", or " ++ (h:" for more options: ")
  tryAgain = do outputStrLn "Invalid response, try again!"
                loopChar
  setDefault s = case md of Nothing -> s
@@ -279,3 +283,39 @@ filterPaths files =
 filterFilePaths :: [FilePath] -> AnchoredPath -> t -> Bool
 filterFilePaths = filterPaths . map floatPath
 
+-- Huh?
+isFileReallySymlink :: FilePath -> IO Bool
+isFileReallySymlink f = do fs <- getSymbolicLinkStatus f
+                           return (isSymbolicLink fs)
+
+doesFileReallyExist :: FilePath -> IO Bool
+doesFileReallyExist f = do fs <- getSymbolicLinkStatus f
+                           return (isRegularFile fs)
+
+doesDirectoryReallyExist :: FilePath -> IO Bool
+doesDirectoryReallyExist f = do fs <- getSymbolicLinkStatus f
+                                return (isDirectory fs)
+
+treeHasAnycase :: (MonadError e m, Functor m, Monad m) => Tree m -> FilePath -> m Bool
+treeHasAnycase tree path = fst `fmap` virtualTreeMonad (existsAnycase $ floatPath path) tree
+
+existsAnycase :: (MonadError e m, Functor m, Monad m) => AnchoredPath -> TreeMonad m Bool
+existsAnycase (AnchoredPath []) = return True
+existsAnycase (AnchoredPath (Name x:xs)) =
+  do wd <- currentDirectory
+     Just tree <- gets (flip findTree wd . tree)
+     let subs = [ AnchoredPath [Name n] | (Name n, _) <- listImmediate tree,
+                                          BSC.map toLower n == BSC.map toLower x ]
+     or `fmap` forM subs (\path -> do
+       file <- fileExists path
+       if file then return True
+               else withDirectory path (existsAnycase $ AnchoredPath xs))
+
+treeHas :: (MonadError e m, Functor m, Monad m) => Tree m -> FilePath -> m Bool
+treeHas tree path = fst `fmap` virtualTreeMonad (exists $ floatPath path) tree
+
+treeHasDir :: (MonadError e m, Functor m, Monad m) => Tree m -> FilePath -> m Bool
+treeHasDir tree path = fst `fmap` virtualTreeMonad (directoryExists $ floatPath path) tree
+
+treeHasFile :: (MonadError e m, Functor m, Monad m) => Tree m -> FilePath -> m Bool
+treeHasFile tree path = fst `fmap` virtualTreeMonad (fileExists $ floatPath path) tree
