@@ -74,3 +74,7 @@ intersperseLast _ _ [] = ""
 intersperseLast _ _ [clause] = clause
 intersperseLast sep sepLast clauses =
     concat (intersperse sep $ init clauses) ++ sepLast ++ last clauses
+
+presentParticiple :: String -> String
+presentParticiple v | last v == 'e' = init v ++ "ing"
+                     | otherwise = v ++ "ing"
