@@ -20,7 +20,7 @@
 module IsoDate ( getIsoDateTime, readLocalDate, readUTCDate,
                  parseDate, getLocalTz,
                  englishDateTime, englishInterval, englishLast,
-                 iso8601_interval, iso8601_duration,
+                 iso8601Interval, iso8601Duration,
                  cleanLocalDate, resetCalendar,
                  MCalendarTime(..), subtractFromMCal, addToMCal,
                  toMCalendarTime, unsafeToCalendarTime,
@@ -71,7 +71,7 @@ readDate tz d =
 
 -- | Parse a date string, assuming a default timezone if
 --   the date string does not specify one.  The date formats
---   understood are those of 'showIsoDateTime' and 'date_time'
+--   understood are those of 'showIsoDateTime' and 'dateTime'
 parseDate :: Int -> String -> Either ParseError MCalendarTime
 parseDate tz d =
               if length d >= 14 && B.all isDigit bd
@@ -84,7 +84,7 @@ parseDate tz d =
                                 (readI $ B.take 2 $ B.drop 12 bd) -- Second
                                 0 Sunday 0 -- Picosecond, weekday and day of year unknown
                                 "GMT" 0 False
-              else let dt = do { x <- date_time tz; eof; return x }
+              else let dt = do { x <- dateTime tz; eof; return x }
                    in parse dt "" d
   where bd = B.pack (take 14 d)
         readI s = fst $ fromMaybe (error "parseDate: invalid date") (B.readInt s)
@@ -138,54 +138,54 @@ manyNtoM n m p
 
 -- | Try each of these date parsers in the following order
 --
---    (1) 'cvs_date_time'
+--    (1) 'cvsDateTime'
 --
---    (2) 'iso8601_date_time'
+--    (2) 'iso8601DateTime'
 --
---    (3) 'old_date_time
-date_time :: Int -> CharParser a MCalendarTime
-date_time tz =
-            choice [try $ toMCalendarTime `fmap` cvs_date_time tz,
-                    try $ iso8601_date_time tz,
-                    toMCalendarTime `fmap` old_date_time]
+--    (3) 'oldDateTime
+dateTime :: Int -> CharParser a MCalendarTime
+dateTime tz =
+            choice [try $ toMCalendarTime `fmap` cvsDateTime tz,
+                    try $ iso8601DateTime tz,
+                    toMCalendarTime `fmap` oldDateTime]
 
 -- | CVS-style date/times, e.g.
 --   2007/08/25 14:25:39 GMT
 --   Note that time-zones are optional here.
-cvs_date_time :: Int -> CharParser a CalendarTime
-cvs_date_time tz =
+cvsDateTime :: Int -> CharParser a CalendarTime
+cvsDateTime tz =
                 do y <- year
                    char '/'
-                   mon <- month_num 
+                   mon <- monthNum
                    char '/'
                    d <- day
-                   my_spaces
+                   mySpaces
                    h <- hour
                    char ':'
                    m <- minute
                    char ':'
                    s <- second
-                   z <- option tz $ my_spaces >> zone
+                   z <- option tz $ mySpaces >> zone
                    return (CalendarTime y mon d h m s 0 Monday 0 "" z False)
 
 -- | \"Old\"-style dates, e.g.
 --   Tue Jan 3 14:08:07 EST 1999
 -- darcs-doc: Question (what does the "old" stand for really?)
-old_date_time   :: CharParser a CalendarTime
-old_date_time    = do wd <- day_name
-                      my_spaces
-                      mon <- month_name
-                      my_spaces
+oldDateTime   :: CharParser a CalendarTime
+oldDateTime      = do wd <- dayName
+                      mySpaces
+                      mon <- monthName
+                      mySpaces
                       d <- day
-                      my_spaces
+                      mySpaces
                       h <- hour
                       char ':'
                       m <- minute
                       char ':'
                       s <- second
-                      my_spaces
+                      mySpaces
                       z <- zone
-                      my_spaces
+                      mySpaces
                       y <- year
                       return (CalendarTime y mon d h m s 0 wd 0 "" z False)
 
@@ -195,7 +195,7 @@ old_date_time    = do wd <- day_name
 --
 --      * years > 9999
 --
---      * truncated representations with implied century (89 for 1989) 
+--      * truncated representations with implied century (89 for 1989)
 --
 --   I have not implemented:
 --
@@ -209,17 +209,17 @@ old_date_time    = do wd <- day_name
 --
 --      * the difference between 24h and 0h
 --
---      * allows stuff like 2005-1212; either you use the hyphen all the way 
+--      * allows stuff like 2005-1212; either you use the hyphen all the way
 --        (2005-12-12) or you don't use it at all (20051212), but you don't use
 --        it halfway, likewise with time
 --
 --      * No bounds checking whatsoever on intervals!
 --        (next action: read iso doc to see if bounds-checking required?) -}
-iso8601_date_time   :: Int -> CharParser a MCalendarTime
-iso8601_date_time localTz = try $ 
-  do d <- iso8601_date
-     t <- option id $ try $ do optional $ oneOf " T" 
-                               iso8601_time  
+iso8601DateTime   :: Int -> CharParser a MCalendarTime
+iso8601DateTime localTz = try $
+  do d <- iso8601Date
+     t <- option id $ try $ do optional $ oneOf " T"
+                               iso8601Time
      return $ t $ d { mctTZ = Just localTz }
 
 -- | Three types of ISO 8601 date:
@@ -229,14 +229,14 @@ iso8601_date_time localTz = try $
 --     * week+day in year, e.g.,  1997-W32-4
 --
 --     * day in year, e.g, 1997-273
-iso8601_date :: CharParser a MCalendarTime
-iso8601_date = 
+iso8601Date :: CharParser a MCalendarTime
+iso8601Date =
   do d <- calendar_date <|> week_date <|> ordinal_date
      return $ foldr ($) nullMCalendar d
-  where 
+  where
     calendar_date = -- yyyy-mm-dd
       try $ do d <- optchain year_ [ (dash, month_), (dash, day_) ]
-               -- allow other variants to be parsed correctly 
+               -- allow other variants to be parsed correctly
                notFollowedBy (digit <|> char 'W')
                return d
     week_date = --yyyy-Www-d
@@ -244,8 +244,8 @@ iso8601_date =
                optional dash
                char 'W'
                -- offset human 'week 1' -> computer 'week 0'
-               w'  <- (\x -> x-1) `liftM` two_digits
-               mwd  <- option Nothing $ do { optional dash; Just `fmap` n_digits 1 }
+               w'  <- (\x -> x-1) `liftM` twoDigits
+               mwd  <- option Nothing $ do { optional dash; Just `fmap` nDigits 1 }
                let y = resetCalendar . unsafeToCalendarTime . yfn $ nullMCalendar { mctDay = Just 1 }
                    firstDay = ctWDay y
                -- things that make this complicated
@@ -263,33 +263,33 @@ iso8601_date =
     ordinal_date = -- yyyy-ddd
       try $ optchain year_ [ (dash, yearDay_) ]
     --
-    year_  = try $ do y <- four_digits <?> "year (0000-9999)"
+    year_  = try $ do y <- fourDigits <?> "year (0000-9999)"
                       return $ \c -> c { mctYear = Just y }
-    month_ = try $ do m <- two_digits <?> "month (1 to 12)"
+    month_ = try $ do m <- twoDigits <?> "month (1 to 12)"
                       return $ \c -> c { mctMonth = Just $ intToMonth m }
-    day_   = try $ do d <- two_digits <?> "day in month (1 to 31)"
+    day_   = try $ do d <- twoDigits <?> "day in month (1 to 31)"
                       return $ \c -> c { mctDay = Just d }
-    yearDay_ = try $ do d <- n_digits 3 <?> "day in year (001 to 366)"
+    yearDay_ = try $ do d <- nDigits 3 <?> "day in year (001 to 366)"
                         return $ \c -> c { mctDay = Just d
                                          , mctYDay = Just (d - 1) }
     dash = char '-'
 
 -- | Note that this returns a function which sets the time on
---   another calendar (see 'iso8601_date_time' for a list of
+--   another calendar (see 'iso8601DateTime' for a list of
 --   flaws
-iso8601_time :: CharParser a (MCalendarTime -> MCalendarTime)
-iso8601_time = try $
+iso8601Time :: CharParser a (MCalendarTime -> MCalendarTime)
+iso8601Time = try $
   do ts <- optchain hour_ [ (colon     , min_)
                           , (colon     , sec_)
-                          , (oneOf ",.", pico_) ] 
+                          , (oneOf ",.", pico_) ]
      z  <- option id $ choice [ zulu , offset ]
      return $ foldr (.) id (z:ts)
-  where 
-    hour_ = do h <- two_digits
+  where
+    hour_ = do h <- twoDigits
                return $ \c -> c { mctHour = Just h }
-    min_  = do m <- two_digits
+    min_  = do m <- twoDigits
                return $ \c -> c { mctMin = Just m }
-    sec_  = do s <- two_digits
+    sec_  = do s <- twoDigits
                return $ \c -> c { mctSec = Just s }
     pico_ = do digs <- many digit
                let picoExp = 12
@@ -301,8 +301,8 @@ iso8601_time = try $
     zulu   = do { char 'Z'; return (\c -> c { mctTZ = Just 0 }) }
     offset = do sign <- choice [ do { char '+' >> return   1  }
                                , do { char '-' >> return (-1) } ]
-                h <- two_digits
-                m <- option 0 $ do { optional colon; two_digits }
+                h <- twoDigits
+                m <- option 0 $ do { optional colon; twoDigits }
                 return $ \c -> c { mctTZ = Just $ sign * 60 * ((h*60)+m) }
     colon = char ':'
 
@@ -314,24 +314,24 @@ iso8601_time = try $
 --
 --    * P2Y11MT16H30M/2012-08-17T16:30
 --
---   See 'iso8601_duration'
-iso8601_interval :: Int -> CharParser a (Either TimeDiff (MCalendarTime, MCalendarTime))
-iso8601_interval localTz = leftDur <|> rightDur where
-  leftDur  = 
-    do dur <- iso8601_duration 
+--   See 'iso8601Duration'
+iso8601Interval :: Int -> CharParser a (Either TimeDiff (MCalendarTime, MCalendarTime))
+iso8601Interval localTz = leftDur <|> rightDur where
+  leftDur  =
+    do dur <- iso8601Duration
        end <- option Nothing $ do { char '/'; Just `liftM` isoDt }
-       return $ case end of 
+       return $ case end of
                 Nothing -> Left dur
                 Just e  -> Right (dur `subtractFromMCal` e, e)
   rightDur =
     do start <- isoDt
        char '/'
-       durOrEnd <- Left `liftM` iso8601_duration <|> Right `liftM` isoDt
+       durOrEnd <- Left `liftM` iso8601Duration <|> Right `liftM` isoDt
        return $ case durOrEnd of
                 Left dur  -> Right (start, dur `addToMCal` start)
                 Right end -> Right (start, end)
-  isoDt   = iso8601_date_time localTz
-   
+  isoDt   = iso8601DateTime localTz
+
 -- | Durations in ISO 8601, e.g.,
 --
 --    * P4Y (four years)
@@ -341,19 +341,19 @@ iso8601_interval localTz = leftDur <|> rightDur where
 --    * P4Y5M (four years and five months)
 --
 --    * P4YT3H6S (four years, three hours and six seconds)
-iso8601_duration :: CharParser a TimeDiff
-iso8601_duration = 
+iso8601Duration :: CharParser a TimeDiff
+iso8601Duration =
   do char 'P'
      y   <- block 0 'Y'
      mon <- block 0 'M'
      d   <- block 0 'D'
-     (h,m,s) <- option (0,0,0) $ 
+     (h,m,s) <- option (0,0,0) $
        do char 'T'
           h' <- block (-1) 'H'
           m' <- block (-1) 'M'
           s' <- block (-1) 'S'
           let unset = (== (-1))
-          if all unset [h',m',s'] 
+          if all unset [h',m',s']
              then fail "T should be omitted if time is unspecified"
              else let clear x = if (unset x) then 0 else x
                   in return (clear h', clear m', clear s')
@@ -361,7 +361,7 @@ iso8601_duration =
      return $ TimeDiff y mon d h m s 0
   where block d c = option d $ try $
           do n <- many1 digit
-             char c 
+             char c
              return $ read n
 
 -- | 'optchain' @p xs@ parses a string with the obligatory
@@ -378,29 +378,29 @@ iso8601_duration =
 --   the year and month), 200707 (only the year and month
 --   with no separator), 2007-07-19 (year, month and day).
 optchain :: CharParser a b -> [(CharParser a c, CharParser a b)] -> CharParser a [b]
-optchain p next = try $ 
+optchain p next = try $
   do r1 <- p
-     r2 <- case next of 
+     r2 <- case next of
            [] -> return []
            ((sep,p2):next2) -> option [] $ do { optional sep; optchain p2 next2 }
      return (r1:r2)
 
-n_digits :: Int -> CharParser a Int 
-n_digits n = read `liftM` count n digit
+nDigits :: Int -> CharParser a Int
+nDigits n = read `liftM` count n digit
 
-two_digits, four_digits :: CharParser a Int
-two_digits = n_digits 2
-four_digits = n_digits 4
+twoDigits, fourDigits :: CharParser a Int
+twoDigits = nDigits 2
+fourDigits = nDigits 4
 
 -- | One or more space.
 --   WARNING! This only matches on the space character, not on
 --   whitespace in general
-my_spaces :: CharParser a String
-my_spaces = manyN 1 $ char ' '
+mySpaces :: CharParser a String
+mySpaces = manyN 1 $ char ' '
 
 -- | English three-letter day abbreviations (e.g. Mon, Tue, Wed)
-day_name        :: CharParser a Day
-day_name         = choice
+dayName        :: CharParser a Day
+dayName         = choice
                        [ caseString "Mon"       >> return Monday
                        , try (caseString "Tue") >> return Tuesday
                        , caseString "Wed"       >> return Wednesday
@@ -412,11 +412,11 @@ day_name         = choice
 
 -- | Four-digit year
 year            :: CharParser a Int
-year             = four_digits
+year             = fourDigits
 
 -- | One or two digit month (e.g. 3 for March, 11 for November)
-month_num       :: CharParser a Month
-month_num = do mn <- manyNtoM 1 2 digit 
+monthNum       :: CharParser a Month
+monthNum =  do mn <- manyNtoM 1 2 digit
                return $ intToMonth $ (read mn :: Int)
 
 -- | January is 1, February is 2, etc
@@ -436,8 +436,8 @@ intToMonth 12 = December
 intToMonth _  = error "invalid month!"
 
 -- | English three-letter month abbreviations (e.g. Jan, Feb, Mar)
-month_name      :: CharParser a Month
-month_name       = choice
+monthName      :: CharParser a Month
+monthName       = choice
                        [ try (caseString "Jan") >> return January
                        , caseString "Feb"       >> return February
                        , try (caseString "Mar") >> return March
@@ -459,15 +459,15 @@ day              = do d <- manyNtoM 1 2 digit
 
 -- | hour in two-digit notation
 hour            :: CharParser a Int
-hour             = two_digits
+hour             = twoDigits
 
 -- | minute in two-digit notation
 minute          :: CharParser a Int
-minute           = two_digits
+minute           = twoDigits
 
 -- | second in two-digit notation
 second          :: CharParser a Int
-second           = two_digits
+second           = twoDigits
 
 -- | limited timezone support
 --
@@ -552,18 +552,18 @@ zone             = choice
 --   Uses its first argument as "now", i.e. the time relative to which
 --   "yesterday", "today" etc are to be interpreted
 englishDateTime :: CalendarTime -> CharParser a CalendarTime
-englishDateTime now = 
-  try $ dateMaybeAtTime <|> timeThenDate      
-  where 
+englishDateTime now =
+  try $ dateMaybeAtTime <|> timeThenDate
+  where
    -- yesterday (at) noon
-   dateMaybeAtTime = try $ 
+   dateMaybeAtTime = try $
      do ed <- englishDate now
         t  <- option Nothing $ try $
                 do { space; optional $ caseString "at "; Just `liftM` englishTime }
         return $ fromMaybe id t $ ed
    -- tea time 2005-12-04
    timeThenDate = try $
-     do t  <- englishTime 
+     do t  <- englishTime
         optional $ char ','
         space
         ed <- englishDate now
@@ -581,7 +581,7 @@ englishDateTime now =
 --
 --   The first argument is "now".
 englishDate :: CalendarTime -> CharParser a CalendarTime
-englishDate now = try $ 
+englishDate now = try $
       (caseString "today"     >> (return $ resetCalendar now))
   <|> (caseString "yesterday" >> (return $ oneDay `subtractFromCal` now) )
   <|> fst `fmap` englishLast now
@@ -606,7 +606,7 @@ englishAgo now =
                           space
                           d <- englishDate now
                                <|> fst `fmap` englishLast now
-                               <|> unsafeToCalendarTime `fmap` iso8601_date_time (ctTZ now)
+                               <|> unsafeToCalendarTime `fmap` iso8601DateTime (ctTZ now)
                           return (m,d)
            return $ multiplyDiff m p `addToCal` ref
   where
@@ -626,27 +626,27 @@ englishAgo now =
 --    * 4 months ago (i.e. till now; see 'englishAgo')
 englishInterval :: CalendarTime -> CharParser a TimeInterval
 englishInterval now = twixt <|> before <|> after <|> inTheLast <|> lastetc
-  where 
-   englishDT = (unsafeToCalendarTime `fmap` iso8601_date_time (ctTZ now)
+  where
+   englishDT = (unsafeToCalendarTime `fmap` iso8601DateTime (ctTZ now)
                 <|> englishDateTime now)
    before = try $
      do caseString "before"
         space
-        end <- englishDT 
+        end <- englishDT
         return (Just theBeginning, Just end)
    after = try $
      do caseString "after"
         space
         start <- englishDT
         return (Just start, Nothing)
-   twixt = try $ 
+   twixt = try $
      do caseString "between"
         space
         start <- englishDT
         space
-        caseString "and" 
+        caseString "and"
         space
-        end <- englishDT 
+        end <- englishDT
         return (Just start, Just end)
    inTheLast = try $
      do caseString "in the last"
@@ -668,17 +668,17 @@ englishLast now =
              d <- englishDuration
              return (d `subtractFromCal` now, now)
 
--- | Either an 'iso8601_time' or one of several common
+-- | Either an 'iso8601Time' or one of several common
 --   English time expressions like 'noon' or 'tea time'
 englishTime :: CharParser a (CalendarTime->CalendarTime)
-englishTime = try $ 
-  choice [ wrapM `fmap` iso8601_time
-         , namedTime "noon"            12  0 
+englishTime = try $
+  choice [ wrapM `fmap` iso8601Time
+         , namedTime "noon"            12  0
          , namedTime "midnight"         0  0
          , namedTime "tea time"        16 30
-         , namedTime "bed time"         2 30    
+         , namedTime "bed time"         2 30
          , namedTime "proper bed time" 21 30 ]
-  where namedTime name h m = try $ 
+  where namedTime name h m = try $
           do caseString name
              return $ \c -> c { ctHour = h, ctMin = m }
         wrapM f = unsafeToCalendarTime . f . toMCalendarTime
@@ -702,11 +702,11 @@ englishDuration = try $
      b <- base
      optional (caseString "es" <|> caseString "s")
      let current = multiplyDiff n b
-     next <- option noTimeDiff $ try $ do 
+     next <- option noTimeDiff $ try $ do
               { optional space; char ',' ; optional space ; englishDuration }
-     return $ addDiff current next 
-  where 
-  base = choice 
+     return $ addDiff current next
+  where
+  base = choice
          [ try $ caseString "score"      >> (return $ TimeDiff 20 0  0 0 0 0 0) -- why not?
          ,       caseString "year"       >> (return $ TimeDiff  1 0  0 0 0 0 0)
          , try $ caseString "month"      >> (return $ TimeDiff  0 1  0 0 0 0 0)
@@ -714,9 +714,9 @@ englishDuration = try $
          ,       caseString "week"       >> (return $ TimeDiff  0 0  7 0 0 0 0)
          ,       caseString "day"        >> (return $ TimeDiff  0 0  1 0 0 0 0)
          ,       caseString "hour"       >> (return $ TimeDiff  0 0  0 1 0 0 0)
-         ,       caseString "minute"     >> (return $ TimeDiff  0 0  0 0 1 0 0) 
+         ,       caseString "minute"     >> (return $ TimeDiff  0 0  0 0 1 0 0)
          ,       caseString "second"     >> (return $ TimeDiff  0 0  0 0 0 1 0) ]
-   
+
 ----- Calendar and TimeDiff manipulation ---------------------------------------------
 
 -- | The very beginning of time, i.e. 1970-01-01
