@@ -15,7 +15,7 @@
 -- the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 -- Boston, MA 02110-1301, USA.
 
-{-# OPTIONS_GHC -fno-warn-name-shadowing -cpp #-}
+{-# OPTIONS_GHC -fno-warn-name-shadowing #-}
 {-# LANGUAGE CPP #-}
 
 
@@ -40,52 +40,52 @@ data XYZ = XYZ !Word32 !Word32 !Word32
 
 sha1PS :: B.ByteString -> String
 sha1PS s = s5
- where s1_2 = sha1_step_1_2_pad_length s
-       abcde = sha1_step_3_init
+ where s1_2 = sha1Step12PadLength s
+       abcde = sha1Step3Init
        abcde' = unsafePerformIO
               $ unsafeWithInternals s1_2 (\ptr len ->
                     do let ptr' = castPtr ptr
 #ifndef BIGENDIAN
-                       fiddle_endianness ptr' len
+                       fiddleEndianness ptr' len
 #endif
-                       sha1_step_4_main abcde ptr' len)
-       s5 = sha1_step_5_display abcde'
+                       sha1Step4Main abcde ptr' len)
+       s5 = sha1Step5Display abcde'
 
-fiddle_endianness :: Ptr Word32 -> Int -> IO ()
-fiddle_endianness p 0 = p `seq` return ()
-fiddle_endianness p n
+fiddleEndianness :: Ptr Word32 -> Int -> IO ()
+fiddleEndianness p 0 = p `seq` return ()
+fiddleEndianness p n
  = do x <- peek p
       poke p $ shiftL x 24
            .|. shiftL (x .&. 0xff00) 8
            .|. (shiftR x 8 .&. 0xff00)
            .|. shiftR x 24
-      fiddle_endianness (p `advancePtr` 1) (n - 4)
+      fiddleEndianness (p `advancePtr` 1) (n - 4)
 
--- sha1_step_1_2_pad_length assumes the length is at most 2^61.
+-- sha1Step12PadLength assumes the length is at most 2^61.
 -- This seems reasonable as the Int used to represent it is normally 32bit,
 -- but obviously could go wrong with large inputs on 64bit machines.
 -- The B.ByteString library should probably move to Word64s if this is an
 -- issue, though.
 
-sha1_step_1_2_pad_length :: B.ByteString -> B.ByteString
-sha1_step_1_2_pad_length s
+sha1Step12PadLength :: B.ByteString -> B.ByteString
+sha1Step12PadLength s
  = let len = B.length s
        num_nuls = (55 - len) `mod` 64
        padding = 128:replicate num_nuls 0
-       len_w8s = reverse $ size_split 8 (fromIntegral len*8)
+       len_w8s = reverse $ sizeSplit 8 (fromIntegral len*8)
    in B.concat [s, B.pack padding, B.pack len_w8s]
 
-size_split :: Int -> Integer -> [Word8]
-size_split 0 _ = []
-size_split p n = fromIntegral d:size_split (p-1) n'
+sizeSplit :: Int -> Integer -> [Word8]
+sizeSplit 0 _ = []
+sizeSplit p n = fromIntegral d:sizeSplit (p-1) n'
  where (n', d) = divMod n 256
 
-sha1_step_3_init :: ABCDE
-sha1_step_3_init = ABCDE 0x67452301 0xefcdab89 0x98badcfe 0x10325476 0xc3d2e1f0
+sha1Step3Init :: ABCDE
+sha1Step3Init = ABCDE 0x67452301 0xefcdab89 0x98badcfe 0x10325476 0xc3d2e1f0
 
-sha1_step_4_main :: ABCDE -> Ptr Word32 -> Int -> IO ABCDE
-sha1_step_4_main abcde _ 0 = return $! abcde
-sha1_step_4_main (ABCDE a0@a b0@b c0@c d0@d e0@e) s len
+sha1Step4Main :: ABCDE -> Ptr Word32 -> Int -> IO ABCDE
+sha1Step4Main abcde _ 0 = return $! abcde
+sha1Step4Main (ABCDE a0@a b0@b c0@c d0@d e0@e) s len
     = do
          (e, b) <- doit f1 0x5a827999 (x 0) a b c d e
          (d, a) <- doit f1 0x5a827999 (x 1) e a b c d
@@ -168,7 +168,7 @@ sha1_step_4_main (ABCDE a0@a b0@b c0@c d0@d e0@e) s len
          (b, d) <- doit f2 0xca62c1d6 (m 78) c d e a b
          (a, c) <- doit f2 0xca62c1d6 (m 79) b c d e a
          let abcde' = ABCDE (a0 + a) (b0 + b) (c0 + c) (d0 + d) (e0 + e)
-         sha1_step_4_main abcde' (s `advancePtr` 16) (len - 64)
+         sha1Step4Main abcde' (s `advancePtr` 16) (len - 64)
  where {-# INLINE f1 #-}
        f1 (XYZ x y z) = (x .&. y) .|. ((complement x) .&. z)
        {-# INLINE f2 #-}
@@ -192,8 +192,8 @@ sha1_step_4_main (ABCDE a0@a b0@b c0@c d0@d e0@e) s len
               return (rotateL a 5 + f (XYZ b c d) + e + i' + k,
                       rotateL b 30)
 
-sha1_step_5_display :: ABCDE -> String
-sha1_step_5_display (ABCDE a b c d e)
+sha1Step5Display :: ABCDE -> String
+sha1Step5Display (ABCDE a b c d e)
  = concatMap showAsHex [a, b, c, d, e]
 
 showAsHex :: Word32 -> String
