@@ -1,8 +1,8 @@
 {-# LANGUAGE CPP, ForeignFunctionInterface #-}
 
-module URL ( copyUrl, copyUrlFirst, pipeliningEnabledByDefault,
-             setDebugHTTP, setHTTPPipelining, waitUrl,
-             Cachable(Cachable, Uncachable, MaxAge),
+module URL ( copyUrl, copyUrlFirst, setDebugHTTP,
+             disableHTTPPipelining, maxPipelineLength,
+             waitUrl, Cachable(Cachable, Uncachable, MaxAge),
              environmentHelpProxy, environmentHelpProxyPassword
            ) where
 
@@ -31,23 +31,21 @@ import System.Random ( randomRIO )
 #ifdef HAVE_CURL
 import Foreign.C.String ( withCString, peekCString, CString )
 #else
-import qualified HTTP ( request_url, wait_next_url )
+import qualified HTTP ( requestUrl, waitNextUrl )
 #endif
 #include "impossible.h"
 
 data UrlRequest = UrlRequest { url :: String
                              , file :: FilePath
                              , cachable :: Cachable
-                             , priority :: Priority
-                             , notifyVar :: MVar String }
+                             , priority :: Priority }
 
 data Cachable = Cachable | Uncachable | MaxAge !CInt
                 deriving (Show, Eq)
 
 data UrlState = UrlState { inProgress :: Map String ( FilePath
                                                     , [FilePath]
-                                                    , Cachable
-                                                    , (MVar String) )
+                                                    , Cachable )
                          , waitToStart :: Q String
                          , pipeLength :: Int
                          , randomJunk :: String }
@@ -80,26 +78,19 @@ nullQ _         = False
 
 data Priority = High | Low deriving Eq
 
-#if defined(CURL_PIPELINING) || defined(CURL_PIPELINING_DEFAULT)
-pipeliningLimit :: Int
-pipeliningLimit = 100
+{-# NOINLINE maxPipelineLengthRef #-}
+maxPipelineLengthRef :: IORef Int
+maxPipelineLengthRef = unsafePerformIO $ do
+  enabled <- pipeliningEnabled
+#ifdef HAVE_CURL
+  when (not enabled) (debugMessage $
+                      "Warning: pipelining is disabled, because libcurl "++
+                      "version darcs was compiled with is too old (< 7.19.1)")
 #endif
+  newIORef $ if enabled then 100 else 1
 
-pipeliningEnabledByDefault :: Bool
-#ifdef CURL_PIPELINING_DEFAULT
-pipeliningEnabledByDefault = True
-#else
-pipeliningEnabledByDefault = False
-#endif
-
-{-# NOINLINE maxPipeLength #-}
-maxPipeLength :: IORef Int
-maxPipeLength = unsafePerformIO $ newIORef $
-#ifdef CURL_PIPELINING_DEFAULT
-                pipeliningLimit
-#else
-                1
-#endif
+maxPipelineLength :: IO Int
+maxPipelineLength = readIORef maxPipelineLengthRef
 
 {-# NOINLINE urlNotifications #-}
 urlNotifications :: MVar (Map String (MVar String))
@@ -148,23 +139,23 @@ urlThread ch = do junk <- flip showHex "" `fmap` randomRIO rrange
                  st <- get
                  let p = inProgress st
                      w = waitToStart st
-                     e = (f, [], c, notifyVar r)
+                     e = (f, [], c)
                      new_w = case priority r of
                                High -> pushQ u w
                                Low  -> insertQ u w
                      new_st = st { inProgress = Map.insert u e p
                                  , waitToStart = new_w }
                  case Map.lookup u p of
-                   Just (f', fs', c', v) -> do
+                   Just (f', fs', c') -> do
                      let new_c = minCachable c c'
-                     when (c /= c') $ let new_p = Map.insert u (f', fs', new_c, v) p
+                     when (c /= c') $ let new_p = Map.insert u (f', fs', new_c) p
                                       in do modify (\s -> s { inProgress = new_p })
                                             dbg $ "Changing "++u++" request cachability from "++show c++" to "++show new_c
                      when (u `elemQ` w && priority r == High) $ do
                        modify (\s -> s { waitToStart = pushQ u (deleteQ u w) })
                        dbg $ "Moving "++u++" to head of download queue."
                      if f `notElem` (f':fs')
-                        then let new_p = Map.insert u (f', f:fs', new_c, v) p
+                        then let new_p = Map.insert u (f', f:fs', new_c) p
                              in do modify (\s -> s { inProgress = new_p })
                                    dbg "Adding new file to existing UrlRequest."
                         else dbg "Ignoring UrlRequest of file that's already queued."
@@ -179,25 +170,25 @@ checkWaitToStart :: StateT UrlState IO ()
 checkWaitToStart = do
   st <- get
   let l = pipeLength st
-  mpl <- liftIO $ readIORef maxPipeLength
+  mpl <- liftIO maxPipelineLength
   when (l < mpl) $ do
     let w = waitToStart st
     case readQ w of
       Just (u,rest) -> do
         case Map.lookup u (inProgress st) of
-          Just (f, _, c, v) -> do
-            dbg ("URL.request_url ("++u++"\n"++
+          Just (f, _, c) -> do
+            dbg ("URL.requestUrl ("++u++"\n"++
                  "              -> "++f++")")
             let f_new = f++"-new_"++randomJunk st
-            err <- liftIO $ request_url u f_new c
+            err <- liftIO $ requestUrl u f_new c
             if null err
-               then do dbg "URL.request_url succeeded"
+               then do dbg "URL.requestUrl succeeded"
                        liftIO $ atexit (removeFileMayNotExist f_new)
                        put $ st { waitToStart = rest
                                 , pipeLength = l + 1 }
                else do dbg $ "Failed to start download URL "++u++": "++err
                        liftIO $ do removeFileMayNotExist f_new
-                                   putMVar v err
+                                   downloadComplete u err
                        put $ st { waitToStart = rest }
           _              -> bug $ "Possible bug in URL.checkWaitToStart "++u
         checkWaitToStart
@@ -216,7 +207,7 @@ copyUrlWithPriority p u f c = do
   v <- newEmptyMVar
   let fn _ old_val = old_val
   modifyMVar_ urlNotifications (return . (Map.insertWith fn u v))
-  let r = UrlRequest u f c p v
+  let r = UrlRequest u f c p
   writeChan urlChan r
 
 waitNextUrl :: StateT UrlState IO ()
@@ -225,22 +216,22 @@ waitNextUrl = do
   let l = pipeLength st
   when (l > 0) $ do
                 dbg "URL.waitNextUrl start"
-                (u, e) <- liftIO $ wait_next_url
+                (u, e) <- liftIO $ waitNextUrl'
                 let p = inProgress st
                     new_st = st { inProgress = Map.delete u p
                                 , pipeLength = l - 1 }
                 liftIO $ if null e
                          then case Map.lookup u p of
-                                Just (f, fs, _, v) -> do
+                                Just (f, fs, _) -> do
                                   renameFile (f++"-new_"++randomJunk st) f
                                   mapM_ (safeCopyFile st f) fs
-                                  putMVar v e
+                                  downloadComplete u e
                                   debugMessage $ "URL.waitNextUrl succeeded: "++u++" "++f
                                 Nothing -> bug $ "Possible bug in URL.waitNextUrl: "++u
                          else case Map.lookup u p of
-                                Just (f, _, _, v) -> do
+                                Just (f, _, _) -> do
                                   removeFileMayNotExist (f++"-new_"++randomJunk st)
-                                  putMVar v e
+                                  downloadComplete u e
                                   debugMessage $ "URL.waitNextUrl failed: "++
                                                u++" "++f++" "++e
                                 Nothing -> bug $ "Another possible bug in URL.waitNextUrl: "++u++" "++e
@@ -249,6 +240,13 @@ waitNextUrl = do
                                 in do copyFile f new_t
                                       renameFile new_t t
 
+downloadComplete :: String -> String -> IO ()
+downloadComplete u e = do
+  r <- withMVar urlNotifications (return . (Map.lookup u))
+  case r of
+    Just notifyVar -> putMVar notifyVar e
+    Nothing -> debugMessage $ "downloadComplete URL '"++u++"' downloaded several times"
+
 waitUrl :: String -> IO ()
 waitUrl u = do debugMessage $ "URL.waitUrl "++u
                r <- withMVar urlNotifications (return . (Map.lookup u))
@@ -277,35 +275,33 @@ cachableToInt Uncachable = 0
 cachableToInt (MaxAge n) = n
 #endif
 
-setHTTPPipelining :: Bool -> IO ()
-setHTTPPipelining False = writeIORef maxPipeLength 1
-setHTTPPipelining True = writeIORef maxPipeLength
-#ifdef CURL_PIPELINING
-    pipeliningLimit
-#else
-    1 >> (putStrLn $ "Warning: darcs is compiled without HTTP pipelining "++
-                     "support, '--http-pipelining' argument is ignored.")
-#endif
+disableHTTPPipelining :: IO ()
+disableHTTPPipelining = writeIORef maxPipelineLengthRef 1
 
 setDebugHTTP :: IO ()
-request_url :: String -> FilePath -> Cachable -> IO String
-wait_next_url :: IO (String, String)
+requestUrl :: String -> FilePath -> Cachable -> IO String
+waitNextUrl' :: IO (String, String)
+pipeliningEnabled :: IO Bool
 
 #ifdef HAVE_CURL
 
 setDebugHTTP = curl_enable_debug
 
-request_url u f cache =
+requestUrl u f cache =
     withCString u $ \ustr ->
     withCString f $ \fstr -> do
       err <- curl_request_url ustr fstr (cachableToInt cache) >>= peekCString
       return err
 
-wait_next_url = do
+waitNextUrl' = do
   e <- curl_wait_next_url >>= peekCString
   u <- curl_last_url >>= peekCString
   return (u, e)
 
+pipeliningEnabled = do
+  r <- curl_pipelining_enabled
+  return $ r /= 0
+
 foreign import ccall "hscurl.h curl_request_url"
   curl_request_url :: CString -> CString -> CInt -> IO CString
 
@@ -318,17 +314,22 @@ foreign import ccall "hscurl.h curl_last_url"
 foreign import ccall "hscurl.h curl_enable_debug"
   curl_enable_debug :: IO ()
 
+foreign import ccall "hscurl.h curl_pipelining_enabled"
+  curl_pipelining_enabled :: IO CInt
+
 #elif defined(HAVE_HTTP)
 
 setDebugHTTP = return ()
-request_url = HTTP.request_url
-wait_next_url = HTTP.wait_next_url
+requestUrl = HTTP.requestUrl
+waitNextUrl' = HTTP.waitNextUrl
+pipeliningEnabled = return False
 
 #else
 
 setDebugHTTP = debugMessage "URL.setDebugHttp works only with libcurl"
-request_url _ _ _ = debugFail "URL.request_url: there is no libcurl!"
-wait_next_url = debugFail "URL.wait_next_url: there is no libcurl!"
+requestUrl _ _ _ = debugFail "URL.requestUrl: there is no libcurl!"
+waitNextUrl' = debugFail "URL.waitNextUrl': there is no libcurl!"
+pipeliningEnabled = return False
 
 #endif
 
