@@ -1,5 +1,3 @@
-#ifdef HAVE_CURL
-
 #include "hscurl.h"
 
 #include <curl/curl.h>
@@ -8,6 +6,11 @@
 #include <stdlib.h>
 #include <string.h>
 
+#if LIBCURL_VERSION_NUM >= 0x071301
+/* enable pipelining for libcurl >= 7.19.1 */
+#define ENABLE_PIPELINING
+#endif
+
 enum RESULT_CODES
   {
     RESULT_OK = 0,
@@ -16,7 +19,6 @@ enum RESULT_CODES
     RESULT_MULTI_INIT_FAIL,
     RESULT_EASY_INIT_FAIL,
     RESULT_SLIST_APPEND_FAIL,
-    RESULT_NO_RUNNING_HANDLES,
     RESULT_MULTI_INFO_READ_FAIL,
     RESULT_UNKNOWN_MESSAGE,
     RESULT_FILE_OPEN_FAIL
@@ -30,7 +32,6 @@ static const char *error_strings[] =
     "curl_multi_init() failed",
     "curl_easy_init() failed",
     "curl_slist_append() failed",
-    "curl_multi_perform() - no running handles",
     "curl_multi_info_read() failed",
     "curl_multi_info_read() returned unknown message",
     "fopen() failed"
@@ -44,8 +45,14 @@ struct UrlData
 };
 
 static int debug = 0;
+#ifndef _WIN32
 static const char user_agent[] =
   "darcs/" PACKAGE_VERSION " libcurl/" LIBCURL_VERSION;
+#else
+static const char user_agent[] =
+  "darcs/unknown libcurl/" LIBCURL_VERSION;
+#endif
+
 static const char *proxypass;
 static int init_done = 0;
 static CURLM *multi = NULL;
@@ -64,11 +71,9 @@ static const char *perform()
   error = curl_multi_perform(multi, &running_handles);
   if (error != CURLM_OK && error != CURLM_CALL_MULTI_PERFORM)
     return curl_multi_strerror(error);
-  if (running_handles == 0)
-    return error_strings[RESULT_NO_RUNNING_HANDLES];
 
   running_handles_last = running_handles;
-  while (1)
+  while (running_handles_last > 0)
     {
       while (error == CURLM_CALL_MULTI_PERFORM)
         error = curl_multi_perform(multi, &running_handles);
@@ -133,7 +138,7 @@ const char *curl_request_url(const char *url,
       multi = curl_multi_init();
       if (multi == NULL)
         return error_strings[RESULT_MULTI_INIT_FAIL];
-#ifdef CURL_PIPELINING
+#ifdef ENABLE_PIPELINING
       error = curl_multi_setopt(multi, CURLMOPT_PIPELINING, 1);
       if (error != CURLM_OK && error != CURLM_CALL_MULTI_PERFORM)
         return curl_multi_strerror(error);
@@ -302,4 +307,11 @@ void curl_enable_debug()
   debug = 1;
 }
 
+int curl_pipelining_enabled()
+{
+#ifdef ENABLE_PIPELINING
+  return 1;
+#else
+  return 0;
 #endif
+}
