@@ -3,35 +3,31 @@
 
 module System.Posix where
 
-import Foreign.Ptr ( Ptr, castPtr, plusPtr )
-import Foreign.Storable ( peek, poke, sizeOf )
+import Foreign.Ptr ( Ptr )
+import Foreign.Storable ( peek )
 import Foreign.C.Types ( CInt, CUInt, CULong, CTime )
 import Foreign.C.String ( CString, withCString )
-import Foreign.Marshal.Alloc ( allocaBytes )
+import Foreign.Marshal.Array ( withArray )
+import Foreign.Marshal.Alloc ( alloca )
 
 import System.Posix.Types ( EpochTime )
 import System.IO ( Handle )
 
-
-foreign import ccall "sys/utime.h _utime" c_utime :: CString -> Ptr a -> IO CInt
+foreign import ccall "sys/utime.h _utime" c_utime :: CString -> Ptr CTime -> IO CInt
 
 setFileTimes :: FilePath -> EpochTime -> EpochTime -> IO ()
 setFileTimes path atime mtime = path `withCString` \s -> do
-  allocaBytes 8 $ \p -> do
-    poke (castPtr p :: Ptr CTime) (atime)
-    poke (castPtr (plusPtr p 4) :: Ptr CTime) (mtime)
-    c_utime s p
-    return ()
+  withArray [atime,mtime] $ \p -> do c_utime s p
+                                     return ()
 
 
 foreign import ccall "time" c_ctime :: Ptr CTime -> IO CInt
 
 epochTime :: IO EpochTime
 epochTime = do
-    allocaBytes (sizeOf (undefined :: CTime)) $ \p -> do
-      c_ctime p
-      t <- peek p :: IO CTime
-      return t
+  alloca $ \p -> do c_ctime p
+                    t <- peek p :: IO CTime
+                    return t
 
 foreign import stdcall "winbase.h SleepEx" c_SleepEx :: CULong -> CUInt -> IO CInt
 
