@@ -31,7 +31,7 @@ darcs init
 cd ..
 darcs get temp1 > log
 not grep fakessh log
-not darcs get http://example.com/foo
+not darcs get http://darcs.net/nonexistent
 not grep fakessh log
 cd ..
 rm -rf temp1
