@@ -1,19 +1,17 @@
 #!/usr/bin/env bash
 set -ev
 
-test "$DARCS" || DARCS="$PWD"/../darcs
-
 rm -rf temp temp2 temp3
 
 #"$DARCS" get http://darcs.net temp
 
-"$DARCS" get --lazy http://darcs.net temp2
+darcs get --lazy http://darcs.net temp2
 
-"$DARCS" get --lazy --tag . http://darcs.net temp3
+darcs get --lazy --tag . http://darcs.net temp3
 
 cd temp2
-"$DARCS" obliterate --from-tag . -a
-"$DARCS" pull --tag . -a
+darcs obliterate --from-tag . -a
+darcs pull --tag . -a
 cd ..
 
 diff -u temp2/_darcs/hashed_inventory temp3/_darcs/hashed_inventory
