@@ -25,7 +25,7 @@ cd ../..  # now in temp2
 darcs add one;
 darcs record --patch-name uno --all
 cd ..     # now outside of any repo
-darcs pull --repodir temp1 --all temp2 | grep -i 'Finished pulling.' # temp2 is not relative to temp1
+darcs pull --set-default --repodir temp1 --all temp2 | grep -i 'Finished pulling.' # temp2 is not relative to temp1
 
 # set up server repo
 date > temp2/one/date.t
@@ -119,7 +119,7 @@ darcs add newdir
 darcs record -am newdir
 cd ../temp2
 mkdir newdir
-darcs pull -a ../temp1 &> out2
+darcs pull -a --set-default ../temp1 &> out2
 cat out
 grep Backing out2
 grep 'Finished pulling' out2
