@@ -19,7 +19,7 @@ cd ..
 mkdir temp2
 cd temp2
 darcs init
-echo yn | darcs pull ../temp1
+echo yn | darcs pull --set-default ../temp1
 rm foo
 darcs pull -a
 cd ..
